<?php
/*
Plugin Name: Alpus Core
Plugin URI: https://alpustheme.com/
Description: Adds functionality such as Post Types, Widgets and Page Builders to Alpus Theme
Version: 1.0.1
Author: AlpusTheme
Author URI: https://alpustheme.com/
Text Domain: alpha-core
*/

// Direct load is not allowed
defined( 'ABSPATH' ) || die;

/**************************************/
/* Define Constants                   */
/**************************************/
defined( 'ALPHA_NAME' ) || define( 'ALPHA_NAME', 'alpha' );
defined( 'ALPHA_DISPLAY_NAME' ) || define( 'ALPHA_DISPLAY_NAME', 'Alpus' );
defined( 'ALPHA_ICON_PREFIX' ) || define( 'ALPHA_ICON_PREFIX', 'a' );
define( 'ALPHA_CORE_URI', untrailingslashit( plugin_dir_url( __FILE__ ) ) );               // Plugin directory uri
define( 'ALPHA_CORE_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );             // Plugin directory path
define( 'ALPHA_CORE_FILE', __FILE__ );                                                     // Plugin file path
define( 'ALPHA_CORE_VERSION', '1.0.0' );                                                   // Plugin Version

defined( 'ALPHA_SERVER_URI' ) || define( 'ALPHA_SERVER_URI', 'http://alpustheme.com/' );                    // Server uri

// Defines core name and slug if not defined.
defined( 'ALPHA_CORE_NAME' ) || define( 'ALPHA_CORE_NAME', 'Alpus Core' );
defined( 'ALPHA_CORE_SLUG' ) || define( 'ALPHA_CORE_SLUG', 'alpus-core' );
defined( 'ALPHA_CORE_PLUGIN_URI' ) || define( 'ALPHA_CORE_PLUGIN_URI', 'alpus-core/alpus-core.php' );

// Define script debug
defined( 'ALPHA_JS_SUFFIX' ) || ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? define( 'ALPHA_JS_SUFFIX', '.js' ) : define( 'ALPHA_JS_SUFFIX', '.min.js' ) );

if ( ! class_exists( 'Alpha_Base' ) ) {
	require_once ALPHA_CORE_PATH . '/framework/class-alpha-base.php';
}

require_once ALPHA_CORE_PATH . '/inc/config-function.php';

require_once ALPHA_CORE_PATH . '/framework/config.php';

if ( ! function_exists( 'alpus_plugin_framework_loader' ) ) {
	require_once( ALPHA_CORE_PATH . '/plugin-framework/init.php' );
}
alpus_plugin_framework_loader( ALPHA_CORE_PATH . '/' );

/**
 * Alpha Core Plugin Class
 *
 * @since 1.0
 */
class Alpha_Core {

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	public function __construct() {
		// Load plugin
		add_action( 'plugins_loaded', array( $this, 'load' ) );
	}

	/**
	 * Load required files
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function load() {
		// Load text domain
		load_plugin_textdomain( 'alpha-core', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
		
		// Check if theme activated
		if ( 'alpus' != get_template() && 'alpus-pro' != get_template() ) {
			add_action( 'admin_notices', array( $this, 'theme_required' ) );
			return;
		}

		require_once ALPHA_CORE_PATH . '/inc/core-setup.php';
		require_once alpha_core_framework_path( ALPHA_CORE_FRAMEWORK_PATH . '/init.php' );
		
		global $alpus_plugin_fw_data;
		if ( ! empty( $alpus_plugin_fw_data ) ) {
			require_once array_values( $alpus_plugin_fw_data )[0];
		}

		new Alpus_Plugin_Framework( array( 'slug' => '' ) );
	}
	
	/**
	 * Show in WP Dashboard notice about the alpus theme is not activated.
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function theme_required() {
		$message  = '<p>' . sprintf( esc_html__( '%1$sAlpus Core%2$s requires Alpus to be your active theme. Please install & activate to continue.', 'alpha-core' ), '<strong>', '</strong>' ) . '</p>';
		echo '<div class="error">' . $message . '</div>';
	}
}

new Alpha_Core();
