<?php
/**
 * Alpha Studio Extend
 *
 * @author     AlpusTheme
 * @package    Alpus Core
 * @subpackage Core
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

if ( ! class_exists( 'Alpha_Studio_Extend' ) ) :

	/**
	 * The Alpha Studio class
	 *
	 * @since 1.0
	 */
	class Alpha_Studio_Extend {
	
		private $element_categories  = array();
	
		/**
		 * Constructor
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_filter( 'alpha_studio_vars', array( $this, 'studio_vars' ) );

			// Update framework studio categories
			add_filter( 'alpha_studio_category', array( $this, 'studio_categories' ) );
			add_filter( 'alpha_studio_big_category', array( $this, 'studio_big_categories' ) );
			add_filter( 'alpha_studio_has_children', array( $this, 'studio_has_children' ) );
			add_filter( 'alpha_studio_block_category', array( $this, 'studio_block_categories' ) );
			add_filter( 'alpha_studio_blocks_args', array( $this, 'studio_blocks_args' ) );

			// Add new studio categories
			$this->element_categories  = apply_filters( 'alpha_studio_element_category', array( 'button', 'contact_info', 'counter', 'icon_box', 'image_box', 'image_gallery', 'icon_list', 'search', 'progressbars', 'social', 'testimonials', 'video', 'pricing', 'products', 'posts', 'projects', 'team' ) );
		}

		/**
		 * Extend studio vars
		 *
		 * @since 1.0
		 */
		public function studio_vars( $vars ) {
			$vars['registered']    = class_exists( 'Alpha_Admin' ) && Alpha_Admin::get_instance()->is_registered();
			$vars['pro_title']    = esc_html__( 'Upgrade', 'alpha-core' );
			$vars['pro_desc']     = ALPHA_ENVATO_CODE ? esc_html__( 'Activate theme and get pro to access Alpus Studio Library.', 'alpha-core' ) : esc_html__( 'Purchase of Pro and theme activation are required to access Alpus Studio Library.', 'alpha-core' );
			$vars['purchase_pro']  = ALPHA_GET_PRO_URI;
			return $vars;
		}

		/**
		 * Studio categories
		 *
		 * @since 1.0
		 */
		public function studio_categories( $categories ) {
			$categories = array(
				'block'          => esc_html__( 'Block', 'alpha-core' ), // Blocks
				'demo'           => esc_html__( 'Demo', 'alpha-core' ),
				'about'          => esc_html__( 'About', 'alpha-core' ),
				'contact'        => esc_html__( 'Contact', 'alpha-core' ),
				'banner'         => esc_html__( 'Banner', 'alpha-core' ),
				'slider'         => esc_html__( 'Slider', 'alpha-core' ),
				'megamenu'       => esc_html__( 'Megamenu', 'alpha-core' ),
				'error-404'      => esc_html__( 'Error 404', 'alpha-core' ),
				'other'          => esc_html__( 'Other', 'alpha-core' ),
				'element'        => esc_html__( 'Element', 'alpha-core' ), // Elements
				'button'         => esc_html__( 'Button', 'alpha-core' ),
				'contact_info'   => esc_html__( 'Contact', 'alpha-core' ),
				'counter'        => esc_html__( 'Counter', 'alpha-core' ),
				'icon_box'       => esc_html__( 'Icon Box', 'alpha-core' ),
				'image_box'      => esc_html__( 'Image Box', 'alpha-core' ),
				'image_gallery'  => esc_html__( 'Image Gallery', 'alpha-core' ),
				'icon_list'      => esc_html__( 'Icon List', 'alpha-core' ),
				'search'         => esc_html__( 'Search', 'alpha-core' ),
				'social'         => esc_html__( 'Social Icons', 'alpha-core' ),
				'progressbars'   => esc_html__( 'Progressbars', 'alpha-core' ),
				'testimonials'   => esc_html__( 'Testimonials', 'alpha-core' ),
				'video'          => esc_html__( 'Video', 'alpha-core' ),
				'pricing'        => esc_html__( 'Pricing', 'alpha-core' ),
				'products'       => esc_html__( 'Products', 'alpha-core' ),
				'posts'          => esc_html__( 'Posts', 'alpha-core' ),
				'projects'       => esc_html__( 'Projects', 'alpha-core' ),
				'team'           => esc_html__( 'Team', 'alpha-core' ),
				'header'         => esc_html__( 'Header', 'alpha-core' ),
				'footer'         => esc_html__( 'Footer', 'alpha-core' ),
				'template'       => esc_html__( 'Template', 'alpha-core' ), // Templates
				'shop'           => esc_html__( 'Shop', 'alpha-core' ),
				'product_layout' => esc_html__( 'Single Product', 'alpha-core' ),
				'single'         => esc_html__( 'Single', 'alpha-core' ),
				'archive'        => esc_html__( 'Archive', 'alpha-core' ),
				'popup'          => esc_html__( 'Popup', 'alpha-core' ),
				'cart'           => esc_html__( 'Cart', 'alpha-core' ),
				'checkout'       => esc_html__( 'Checkout', 'alpha-core' ),
				'type'           => esc_html__( 'Post Types', 'alpha-core' ),
				'page_title_bar' => esc_html__( 'Page Title Bar', 'alpha-core' ),
				'favourites'     => esc_html__( 'Favourites', 'alpha-core' ),
				'my-templates'   => esc_html__( 'My Templates', 'alpha-core' ),
			);
			
			return $categories;
		}

		/**
		 * Studio parent categories
		 *
		 * @since 1.0
		 */
		public function studio_big_categories( $categories ) {
			$categories = array( 'header', 'page_title_bar', 'block', 'element', 'footer', 'popup', 'template', 'favourites', 'my-templates' );
			return $categories;
		}

		/**
		 * Studio categories that have child categories
		 *
		 * @since 1.0
		 */
		public function studio_has_children( $categories ) {
			$categories = array( 'block', 'element', 'template' );
			return $categories;
		}

		/**
		 * Studio categories child of blocks category
		 *
		 * @since 1.0
		 */
		public function studio_block_categories( $categories ) {
			$categories = array( 'demo', 'about', 'banner', 'slider', 'contact', 'megamenu', 'other' );
			return $categories;
		}

		/**
		 * Studio block render args
		 *
		 * @since 1.0
		 */
		public function studio_blocks_args( $args ) {
			$args[ 'element_categories' ] = $this->element_categories;
			return $args;
		}
	}

	new Alpha_Studio_Extend;

endif;
