<?php
/**
 * Alpha Customizer
 *
 * @author     AlpusTheme
 * @package    Alpus Core
 * @subpackage Core
 * @since      1.0
 *
 */
defined( 'ABSPATH' ) || die;

if ( ! class_exists( 'Alpha_Core_Admin' ) ) {
	class Alpha_Core_Admin extends Alpha_Base {

		/**
		 * The Constructor.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_filter( 'alpha_admin_config', array( $this, 'admin_config' ), 10, 2 );
			add_filter( 'alpha_demo_types', array( $this, 'demo_types' ) );

			add_action( 'after_setup_theme', function() {
				if ( is_admin_bar_showing() && defined( 'ALPHA_VERSION' ) ) {
					add_action( 'wp_before_admin_bar_render', array( $this, 'add_wp_toolbar_menu' ) );
				}
			} );
		}

		/**
		 * Get demo types for import in setup wizard.
		 *
		 * @see framework/admin/setup-wizard/class-alpha-setup-wizard.php
		 * @since 1.0
		 */
		public function demo_types( $demo ) {
			return $demo;
		}

		/**
		 * Get the admin config.
		 *
		 * @since 1.0
		 */
		public function admin_config( $config, $self ) {
			unset( $config['links']['showcase'] );
            $config['admin_navs'] = array(
				'dashboard'     => array(
					'icon'  => 'fas fa-tachometer-alt',
					'label' => esc_html__( 'Dashboard', 'alpha-core' ),
					'url'   => admin_url( 'admin.php?page=alpha' ),
				),
				'management'    => array(
					'icon'    => 'fas fa-cog',
					'label'   => esc_html__( 'Management', 'alpha-core' ),
					'submenu' => array(
						'setup_wizard'    => array(
							'label' => esc_html__( 'Setup Wizard', 'alpha-core' ),
							'icon'  => 'fas fa-user-cog',
							'url'   => admin_url( 'admin.php?page=alpha-setup-wizard' ),
							'desc'  => esc_html__( 'Setup your site quickly.', 'alpha-core' ),
						),
						'optimize_wizard' => array(
							'label' => esc_html__( 'Optimize Wizard', 'alpha-core' ),
							'icon'  => 'fas fa-rocket',
							'url'   => admin_url( 'admin.php?page=alpha-optimize-wizard' ),
							'desc'  => esc_html__( 'Enhance your site spped.', 'alpha-core' ),
						),
						'tools'           => array(
							'label' => esc_html__( 'Tools', 'alpha-core' ),
							'icon'  => 'fas fa-puzzle-piece',
							'url'   => admin_url( 'admin.php?page=alpha-tools' ),
							'desc'  => esc_html__( 'Keep your site healthy.', 'alpha-core' ),
						),
					),
				),
				'layouts'       => array(
					'icon'    => 'fas fa-layer-group',
					'label'   => esc_html__( 'Layouts', 'alpha-core' ),
					'submenu' => array(
						'layout_builder' => array(
							'label' => esc_html__( 'Layout Builder', 'alpha-core' ),
							'icon'  => 'fas fa-object-group',
							'url'   => admin_url( 'admin.php?page=alpha-layout-builder' ),
							'desc'  => esc_html__( 'Edit your site layouts.', 'alpha-core' ),
						),
					),
				),
				'theme_options' => array(
					'icon'  => 'fas fa-users-cog',
					'label' => esc_html__( 'Theme Options', 'alpha-core' ),
					'url'   => admin_url( 'customize.php' ),
				),
			);
            
			if ( $self->is_registered() ) {
				$config['admin_navs']['management']['submenu']['rollback'] = array(
					'label' => esc_html__( 'Rollback', 'alpha-core' ),
					'icon'  => 'fas fa-arrow-alt-circle-down',
					'url'   => admin_url( 'admin.php?page=alpha-rollback' ),
					'desc'  => esc_html__( 'Rollback to previous versions.', 'alpha-core' ),
				);
				if ( alpha_get_option( 'resource_critical_css' ) && class_exists( 'Alpha_Critical' ) ) {
					$config['admin_navs']['management']['submenu']['critical_css'] = array(
						'label' => esc_html__( 'Critical CSS', 'alpha-core' ),
						'icon'  => 'fab fa-critical-role',
						'url'   => admin_url( 'admin.php?page=alpha-critical' ),
						'desc'  => esc_html__( 'Generate Critical CSS.', 'alpha-core' ),
					);
				}
			}

			if ( class_exists( 'Alpha_Builders' ) ) {
				$config['admin_navs']['layouts']['submenu']['templates_builder'] = array(
					'label' => esc_html__( 'Templates', 'alpha-core' ),
					'icon'  => 'fas fa-pencil-ruler',
					'url'   => admin_url( 'edit.php?post_type=' . ALPHA_NAME . '_template' ),
					'desc'  => esc_html__( 'Create specific site templates.', 'alpha-core' ),
				);
			}
			if ( class_exists( 'Alpha_Sidebar_Builder' ) ) {
				$config['admin_navs']['layouts']['submenu']['sidebars_builder'] = array(
					'label'  => esc_html__( 'Sidebars', 'alpha-core' ),
					'icon'   => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 70 70" enable-background="new 0 0 70 70" xml:space="preserve">
						<rect x="3.5" y="3.5" width="17.5" height="63"/>
						<rect x="27.8" y="49.6" width="38.7" height="16.9"/>
						<rect x="27.8" y="3.5" width="38.7" height="39.5"/>
					</svg>',
					'is_svg' => true,
					'url'    => admin_url( 'admin.php?page=alpha-sidebar' ),
					'desc'   => esc_html__( 'Create unlimited sidebars.', 'alpha-core' ),
				);
			}
			return $config;
		}
        
		/**
		 * Add Alpha menu items to WordPress admin menu.
		 *
		 * @since 1.0
		 */
		public function add_wp_toolbar_menu() {
			$target = is_admin() ? '_self' : '_blank';

			if ( current_user_can( 'edit_theme_options' ) ) {

				$title = sprintf( esc_html__( '%s', 'alpha-core'), alpha_get_option( 'white_label_title' ) ); //phpcs:ignore
				$icon  = sprintf( esc_html__( '%s', 'alpha-core'), alpha_get_option( 'white_label_icon' ) ); //phpcs:ignore
				$this->add_wp_toolbar_menu_item(
					'<span class="ab-icon dashicons ' . ( ! $icon ? 'dashicons-alpha-logo">' : 'custom-mini-logo" style="background-image: url(' . esc_attr( $icon ) . ') !important; background-size: 20px 20px; background-repeat: no-repeat; background-position: center; width: 20px; height: 20px;">' ) . '</span><span class="ab-label">' . ( $title ? esc_html( $title ) : ALPHA_DISPLAY_NAME ) . '</span>',
					false,
					esc_url( admin_url( 'admin.php?page=alpha' ) ),
					array(
						'class'  => 'alpha-menu',
						'target' => $target,
					),
					'alpha'
				);

				// License

				$this->add_wp_toolbar_menu_item(
					esc_html__( 'Dashboard', 'alpha-core' ),
					'alpha',
					esc_url( admin_url( 'admin.php?page=alpha' ) ),
					array(
						'target' => $target,
					)
				);

				// Theme Options

				$this->add_wp_toolbar_menu_item(
					esc_html__( 'Theme Options', 'alpha-core' ),
					'alpha',
					esc_url( admin_url( 'customize.php' ) ),
					array(
						'target' => $target,
					)
				);

				// Management Submenu

				$this->add_wp_toolbar_menu_item(
					esc_html__( 'Management', 'alpha-core' ),
					'alpha',
					esc_url( admin_url( 'admin.php?page=alpha-setup-wizard' ) ),
					array(
						'target' => $target,
					),
					'alpha_management'
				);

				if ( class_exists( 'Alpha_Setup_Wizard' ) ) {
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Setup Wizard', 'alpha-core' ),
						'alpha_management',
						esc_url( admin_url( 'admin.php?page=alpha-setup-wizard' ) ),
						array(
							'target' => $target,
						),
						'alpha_setup'
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Status', 'alpha-core' ),
						'alpha_setup',
						esc_url( admin_url( 'admin.php?page=alpha-setup-wizard' ) ),
						array(
							'target' => $target,
						)
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Child Theme', 'alpha-core' ),
						'alpha_setup',
						esc_url( admin_url( 'admin.php?page=alpha-setup-wizard&step=customize' ) ),
						array(
							'target' => $target,
						)
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Plugins', 'alpha-core' ),
						'alpha_setup',
						esc_url( admin_url( 'admin.php?page=alpha-setup-wizard&step=default_plugins' ) ),
						array(
							'target' => $target,
						),
						'alpha_setup_plugins'
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Demo', 'alpha-core' ),
						'alpha_setup',
						esc_url( admin_url( 'admin.php?page=alpha-setup-wizard&step=demo_content' ) ),
						array(
							'target' => $target,
						)
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Ready', 'alpha-core' ),
						'alpha_setup',
						esc_url( admin_url( 'admin.php?page=alpha-setup-wizard&step=ready' ) ),
						array(
							'target' => $target,
						),
						'alpha_setup_ready'
					);
				}
				if ( class_exists( 'Alpha_Optimize_Wizard' ) ) {
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Optimize Wizard', 'alpha-core' ),
						'alpha_management',
						esc_url( admin_url( 'admin.php?page=alpha-optimize-wizard' ) ),
						array(
							'target' => $target,
						),
						'alpha_optimize'
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Resources', 'alpha-core' ),
						'alpha_optimize',
						esc_url( admin_url( 'admin.php?page=alpha-optimize-wizard' ) ),
						array(
							'target' => $target,
						)
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Lazyload', 'alpha-core' ),
						'alpha_optimize',
						esc_url( admin_url( 'admin.php?page=alpha-optimize-wizard&step=lazyload' ) ),
						array(
							'target' => $target,
						)
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Performance', 'alpha-core' ),
						'alpha_optimize',
						esc_url( admin_url( 'admin.php?page=alpha-optimize-wizard&step=performance' ) ),
						array(
							'target' => $target,
						)
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Plugins', 'alpha-core' ),
						'alpha_optimize',
						esc_url( admin_url( 'admin.php?page=alpha-optimize-wizard&step=plugins' ) ),
						array(
							'target' => $target,
						)
					);
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Ready', 'alpha-core' ),
						'alpha_optimize',
						esc_url( admin_url( 'admin.php?page=alpha-optimize-wizard&step=ready' ) ),
						array(
							'target' => $target,
						)
					);
				}
				if ( class_exists( 'Alpha_Tools' ) ) {
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Tools', 'alpha-core' ),
						'alpha_management',
						esc_url( admin_url( 'admin.php?page=alpha-tools' ) ),
						array(
							'target' => $target,
						)
					);
				}
				if ( class_exists( 'Alpha_Rollback' ) ) {
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Rollback', 'alpha-core' ),
						'alpha_management',
						esc_url( admin_url( 'admin.php?page=alpha-rollback' ) ),
						array(
							'target' => $target,
						)
					);
				}

				// Layouts Submenu

				$this->add_wp_toolbar_menu_item(
					esc_html__( 'Layouts', 'alpha-core' ),
					'alpha',
					esc_url( admin_url( 'admin.php?page=alpha-layout-builder' ) ),
					array(
						'target' => $target,
					),
					'alpha_layouts'
				);

				$this->add_wp_toolbar_menu_item(
					esc_html__( 'Layout Builder', 'alpha-core' ),
					'alpha_layouts',
					esc_url( admin_url( 'admin.php?page=alpha-layout-builder' ) ),
					array(
						'target' => $target,
					)
				);

				if ( class_exists( 'Alpha_Builders' ) ) {
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'All Templates', 'alpha-core' ),
						'alpha_layouts',
						esc_url( admin_url( 'edit.php?post_type=' . ALPHA_NAME . '_template' ) ),
						array(
							'target' => $target,
						)
					);
				}
				if ( class_exists( 'Alpha_Sidebar_Builder' ) ) {
					$this->add_wp_toolbar_menu_item(
						esc_html__( 'Sidebars', 'alpha-core' ),
						'alpha_layouts',
						esc_url( admin_url( 'admin.php?page=alpha-sidebar' ) ),
						array(
							'target' => $target,
						)
					);
				}

				if ( class_exists( 'Alpha_Builders' ) ) {

					global $alpha_layout;

					if ( ! empty( $alpha_layout['used_blocks'] ) && count( $alpha_layout['used_blocks'] ) ) {

						$used_templates = $alpha_layout['used_blocks'];

						foreach ( $used_templates as $template_id => $data ) {

							$template_type = get_post_meta( $template_id, ALPHA_NAME . '_template_type', true );
							if ( ! $template_type ) {
								$template_type = 'block';
							}

							$template = get_post( $template_id );

							if ( alpha_get_feature( 'fs_pb_elementor' ) && defined( 'ELEMENTOR_VERSION' ) && get_post_meta( $template_id, '_elementor_edit_mode', true ) ) {
								$edit_link = admin_url( 'post.php?post=' . $template_id . '&action=elementor' );
							} else {
								$edit_link = admin_url( 'post.php?post=' . $template_id . '&action=edit' );
							}

							if ( $template ) {
								$this->add_wp_toolbar_menu_item(
									// translators: %s represents template title.
									'<span class="alpha-ab-template-title">' . sprintf( esc_html__( 'Edit %s', 'alpha-core' ), $template->post_title ) . '</span><span class="alpha-ab-template-type">' . sprintf( esc_html__( '%s', 'alpha-core' ), str_replace( '_', ' ', $template_type ) ) . '</span>', //phpcs:ignore
									'edit',
									esc_url( $edit_link ),
									array(
										'target' => $target,
									),
									'edit_' . ALPHA_NAME . '_template_' . $template_id
								);
							}
						}
					}
				}

				/**
				 * Fires after add toolbar menu.
				 *
				 * @since 1.0
				 */
				do_action( 'alpha_add_wp_toolbar_menu', $this );
			}
		}
        
		/**
		 * Add Alpha menu items to WordPress admin menu.
		 *
		 * @param string $title         Title of menu item
		 * @param string $parent        Parent Menu id
		 * @param string $href          Link of menu item
		 * @param array  $custom_meta   Metadata for link
		 * @param string $custom_id     Menu id
		 * @since 1.0
		 */
		public function add_wp_toolbar_menu_item( $title, $parent = false, $href = '', $custom_meta = array(), $custom_id = '' ) {
			global $wp_admin_bar;
			if ( current_user_can( 'edit_theme_options' ) ) {
				if ( ! is_super_admin() || ! is_admin_bar_showing() ) {
					return;
				}
				// Set custom ID
				if ( $custom_id ) {
					$id = $custom_id;
				} else { // Generate ID based on $title
					$id = strtolower( str_replace( ' ', '-', $title ) );
				}
				// links from the current host will open in the current window
				$meta = strpos( $href, home_url() ) !== false ? array() : array( 'target' => '_blank' ); // external links open in new $targetw

				$meta = array_merge( $meta, $custom_meta );
				$wp_admin_bar->add_node(
					array(
						'parent' => $parent,
						'id'     => $id,
						'title'  => $title,
						'href'   => $href,
						'meta'   => $meta,
					)
				);
			}
		}

		/**
		 * Show activation notice.
		 *
		 * @since 1.0
		 */
		public function show_activation_notice() {
			if ( ! $this->is_registered() ) {
				if ( ( 'themes.php' == $GLOBALS['pagenow'] && isset( $_GET['page'] ) ) ||
					empty( $_COOKIE['alpha_dismiss_activate_msg'] ) ||
					version_compare( $_COOKIE['alpha_dismiss_activate_msg'], ALPHA_VERSION, '<' )
				) {
					add_action( 'admin_notices', array( $this, 'activation_notices' ) );
				} elseif ( 'themes.php' == $GLOBALS['pagenow'] ) {
					add_action( 'admin_footer', array( $this, 'activation_message' ) );
				}
			}
		}
        
		/**
		 * Show activation message.
		 *
		 * @since 1.0
		 */
		public function activation_message() {
			?>
			<script>
				(function($){
					$(window).on( 'load', function() {
						<?php /* translators: $1 and $2 are opening and closing anchor tags respectively */ ?>
						$('.themes .theme.active .theme-screenshot').after('<div class="notice update-message notice-error notice-alt"><p><?php printf( esc_html__( 'Please %1$sverify purchase%2$s to get updates!', 'alpha-core' ), '<a href="admin.php?page=alpha" class="button-link">', '</a>' ); ?></p></div>');
					});
				})(window.jQuery);
			</script>
			<?php
		}
        
		/**
		 * Show activation notices.
		 *
		 * @since 1.0
		 */
		public function activation_notices() {
			?>
			<div class="notice error notice-error is-dismissible">
				<?php /* translators: $1, $2 and $3 opening and closing strong tags respectively */ ?>
				<p><?php printf( esc_html__( 'Please %1$sregister%2$s %3$s theme to get access to pre-built demo websites and auto updates.', 'alpha-core' ), '<a href="admin.php?page=alpha">', '</a>', ALPHA_DISPLAY_NAME ); ?></p>
				<?php /* translators: $1 and $2 opening and closing strong tags respectively, and $3 and $4 are opening and closing anchor tags respectively */ ?>
				<p><?php printf( esc_html__( '%1$s Important! %2$s One %3$s standard license %4$s is valid for only %1$s1 website%2$s. Running multiple websites on a single license is a copyright violation.', 'alpha-core' ), '<strong>', '</strong>', '<a target="_blank" href="https://themeforest.net/licenses/standard">', '</a>' ); ?></p>
				<button type="button" class="notice-dismiss alpha-notice-dismiss"><span class="screen-reader-text"><?php esc_html__( 'Dismiss this notice.', 'alpha-core' ); ?></span></button>
			</div>
			<script>
				(function($) {
					var setCookie = function (name, value, exdays) {
						var exdate = new Date();
						exdate.setDate(exdate.getDate() + exdays);
						var val = encodeURIComponent(value) + ((null === exdays) ? "" : "; expires=" + exdate.toUTCString());
						document.cookie = name + "=" + val;
					};
					$(document).on('click.alpha-notice-dismiss', '.alpha-notice-dismiss', function(e) {
						e.preventDefault();
						var $el = $(this).closest('.notice');
						$el.fadeTo( 100, 0, function() {
							$el.slideUp( 100, function() {
								$el.remove();
							});
						});
						setCookie('alpha_dismiss_activate_msg', '<?php echo ALPHA_VERSION; ?>', 30);
					});
				})(window.jQuery);
			</script>
			<?php
		}
	}
}

Alpha_Core_Admin::get_instance();
