/**
 * Alpha Elementor Admin Extend
 * 
 * @package Alpus Core
 * @since 1.0
 */

'use strict';

var themeElementorAdmin = window.themeElementorAdmin || {};

( function ( $ ) {
    themeElementorAdmin.activeSection = null;
    themeElementorAdmin.editedElement = null;

    themeElementorAdmin.init = function () {
        var self = this;

        window.elementor.on( 'preview:loaded', function () {
            elementor.$preview[ 0 ].contentWindow.themeElementorAdmin = themeElementorAdmin;
        } );
    }

    // This is view for the alpha pro widgets
    elementor.hooks.addFilter( "panel/elements/regionViews", function ( panel ) {

        if ( alpha_widget_settings.pro_activated || alpha_widget_settings.pro_widgets.length <= 0 )
            return panel;

        var alphaProWidgetHandle,
            elementsView = panel.elements.view,
            categoriesView = panel.categories.view;

        alphaProWidgetHandle = {
            isProWidget: function () {
                return 0 === this.model.get( "name" ).indexOf( "alpha-" ) && this.$el.hasClass( 'elementor-element--promotion' );
            },

            getElementObj: function ( key ) {

                var widgetObj = alpha_widget_settings.pro_widgets.find( function ( widget, index ) {
                    if ( widget.name == key )
                        return true;
                } );

                return widgetObj;

            },

            onMouseDown: function () {

                void this.constructor.__super__.onMouseDown.call( this );

                if ( !this.isProWidget() ) {
                    return;
                }

                var widgetObject = this.getElementObj( this.model.get( "name" ) );

                elementor.promotion.showDialog( {
                    title: sprintf( wp.i18n.__( '%s', 'alpha-core' ), this.model.get( "title" ) ),
                    content: sprintf( wp.i18n.__( 'Use %s widget and our more pro widgets to extend your toolbox and build sites faster and more attractive.', 'alpha-core' ), this.model.get( "title" ) ),
                    position: {
                      blockStart: '-7'
                    },
                    targetElement: this.el,
                    actionButton: {
                        url: widgetObject.action_url,
                        text: alpha_widget_settings.pro_button,
                        classes: ['elementor-button', 'go-pro', 'alpha-pro-btn']
                    }
                } )
            }
        }

        panel.elements.view = elementsView.extend( {
            childView: elementsView.prototype.childView.extend( alphaProWidgetHandle )
        } );

        panel.categories.view = categoriesView.extend( {
            childView: categoriesView.prototype.childView.extend( {
                childView: categoriesView.prototype.childView.prototype.childView.extend( alphaProWidgetHandle )
            } )
        } );

        return panel;

    } );

    // Add context menu to import block from clipboard block id
    // elementor.hooks.addFilter('elements/context-menu/groups', function( groups, elType ) {
    //     var controlSign = '^';
    //     groups.push({
    //         name: 'pasteStudio',
    //         actions: [{
    //             name: 'pasteStudio',
    //             icon: 'eicon-library-download',
    //             title: function title() {
    //                 return wp.i18n.__('Paste from Alpus studio', 'alpha-core');
    //             },
    //             callback: function callback() {
    //                 var textarea = document.createElement("textarea");
    //                 textarea.contentEditable = true;
    //                 $(textarea).appendTo($('#elementor-panel-elements-search-wrapper'));
    //                 textarea.focus();
    //                 document.execCommand("paste");
    //                 // retrieve the pasted text with textarea.textContent
    //                 // remove textarea from the document
    //                 console.log(textarea.textContent);
    //             },
    //         }]
    //     });
    //     return groups;  
    // } );

    $( window ).on( 'elementor:init', function () {
        themeElementorAdmin.init();
    } );
} )( jQuery );
