<?php
/**
 * Extending elementor partials.
 *
 * @author     AlpusTheme
 * @package    Alpus Core
 * @subpackage Core
 * @since      1.0
 */

defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;

if ( ! class_exists( 'Alpha_Core_Elementor_Extend' ) ) {
	class Alpha_Core_Elementor_Extend extends Alpha_Base {

		/**
		 * The Constructor
		 *
		 * @since 1.0
		 */
		public function __construct() {

			// Add Elementor column extensions
			require_once ALPHA_CORE_INC . '/widgets/half-container/widget-half-container-elementor.php';

			add_action( 'elementor/editor/after_enqueue_styles', array( $this, 'load_admin_styles' ), 20 );

			add_action( 'elementor/editor/after_enqueue_scripts', array( $this, 'enqueue_editor_scripts' ), 20 );

			if ( alpha_is_elementor_preview() ) {
				add_action( 'wp_enqueue_scripts', array( $this, 'load_preview_scripts' ) );
			}

			// Add Pro Widgets (virtual)
			add_filter( 'elementor/editor/localize_settings', array( $this, 'promote_pro_elements' ) );

			// Register New Controls
			add_filter( 'alpha_elementor_register_control', array( $this, 'register_controls' ) );

			// Include Partials
			add_filter( 'alpha_elementor_partials', array( $this, 'add_partials' ) );

			// Extend Widgets

			// Add Elementor widget extend functions
			$widgets = array(
				'image-gallery',
			);
			foreach ( $widgets as $widget ) {
				require_once ALPHA_CORE_INC . '/widgets/' . $widget . '/widget-' . str_replace( '_', '-', $widget ) . '-elementor-extend.php';
			}

			add_filter( 'alpha_elementor_widgets', array( $this, 'add_widgets' ) );

			// Styles
			add_action( 'wp_enqueue_scripts', array( $this, 'register_script' ), 10 );
			add_action( 'wp_enqueue_scripts', array( $this, 'add_elementor_css' ), 35 );

			add_action(
				'alpha_after_core_framework_plugins',
				function() {
					if ( class_exists( 'Alpus_Elementor_Addon_Manager' ) && class_exists( 'Alpha_Core_Elementor' ) ) {
						remove_action( 'elementor/elements/elements_registered', array( Alpha_Core_Elementor::get_instance(), 'register_element' ), 10 );
					}
				}
			);
		}

		public function promote_pro_elements( $config ) {
			if ( class_exists( 'Alpus_Elementor_Addon_Manager' ) && class_exists( 'Alpha_Admin' ) && Alpha_Admin::get_instance()->is_registered() ) {
				return $config;
			}

			$promotion_widgets = array();

			if ( isset( $config['promotionWidgets'] ) ) {
				$promotion_widgets = $config['promotionWidgets'];
			}

			$combine_array = array_merge(
				$promotion_widgets,
				$this->get_pro_elements()
			);

			$config['promotionWidgets'] = $combine_array;

			return $config;
		}

		public function get_pro_elements() {
			return apply_filters(
				'alpha_pro_widgets',
				array(
					array(
						'name'       => 'alpha-360-degree',
						'title'      => esc_html__( '360 Degree View', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-degree',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-animated-text',
						'title'      => esc_html__( 'Animated Text', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-animate',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-bar-chart',
						'title'      => esc_html__( 'Bar Chart', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-bar-chart',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-circle-progressbar',
						'title'      => esc_html__( 'Circle Progressbar', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-counter-circle',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-contact-form',
						'title'      => esc_html__( 'Contact Form', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-form-horizontal',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-countdown',
						'title'      => esc_html__( 'Countdown', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-countdown',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-filter',
						'title'      => esc_html__( 'Advanced Filter', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-filter',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-flipbox',
						'title'      => esc_html__( 'Flipbox', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-flipbox',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-highlight',
						'title'      => esc_html__( 'Highlight', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-highlight',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-hotspot',
						'title'      => esc_html__( 'Hotspot', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-hotspot',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-image-compare',
						'title'      => esc_html__( 'Image Compare', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-imagecomp',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-line-chart',
						'title'      => esc_html__( 'Line Chart', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-line-chart',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-pie-doughnut-chart',
						'title'      => esc_html__( 'Pie Doughnut Chart', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-pie-chart',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-polar-chart',
						'title'      => esc_html__( 'Polar Chart', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-polar-chart',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-price-tables',
						'title'      => esc_html__( 'Price Tables', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-price-table',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-radar-chart',
						'title'      => esc_html__( 'Radar Chart', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-radar-chart',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-scroll-progress',
						'title'      => esc_html__( 'Scroll Progress', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-import-export',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-scroll-button',
						'title'      => esc_html__( 'Scroll Button', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-scroll',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-sticky-nav',
						'title'      => esc_html__( 'Sticky Navigation', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-navigation-horizontal',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-subcategories',
						'title'      => esc_html__( 'Subcategories List', 'alpha-core' ),
						'icon'       => 'aalpha-elementor-widget-icon eicon-table-of-contents',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-svg-floating',
						'title'      => esc_html__( 'Svg Floating', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-floating',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-table',
						'title'      => esc_html__( 'Table', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-table',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-timeline',
						'title'      => esc_html__( 'Timeline - Vertical', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-time-line',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-timeline-horizontal',
						'title'      => esc_html__( 'Timeline - Horizontal', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon eicon-time-line alpha-time-line-horizontal',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
					array(
						'name'       => 'alpha-price-list',
						'title'      => esc_html__( 'Price List', 'alpha-core' ),
						'icon'       => 'alpha-elementor-widget-icon alpha-widget-icon-pricelist',
						'action_url' => ALPHA_GET_PRO_URI,
						'categories' => '["alpha_widget"]',
					),
				)
			);
		}

		public function load_admin_styles() {
			wp_enqueue_style( 'alpha-elementor-admin-extend-style', ALPHA_CORE_INC_URI . '/plugins/elementor/assets/elementor-admin-extend' . ( is_rtl() ? '-rtl' : '' ) . '.min.css' );
		}

		/**
		 * Extend additional controls
		 *
		 * @since 1.0
		 */
		public function register_controls( $controls ) {
			if ( defined( 'ALPHA_PRO_VERSION' ) && class_exists( 'Alpus_Elementor_Addon_Manager' ) ) {
				return $controls;
			}
			$controls[] = 'select';
			return $controls;
		}


		/**
		 * Register Scripts
		 *
		 * @since 1.0
		 */
		public function register_script() {
			wp_register_script( 'easypiechart', ALPHA_CORE_URI . '/assets/js/easypiechart.min.js', array(), ALPHA_CORE_VERSION, true );
		}

		/**
		 * Load extended elementor css
		 *
		 * @since 1.0
		 */
		public function add_elementor_css() {
			wp_enqueue_style( 'alpha-elementor-extend', ALPHA_CORE_INC_URI . '/plugins/elementor/assets/elementor-extend' . ( is_rtl() ? '-rtl' : '' ) . '.min.css' );
		}

		/**
		 * Load Elementor Editor Scripts
		 *
		 * @since 1.0
		 */
		public function enqueue_editor_scripts() {
			wp_enqueue_script( 'alpha-elementor-admin-extend', ALPHA_CORE_INC_URI . '/plugins/elementor/assets/elementor-admin-extend' . ALPHA_JS_SUFFIX, array( 'jquery-core' ), ALPHA_CORE_VERSION, true );

			wp_localize_script(
				'alpha-elementor-admin-extend',
				'alpha_widget_settings',
				array(
					'pro_activated' => class_exists( 'Alpus_Elementor_Addon_Manager' ) && class_exists( 'Alpha_Admin' ) && Alpha_Admin::get_instance()->is_registered(),
					'pro_widgets'   => $this->get_pro_elements(),
					'pro_button'    => ! class_exists( 'Alpus_Elementor_Addon_Manager' ) ? esc_html__( 'Get Alpus Elementor Addon', 'alpha-core' ) : esc_html__( 'Activate Now', 'alpha-core' ),
					'purchase_pro'  => ALPHA_GET_PRO_URI,
				)
			);
		}

		public function load_preview_scripts() {
			// load needed style & script file in elementor preview
			wp_enqueue_style( 'alpha-elementor-preview-extend', ALPHA_CORE_INC_URI . '/plugins/elementor/assets/elementor-preview-extend' . ( is_rtl() ? '-rtl' : '' ) . '.min.css' );
			wp_enqueue_script( 'alpha-elementor-extend', ALPHA_CORE_INC_URI . '/plugins/elementor/assets/elementor-extend' . ALPHA_JS_SUFFIX, array( 'jquery-core' ), ALPHA_CORE_VERSION, true );
		}

		public function add_partials( $partials ) {
			$partials            = array_merge(
				array(
					'button-extend' => true,
					'slider-extend' => true,
					'tab-extend'    => true,
				),
				$partials
			);
			$partials['hotspot'] = false;
			$partials['chart']   = false;

			if ( class_exists( 'Alpus_Elementor_Addon_Manager' ) ) {
				$partials['banner'] = false;
			}

			return $partials;
		}

		/**
		 * Extend elementor widgets
		 *
		 * @since 1.0
		 */
		public function add_widgets( $widgets ) {
			$extended_widgets = array(
				'counters' => true,
				'icon-box' => true,
				'vendor'   => false,
			);

			$extended_widgets = array_merge(
				$extended_widgets,
				array(
					'360-degree'          => false, // Pro widgets
					'animated-text'       => false,
					'bar-chart'           => false,
					'circle-progressbar'  => false,
					'contact-form'        => false,
					'countdown'           => false,
					'filter'              => false,
					'flipbox'             => false,
					'highlight'           => false,
					'hotspot'             => false,
					'image-compare'       => false,
					'line-chart'          => false,
					'pie-doughnut-chart'  => false,
					'polar-chart'         => false,
					'price-tables'        => false,
					'radar-chart'         => false,
					'scroll-progress'     => false,
					'sticky-nav'          => false,
					'subcategories'       => false,
					'svg-floating'        => false,
					'table'               => false,
					'timeline'            => false,
					'timeline-horizontal' => false,
				)
			);

			if ( defined( 'ALPUS_PRODUCT_BRAND_VERSION' ) ) {
				$extended_widgets = array_merge(
					$extended_widgets,
					array(
						'brands' => true,
					)
				);
			}

			if ( class_exists( 'Alpus_Elementor_Addon_Manager' ) ) {
				$extended_widgets = array_merge(
					$extended_widgets,
					array(
						'banner' => false,
					)
				);
			}

			$extended_widgets = array_merge( $widgets, $extended_widgets );

			return $extended_widgets;
		}

		/**
		** Upgrade to Pro Notice
		*/
		public static function upgrade_pro_notice( $module, $controls_manager, $widget, $option, $condition = array() ) {
			if ( defined( 'ALPHA_PRO_VERSION' ) || ! alpha_is_elementor_preview() ) {
				return;
			}

			$module->add_control(
				$option . '_pro_notice',
				array(
					'raw'             => sprintf( esc_html__( 'This option is available%1$s in the %2$sAlpus Pro%3$s', 'alpha-core' ), '<br>', '<strong><a href="' . ALPHA_GET_PRO_URI . '" target="_blank">', '</a></strong>' ),
					'type'            => $controls_manager,
					'content_classes' => 'alpha-pro-notice',
					'condition'       => $condition,
				)
			);
		}

		/**
		** Upgrade to Elementor Addon Notice
		*/
		public static function purchase_elementor_addon_notice( $module, $controls_manager, $widget, $option, $condition = array() ) {
			if ( class_exists( 'Alpus_Elementor_Addon_Manager' ) || ! alpha_is_elementor_preview() ) {
				return;
			}

			$module->add_control(
				$option . '_pro_notice',
				array(
					'raw'             => sprintf( esc_html__( 'This option is available%1$s in the %2$s Elementor Addon%3$s', 'alpha-core' ), '<br>', '<strong><a href="' . ALPHA_GET_PRO_URI . '" target="_blank">' . ALPHA_DISPLAY_NAME, '</a></strong>' ),
					'type'            => $controls_manager,
					'content_classes' => 'alpha-pro-notice',
					'condition'       => $condition,
				)
			);
		}
	}
}

Alpha_Core_Elementor_Extend::get_instance();
