<?php
/**
 * Tab Partial Extend
 *
 * @author     AlpusTheme
 * @package    Alpus Core
 * @subpackage Core
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Alpha_Controls_Manager;

/**
 * Register elementor tab style controls
 */
if ( ! function_exists( 'alpha_elementor_tab_style_controls' ) ) {
	function alpha_elementor_tab_style_controls( $self, $condition_key = '' ) {
		$left  = is_rtl() ? 'right' : 'left';
		$right = 'left' == $left ? 'right' : 'left';

		$self->start_controls_section(
			'tab_style',
			array_merge(
				array(
					'label' => alpha_elementor_panel_heading( esc_html__( 'Tab', 'alpha-core' ) ),
					'tab'   => Controls_Manager::TAB_STYLE,
				),
				$condition_key ? array(
					'condition' => array(
						$condition_key => 'tab',
					),
				) : array()
			)
		);

		$self->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'tab_nav_typography',
				'label'    => esc_html__( 'Nav Typography', 'alpha-core' ),
				'selector' => '.elementor-element-{{ID}} .nav .nav-link',
			)
		);

		$self->add_responsive_control(
			'tab_nav_space',
			array(
				'label'       => esc_html__( 'Nav Space', 'alpha-core' ),
				'description' => esc_html__( 'Set the space between tab titles.', 'alpha-core' ),
				'type'        => Controls_Manager::SLIDER,
				'size_units'  => array( 'px', 'rem', 'em' ),
				'range'       => array(
					'px' => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
				),
				'selectors'   => array(
					'{{WRAPPER}} .tab' => '--alpha-tab-item-spacing: {{SIZE}}{{UNIT}}',
				),
			)
		);

		$self->add_control(
			'tab_nav_border_radius',
			array(
				'label'       => esc_html__( 'Nav Border Radius', 'alpha-core' ),
				'description' => esc_html__( 'Set the border radius of tab titles.', 'alpha-core' ),
				'type'        => Controls_Manager::SLIDER,
				'size_units'  => array( 'px', '%' ),
				'range'       => array(
					'px' => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-title-radius: {{SIZE}}{{UNIT}}',
				),
			)
		);

		$self->add_control(
			'tab_nav_border_width',
			array(
				'label'       => esc_html__( 'Title Border Width', 'alpha-core' ),
				'description' => esc_html__( 'Set the underline(overline) width of tab titles.', 'alpha-core' ),
				'type'        => Controls_Manager::SLIDER,
				'size_units'  => array( 'px', 'rem', 'em' ),
				'range'       => array(
					'px'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 10,
					),
					'rem' => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 1,
					),
					'em'  => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 1,
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-nav-border-width: {{SIZE}}{{UNIT}}',
				),
				'condition'   => array(
					'tab_type' => array( 'underline', 'border' ),
				),
			)
		);

		$self->add_control(
			'tab_border_width',
			array(
				'label'       => esc_html__( 'Tab Border Width', 'alpha-core' ),
				'description' => esc_html__( 'Set the border width of tab.', 'alpha-core' ),
				'type'        => Controls_Manager::SLIDER,
				'size_units'  => array( 'px', 'rem', 'em' ),
				'range'       => array(
					'px'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 10,
					),
					'rem' => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 1,
					),
					'em'  => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 1,
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-border-width: {{SIZE}}{{UNIT}}',
				),
				'condition'   => array(
					'tab_type' => array( 'underline', 'border' ),
				),
			)
		);

		$self->add_control(
			'tab_solid_border_width',
			array(
				'label'       => esc_html__( 'Nav Border Width', 'alpha-core' ),
				'description' => esc_html__( 'Set the border width of nav.', 'alpha-core' ),
				'type'        => Controls_Manager::SLIDER,
				'size_units'  => array( 'px', 'rem', 'em' ),
				'range'       => array(
					'px'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 10,
					),
					'rem' => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 1,
					),
					'em'  => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 1,
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab-solid .nav-link' => '--alpha-tab-nav-border-width: {{SIZE}}{{UNIT}}',
				),
				'condition'   => array(
					'tab_type' => array( 'solid' ),
				),
			)
		);

		$self->add_responsive_control(
			'tab_nav_padding',
			array(
				'label'       => esc_html__( 'Nav Padding', 'alpha-core' ),
				'description' => esc_html__( 'Set the padding value of tab titles.', 'alpha-core' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => array(
					'px',
					'%',
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-title-padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);

		$self->add_control(
			'tab_border_color',
			array(
				'label'       => esc_html__( 'Border Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the border color skin of tab.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-border-color: {{VALUE}};',
				),
			)
		);

		$self->start_controls_tabs( 'icon_bg_color' );

		$self->start_controls_tab(
			'tab_color_normal',
			array(
				'label' => esc_html__( 'Normal', 'alpha-core' ),
			)
		);

		$self->add_control(
			'tab_color',
			array(
				'label'       => esc_html__( 'Nav Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the normal color skin of tab titles.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .nav-link' => 'color: {{VALUE}};',
					'.elementor-element-{{ID}} .nav-link svg' => 'fill: {{VALUE}};',
				),
			)
		);

		$self->add_control(
			'tab_bg_color',
			array(
				'label'       => esc_html__( 'Nav Background Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the background color of tab.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-background: {{VALUE}};',
				),
			)
		);

		$self->end_controls_tab();

		$self->start_controls_tab(
			'tab_color_active',
			array(
				'label' => esc_html__( 'Active', 'alpha-core' ),
			)
		);

		$self->add_control(
			'tab_active_color',
			array(
				'label'       => esc_html__( 'Nav Active Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the active color skin of tab titles.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-active-color: {{VALUE}};',
				),
			)
		);

		$self->add_control(
			'tab_active_bg_color',
			array(
				'label'       => esc_html__( 'Nav Active Background Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the active background color of tab.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-active-background: {{VALUE}};',
				),
			)
		);

		$self->end_controls_tab();

		$self->end_controls_tabs();

		$self->add_responsive_control(
			'tab_icon_padding',
			array(
				'label'       => esc_html__( 'Icon Padding', 'alpha-core' ),
				'description' => esc_html__( 'Set the padding value of tab title icons.', 'alpha-core' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => array(
					'px',
					'%',
				),
				'separator'   => 'before',
				'selectors'   => array(
					'.elementor-element-{{ID}} .nav .nav-link' => '--alpha-tab-icon-padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);

		$self->add_responsive_control(
			'tab_icon_border_radius',
			array(
				'label'       => esc_html__( 'Icon Border Radius', 'alpha-core' ),
				'description' => esc_html__( 'Set the border radius value of tab title icons.', 'alpha-core' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => array(
					'px',
					'%',
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .nav-link i, .elementor-element-{{ID}} .nav-link svg' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);

		$self->start_controls_tabs( 'tabs_icon_bg_color' );

		$self->start_controls_tab(
			'tab_icon_color_normal',
			array(
				'label' => esc_html__( 'Normal', 'alpha-core' ),
			)
		);

		$self->add_control(
			'tab_icon_color',
			array(
				'label'       => esc_html__( 'Icon Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the normal color of tab title icons.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .nav-link i'   => 'color: {{VALUE}};',
					'.elementor-element-{{ID}} .nav-link svg' => 'fill: {{VALUE}};',
				),
			)
		);

		$self->add_control(
			'tab_icon_bg_color',
			array(
				'label'       => esc_html__( 'Icon Background Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the background color of tab icons.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .nav .nav-link' => '--alpha-tab-icon-background: {{VALUE}};',
				),
			)
		);

		$self->end_controls_tab();

		$self->start_controls_tab(
			'tab_icon_color_active',
			array(
				'label' => esc_html__( 'Active', 'alpha-core' ),
			)
		);

		$self->add_control(
			'tab_icon_active_color',
			array(
				'label'       => esc_html__( 'Nav Active Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the active color of tab title icons.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .nav-link' => '--alpha-tab-icon-active-color: {{VALUE}};',
				),
			)
		);

		$self->add_control(
			'tab_icon_active_bg_color',
			array(
				'label'       => esc_html__( 'Nav Active Background Color', 'alpha-core' ),
				'description' => esc_html__( 'Set the active background color of tab icons.', 'alpha-core' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .nav-link' => '--alpha-tab-icon-active-background: {{VALUE}};',
				),
			)
		);

		$self->end_controls_tab();

		$self->end_controls_tabs();

		$self->add_responsive_control(
			'tab_content_padding',
			array(
				'label'       => esc_html__( 'Content Padding', 'alpha-core' ),
				'description' => esc_html__( 'Set the padding value of tab content.', 'alpha-core' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => array(
					'px',
					'%',
				),
				'separator'   => 'before',
				'selectors'   => array(
					'.elementor-element-{{ID}} .tab' => '--alpha-tab-content-padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);

		$self->end_controls_section();
	}
}
