/**
 * Elementor Admin
 * 
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0
 */
jQuery( document ).ready( function ( $ ) {
    'use strict';

    var themeAddonElementorAdmin = {
        init: function () {
            this.addStudioButtons();
            this.repeaterPopup();

            // elementor.hooks.addFilter( 'panel/elements/regionViews', function ( panel ) {
            //     var categories = panel.categories.options.collection;
            //     var categoryIndex = categories.findIndex( {
            //         name: "basic"
            //     } );

            //     categoryIndex && categories.add( {
            //         name: "alpha-notice",
            //         title: alpha_studio.texts.theme_display_name + wp.i18n.__( ' Library', 'alpha-addon-elementor' ),
            //         defaultActive: 1,
            //         items: []
            //     }, {
            //         at: categoryIndex - 1
            //     } );
            //     return panel;
            // } );

            if ( typeof Marionette != 'undefined' && Marionette.ItemView && Marionette.Behavior ) {
                class alphaStudioItem extends Marionette.ItemView {
                    className() {
                        return 'elementor-panel-category-items-alpha-notice';
                    }
                    getTemplate() {
                        return '#tmpl-alpha-elementor-studio-notice';
                    }
                }

                class alphaStudioHandle extends Marionette.Behavior {
                    initialize() {
                        if ( 'alpha-notice' == this.view.options.model.get( 'name' ) ) {
                            this.view.emptyView = alphaStudioItem;
                        }
                    }
                }
                elementor.hooks.addFilter( 'panel/category/behaviors', function ( behaviors ) {
                    return Object.assign( {}, behaviors, {
                        studioNotice: {
                            behaviorClass: alphaStudioHandle
                        }
                    } );
                } );
            }

            elementor.on( 'panel:init', function () {
                elementor.channels.editor.on( 'section:activated', themeAddonElementorAdmin.initFlipboxWidget );
            } );

            if ( typeof $e != 'undefined' ) {
                $e.commands.on( 'run:before', function ( component, command, args ) {
                    if ( 'document/elements/delete' == command && args && args.containers && args.containers.length ) {
                        args.containers.forEach( function ( cnt ) {
                            elementorFrontend.hooks.doAction( 'alpha_elementor_element_before_delete', cnt.model );
                        } );
                    }
                } );
                $e.commands.on( 'run:after', function ( component, command, args ) {
                    if ( 'document/elements/create' == command && args && args.model && args.model.id ) {
                        elementorFrontend.hooks.doAction( 'alpha_elementor_element_after_add', args.model );
                    }
                } );
            }
        },
        /**
         * Elementor Repeater Popup
         * 
         * @since 1.0
         */
        repeaterPopup: function () {
            $( document.body ).on( 'mouseup', '.elementor-repeater-row-item-title', function () {
                var $this = $( this );
                var $thisControls = $this.parent().siblings( '.elementor-repeater-row-controls' );
                $thisControls.removeClass( 'editable-effect' );
                if ( window.innerHeight > $this.offset().top + 546 ) {
                    $thisControls.css( { 'top': $this.offset().top + 'px', bottom: '' } );
                } else {
                    $thisControls.css( { 'bottom': '46px', 'top': '' } );
                }
                if ( $this.closest( '.elementor-repeater-fields-wrapper' ).find( '.editable' ).length == 0 ) {
                    $thisControls.addClass( 'editable-effect' );
                }
            } ).on( 'click', function ( e ) {
                if ( $( e.target ).closest( '.elementor-repeater-fields' ).length == 0 && $( e.target ).closest( '.pcr-app' ).length == 0 && !$( e.target ).hasClass( 'select2-search__field' ) ) {
                    $( '.elementor-repeater-row-controls.editable' ).removeClass( 'editable editable-effect' );
                }
            } );
        },
        addStudioButtons: function () {
            // Add Studio Block Button
            var addSectionTmpl = document.getElementById( 'tmpl-elementor-add-section' );
            if ( addSectionTmpl ) {
                addSectionTmpl.textContent = addSectionTmpl.textContent.replace(
                    '<div class="elementor-add-section-area-button elementor-add-template-button',
                    '<div class="elementor-add-section-area-button elementor-studio-section-button" ' +
                    'onclick="window.parent.runStudio(this);" ' +
                    'title="Alpus Studio"><i class="alpha-mini-logo"></i><i class="eicon-insert"></i></div>\r\n' +
                    '<div class="elementor-add-section-area-button elementor-add-template-button' );
            }
        },
        initFlipboxWidget: function ( sectionName, editor ) {
            var editedElement = editor.getOption( 'editedElementView' );

            if ( alpha_elementor_admin_vars.theme + '_widget_flipbox' !== editedElement.model.get( 'widgetType' ) ) {
                return;
            }

            var isSideBSection = -1 !== [ 'section_back_side_content', 'section_flipbox_back_style' ].indexOf( sectionName );
            editedElement.$el.toggleClass( 'flipped', isSideBSection );
            var $backLayer = editedElement.$el.find( '.flipbox_back' );

            if ( isSideBSection ) {
                $backLayer.css( 'transition', 'none' );
            }

            if ( !isSideBSection ) {
                setTimeout( function () {
                    $backLayer.css( 'transition', '' );
                }, 10 );
            }
        },
    }

    // Setup Elementor Admin
    elementor.on( 'frontend:init', themeAddonElementorAdmin.init.bind( themeAddonElementorAdmin ) );
} );