<?php
/**
 * Alpus Addon Elementor
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0
 * @version    1.0
 */

defined( 'ABSPATH' ) || die;

use Elementor\Plugin;

class Alpus_Elementor_Addon extends Alpus_Base {

	/**
	 * Check if dom is optimized
	 *
	 * @since 1.0
	 *
	 * @var boolean $is_dom_optimized
	 */
	public static $is_dom_optimized = false;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	public function __construct() {

		// Include Partials
		$partials = apply_filters(
			'alpha_elementor_addon_partials',
			array(
				'hotspot' => true,
				'banner'  => true,
				'button'  => true,
				'chart'   => true,
				'grid'    => true,
			)
		);
		foreach ( $partials as $partial => $active ) {
			if ( $active ) {
				include_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/partials/' . $partial . '.php';
			}
		}

		include_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/conditional-rendering/class-alpha-conditional-rendering.php';

		// Add parallax addon controls
		require_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/tabs/parallax/class-alpha-parallax-elementor.php';

		// Register controls, widgets, elements, icons
		add_action( 'elementor/elements/categories_registered', array( $this, 'register_category' ) );
		add_action( 'elementor/controls/register', array( $this, 'register_control' ) );
		add_action( 'elementor/widgets/register', array( $this, 'register_widget' ) );
		add_action( 'elementor/elements/elements_registered', array( $this, 'register_element' ) );

		// Load Elementor CSS and JS
		if ( ! defined( 'ALPHA_CORE_VERSION' ) ) {
			if ( alpha_is_elementor_preview() ) {
				add_action( 'wp_enqueue_scripts', array( $this, 'load_preview_scripts' ) );
			}

			add_action( 'elementor/editor/after_enqueue_styles', array( $this, 'load_admin_styles' ) );
			add_action( 'elementor/frontend/after_register_styles', array( $this, 'remove_fontawesome' ), 11 );

			// Include Elementor Admin JS
			add_action(
				'elementor/editor/after_enqueue_scripts',
				function() {
					wp_enqueue_script( 'alpus-elementor-addon-admin', ALPUS_ELEMENTOR_ADDON_URI . '/assets/js/editor' . ALPUS_PLUGIN_JS_SUFFIX, array( 'elementor-editor' ), ALPUS_ELEMENTOR_ADDON_VERSION, true );
				}
			);

			add_action( 'admin_print_footer_scripts', array( $this, 'print_footer_scripts' ), 30 );
		}

		// Force Loading Elementor Preloaded Modules js because of section video.
		add_action(
			'wp_footer',
			function() {
				if ( class_exists( 'Alpha_Optimize_Stylesheets' ) ) {
					$cur_page_id  = (int) Alpha_Optimize_Stylesheets::get_instance()->get_current_page_id();
					$the_document = Plugin::$instance->documents->get( $cur_page_id );
					if ( $the_document && $the_document->is_built_with_elementor() ) {
						wp_enqueue_script( 'preloaded-modules', ELEMENTOR_URL . 'assets/js/preloaded-modules' . ALPUS_PLUGIN_JS_SUFFIX, array( 'elementor-frontend' ), ELEMENTOR_VERSION, true );
					}
				}
			}
		);

		// Remove ui theme control: dark/light mode
		add_action( 'elementor/element/editor-preferences/preferences/after_section_end', array( $this, 'remove_dark_mode' ) );

		// Compatabilities
		add_filter( 'elementor/widgets/wordpress/widget_args', array( $this, 'add_wp_widget_args' ), 10, 2 );

		// Load Used Block CSS
		/*
		 * Get Dependent Elementor Styles
		 * Includes Kit style and post style
		 */
		add_action( 'elementor/css-file/post/enqueue', array( $this, 'get_dependent_elementor_styles' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'add_elementor_css' ), 30 );

		// Elementor Custom Control Manager
		if ( ! defined( 'ALPHA_CORE_VERSION' ) ) {
			require_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/restapi/select2.php';
		}
		require_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/controls_manager/controls.php';

	}

	/**
	 * Remove Dark Mode
	 *
	 * @since 1.0
	 */
	public function remove_dark_mode( $args ) {
		$args->remove_control( 'ui_theme' );
	}

	// Register new Category
	public function register_category( $self ) {
		$self->add_category(
			'alpha_addon_widget',
			array(
				'title'  => ALPHA_DISPLAY_NAME . esc_html__( ' Addon Widgets', 'alpus-elementor-addon' ),
				'active' => true,
			)
		);
	}

	// Register new Control
	public function register_control( $self ) {

		$controls = array(
			'ajaxselect2',
			'description',
			'image_choose',
			'origin_position',
		);

		foreach ( $controls as $control ) {
			include_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/controls/' . $control . '.php';
			$class_name = 'Alpha_Control_' . ucfirst( $control );
			$self->register_control( $control, new $class_name() );
		}
	}

	// Register new Widget
	public function register_widget( $self ) {
		/* Remove elementor default common widget and register ours */
		include_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/tabs/widget-advanced-tabs.php';

		if ( ! defined( 'ALPHA_NAME' ) && ! class_exists( 'Alpha_Common_Elementor_Widget' ) ) {
			$self->unregister( 'common' );
			include_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/elements/widget-common.php';
			$self->register( new Alpha_Common_Elementor_Widget( array(), array( 'widget_name' => 'common' ) ) );
		}

		$widgets = array(
			'360-degree'          => true,
			'filter'              => true,
			'animated-text'       => true,
			'banner'              => true,
			'bar-chart'           => true,
			'circle-progressbar'  => true,
			'contact-form'        => true,
			'countdown'           => true,
			'flipbox'             => true,
			'highlight'           => true,
			'hotspot'             => true,
			'image-compare'       => true,
			'line-chart'          => true,
			'pie-doughnut-chart'  => true,
			'polar-chart'         => true,
			'price-list'          => true,
			'price-tables'        => true,
			'radar-chart'         => true,
			'scroll-button'       => true,
			'scroll-progress'     => true,
			'sticky-nav'          => true,
			'subcategories'       => true,
			'svg-floating'        => true,
			'table'               => true,
			'timeline'            => true,
			'timeline-horizontal' => true,
		);

		/**
		 * Filters the widgets which provide by elementor.
		 *
		 * @since 1.0
		 */
		array_multisort( array_keys( $widgets ), SORT_ASC, $widgets );

		foreach ( $widgets as $widget => $usable ) {
			if ( $usable ) {
				require_once  ALPUS_ELEMENTOR_ADDON_PATH . '/inc/widgets/' . $widget . '/widget-' . str_replace( '_', '-', $widget ) . '-elementor.php';
				$class_name = 'Alpha_' . ucwords( str_replace( '-', '_', $widget ), '_' ) . '_Elementor_Widget';
				$self->register( new $class_name( array(), array( 'widget_name' => $class_name ) ) );
			}
		}
	}

	public function register_element() {
		// Elementor Custom Advanced Tab Sections
		include_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/tabs/widget-advanced-tabs.php';

		include_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/elements/section.php';
		Elementor\Plugin::$instance->elements_manager->unregister_element_type( 'section' );
		Elementor\Plugin::$instance->elements_manager->register_element_type( new Alpha_Element_Section() );

		include_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/elements/column.php';
		Elementor\Plugin::$instance->elements_manager->unregister_element_type( 'column' );
		Elementor\Plugin::$instance->elements_manager->register_element_type( new Alpha_Element_Column() );
	}

	public function load_preview_scripts() {
		// load needed style file in elementor preview
		wp_enqueue_style( 'alpus-elementor-addon-preview', ALPUS_ELEMENTOR_ADDON_CSS . '/preview' . ( is_rtl() ? '-rtl' : '' ) . '.min.css' );
		wp_enqueue_script( 'alpus-elementor-addon-preview', ALPUS_ELEMENTOR_ADDON_JS . '/preview' . ALPUS_PLUGIN_JS_SUFFIX, array(), ALPUS_ELEMENTOR_ADDON_VERSION, true );
		wp_localize_script(
			'alpus-elementor-addon-preview',
			'alpha_elementor_preview_vars',
			array(
				'theme'    => ALPHA_NAME,
				'ajax_url' => esc_js( admin_url( 'admin-ajax.php' ) ),
				'wpnonce'  => wp_create_nonce( 'alpha-elementor-nonce' ),
			)
		);
	}

	public function load_admin_styles() {
		wp_enqueue_style( 'fontawesome-free', ALPUS_ELEMENTOR_ADDON_URI . '/assets/vendor/fontawesome-free/css/all.min.css', array(), '5.14.0' );
		wp_enqueue_style( 'alpus-elementor-addon-admin', ALPUS_ELEMENTOR_ADDON_CSS . '/editor' . ( is_rtl() ? '-rtl' : '' ) . '.min.css' );
		wp_dequeue_style( 'elementor-editor-dark-mode' ); // Disable Dark mode
	}


	public function remove_fontawesome() {
		wp_deregister_style( 'elementor-icons-shared-0' );
		wp_deregister_style( 'elementor-icons-fa-regular' );
		wp_deregister_style( 'elementor-icons-fa-solid' );
		wp_deregister_style( 'elementor-icons-fa-brands' );
	}

	public function print_footer_scripts() {
		echo '<script id="alpus-elementor-addon-admin-js-extra">';
		echo 'var alpha_elementor_admin_vars = ' . json_encode(
			apply_filters(
				'alpha_elementor_addon_admin_localize_vars',
				array(
					'ajax_url' => esc_url( admin_url( 'admin-ajax.php' ) ),
					'theme'    => ALPHA_NAME,
				)
			)
		) . ';';
		echo '</script>';
	}

	public function add_wp_widget_args( $args, $self ) {
		$args['before_widget'] = '<div class="widget ' . $self->get_widget_instance()->widget_options['classname'] . ' widget-collapsible">';
		$args['after_widget']  = '</div>';
		$args['before_title']  = '<h3 class="widget-title">';
		$args['after_title']   = '</h3>';

		return $args;
	}

	public function get_dependent_elementor_styles( $self ) {
		if ( 'file' == $self->get_meta()['status'] ) { // Re-check if it's not empty after CSS update.
			preg_match( '/post-(\d+).css/', $self->get_url(), $id );
			if ( count( $id ) == 2 ) {
				global $e_post_ids;

				wp_dequeue_style( 'elementor-post-' . $id[1] );

				wp_register_style( 'elementor-post-' . $id[1], $self->get_url(), array( 'elementor-frontend' ), null ); // phpcs:ignore WordPress.WP.EnqueuedResourceParameters.MissingVersion

				if ( ! isset( $e_post_ids ) ) {
					$e_post_ids = array();
				}
				$e_post_ids[] = $id[1];
			}
		}
	}

	public function add_elementor_css() {
		// Add Alpha elementor style
		if ( ! defined( 'ALPHA_CORE_VERSION' ) ) {
			wp_register_style( 'alpus-elementor-addon-button', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/button/button' . ( is_rtl() ? '-rtl' : '' ) . '.min.css', array() );
			wp_register_script( 'jquery-skrollr', ALPUS_ELEMENTOR_ADDON_JS . '/skrollr.min.js', array(), '0.6.30', true );
			wp_enqueue_style( 'alpus-elementor-addon', ALPUS_ELEMENTOR_ADDON_CSS . '/frontend' . ( is_rtl() ? '-rtl' : '' ) . '.min.css', array( 'elementor-frontend' ) );
		}
		wp_enqueue_script( 'alpus-elementor-addon', ALPUS_ELEMENTOR_ADDON_JS . '/addon' . ALPUS_PLUGIN_JS_SUFFIX, array( 'jquery-core' ), ALPUS_ELEMENTOR_ADDON_VERSION, true );
		wp_localize_script(
			'alpus-elementor-addon',
			'alpus_elementor_vars',
			array(
				'theme'     => ALPHA_NAME,
				'countdown' => array(
					'labels'       => array(
						esc_html__( 'Years', 'alpus-elementor-addon' ),
						esc_html__( 'Months', 'alpus-elementor-addon' ),
						esc_html__( 'Weeks', 'alpus-elementor-addon' ),
						esc_html__( 'Days', 'alpus-elementor-addon' ),
						esc_html__( 'Hours', 'alpus-elementor-addon' ),
						esc_html__( 'Minutes', 'alpus-elementor-addon' ),
						esc_html__( 'Seconds', 'alpus-elementor-addon' ),
					),
					'labels_short' => array(
						esc_html__( 'Years', 'alpus-elementor-addon' ),
						esc_html__( 'Months', 'alpus-elementor-addon' ),
						esc_html__( 'Weeks', 'alpus-elementor-addon' ),
						esc_html__( 'Days', 'alpus-elementor-addon' ),
						esc_html__( 'Hrs', 'alpus-elementor-addon' ),
						esc_html__( 'Mins', 'alpus-elementor-addon' ),
						esc_html__( 'Secs', 'alpus-elementor-addon' ),
					),
					'label1'       => array(
						esc_html__( 'Year', 'alpus-elementor-addon' ),
						esc_html__( 'Month', 'alpus-elementor-addon' ),
						esc_html__( 'Week', 'alpus-elementor-addon' ),
						esc_html__( 'Day', 'alpus-elementor-addon' ),
						esc_html__( 'Hour', 'alpus-elementor-addon' ),
						esc_html__( 'Minute', 'alpus-elementor-addon' ),
						esc_html__( 'Second', 'alpus-elementor-addon' ),
					),
					'label1_short' => array(
						esc_html__( 'Year', 'alpus-elementor-addon' ),
						esc_html__( 'Month', 'alpus-elementor-addon' ),
						esc_html__( 'Week', 'alpus-elementor-addon' ),
						esc_html__( 'Day', 'alpus-elementor-addon' ),
						esc_html__( 'Hour', 'alpus-elementor-addon' ),
						esc_html__( 'Min', 'alpus-elementor-addon' ),
						esc_html__( 'Sec', 'alpus-elementor-addon' ),
					),
				),
			)
		);
	}
}

/**
 * Create instance
 *
 * @since 1.0
 */
Alpus_Elementor_Addon::get_instance();

if ( ! function_exists( 'alpha_elementor_if_dom_optimization' ) ) :
	function alpha_elementor_if_dom_optimization() {
		if ( ! defined( 'ELEMENTOR_VERSION' ) ) {
			return false;
		}
		if ( version_compare( ELEMENTOR_VERSION, '3.1.0', '>=' ) ) {
			return \Elementor\Plugin::$instance->experiments->is_feature_active( 'e_dom_optimization' );
		} elseif ( version_compare( ELEMENTOR_VERSION, '3.0', '>=' ) ) {
			return ( ! \Elementor\Plugin::instance()->get_legacy_mode( 'elementWrappers' ) );
		}
		return false;
	}
endif;
