<?php
/**
 * Chart Partial
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;

/**
 * Register chart font options.
 *
 * @since 1.0
 */

if ( ! function_exists( 'alpha_elementor_chart_font_options' ) ) {
	function alpha_elementor_chart_font_options( $self, $prefix = 'legend', $condition_key = 'show_legend', $condition_value = 'true' ) {

		$self->start_controls_section(
			'section_chart_' . $prefix . '_stylel',
			array(
				'label'     => esc_html__( sprintf( '%s', ucfirst( $prefix ) ), 'alpus-elementor-addon' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => array(
					$condition_key => $condition_value,
				),
			)
		);
			$self->add_control(
				$prefix . '_font_family',
				array(
					'label'       => esc_html__( 'Font Family', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::FONT,
					'description' => esc_html__( 'Choose your favorite font.', 'alpus-elementor-addon' ),
					'default'     => '',
				)
			);
			$self->add_control(
				$prefix . '_font_size',
				array(
					'label'       => esc_html__( 'Font Size', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Set font size.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::NUMBER,
				)
			);

			$typo_weight_options = array(
				'' => esc_html__( 'Default', 'alpus-elementor-addon' ),
			);

		foreach ( array_merge( array( 'normal', 'bold' ), range( 100, 900, 100 ) ) as $weight ) {
			$typo_weight_options[ $weight ] = ucfirst( $weight );
		}

			$self->add_control(
				$prefix . '_font_weight',
				array(
					'label'       => esc_html__( 'Font Weight', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SELECT,
					'description' => esc_html__( 'Set the font weight.', 'alpus-elementor-addon' ),
					'default'     => '',
					'options'     => $typo_weight_options,
				)
			);
			$self->add_control(
				$prefix . '_font_style',
				array(
					'label'       => esc_html__( 'Font Style', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SELECT,
					'description' => esc_html__( 'Set the font style.', 'alpus-elementor-addon' ),
					'default'     => '',
					'options'     => array(
						''        => esc_html__( 'Default', 'alpus-elementor-addon' ),
						'normal'  => esc_attr_x( 'Normal', 'Typography Control', 'alpus-elementor-addon' ),
						'italic'  => esc_attr_x( 'Italic', 'Typography Control', 'alpus-elementor-addon' ),
						'oblique' => esc_attr_x( 'Oblique', 'Typography Control', 'alpus-elementor-addon' ),
					),
				)
			);
			$self->add_control(
				$prefix . '_font_color',
				array(
					'label'       => esc_html__( 'Font Color', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Set the color.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::COLOR,
				)
			);
		$self->end_controls_section();
	}
}

/**
 * Register chart settings controls
 *
 * @since 1.0
 */

if ( ! function_exists( 'alpha_elementor_chart_settings' ) ) {
	function alpha_elementor_chart_settings( $self, $type = '' ) {
		$self->start_controls_section(
			'section_settings',
			array(
				'label' => esc_html__( 'Chart Controls', 'alpus-elementor-addon' ),
			)
		);

		if ( 'bar-chart' == $type ) {
			$self->add_control(
				'show_grid',
				array(
					'label'        => esc_html__( 'Show Grid Line', 'alpus-elementor-addon' ),
					'description'  => esc_html__( 'Determines whether grid(guide) lines are shown or not.', 'alpus-elementor-addon' ),
					'type'         => Controls_Manager::SWITCHER,
					'default'      => 'true',
					'return_value' => 'true',
				)
			);

			$self->add_control(
				'data_value_range',
				array(
					'label'       => esc_html__( 'Axis Range', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::NUMBER,
					'default'     => 10,
					'description' => esc_html__( 'Set maximum value of range that can be set for the data value', 'alpus-elementor-addon' ),
					'condition'   => array(
						'show_grid' => 'true',
					),
				)
			);

			$self->add_control(
				'data_value_step',
				array(
					'label'       => esc_html__( 'Axis Unit', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::NUMBER,
					'default'     => 1,
					'description' => esc_html__( 'Set scale of the axis to show data value', 'alpus-elementor-addon' ),
					'condition'   => array(
						'show_grid' => 'true',
					),
				)
			);

			$self->add_control(
				'show_label',
				array(
					'label'        => esc_html__( 'Show Axis Labels', 'alpus-elementor-addon' ),
					'description'  => esc_html__( 'Choose whether labels should be displayed. Default currently set to Yes.', 'alpus-elementor-addon' ),
					'type'         => Controls_Manager::SWITCHER,
					'separator'    => 'after',
					'default'      => 'true',
					'return_value' => 'true',
				)
			);
		}

			$self->add_control(
				'chart_legend_heading',
				array(
					'label' => esc_html__( 'Legend', 'alpus-elementor-addon' ),
					'type'  => Controls_Manager::HEADING,
				)
			);
			$self->add_control(
				'show_legend',
				array(
					'label'        => esc_html__( 'Show Legend', 'alpus-elementor-addon' ),
					'description'  => esc_html__( 'Enable to show legend for polar chart.', 'alpus-elementor-addon' ),
					'type'         => Controls_Manager::SWITCHER,
					'default'      => 'true',
					'return_value' => 'true',
				)
			);
			$self->add_control(
				'legend_position',
				array(
					'label'       => esc_html__( 'Position', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SELECT,
					'default'     => 'top',
					'description' => esc_html__( 'Control the position of legend on chart.', 'alpus-elementor-addon' ),
					'options'     => array(
						'top'    => esc_html__( 'Top', 'alpus-elementor-addon' ),
						'left'   => esc_html__( 'Left', 'alpus-elementor-addon' ),
						'bottom' => esc_html__( 'Bottom', 'alpus-elementor-addon' ),
						'right'  => esc_html__( 'Right', 'alpus-elementor-addon' ),
					),
					'condition'   => array(
						'show_legend' => 'true',
					),
				)
			);
			$self->add_control(
				'legend_reverse',
				array(
					'label'        => esc_html__( 'Reverse', 'alpus-elementor-addon' ),
					'description'  => esc_html__( 'Legend would be rearranged in reverse.', 'alpus-elementor-addon' ),
					'type'         => Controls_Manager::SWITCHER,
					'default'      => '',
					'return_value' => 'true',
					'condition'    => array(
						'show_legend' => 'true',
					),
				)
			);
			$self->add_control(
				'tooltip_heading',
				array(
					'label'     => esc_html__( 'Tooltip', 'alpus-elementor-addon' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);
			$self->add_control(
				'show_tooltip',
				array(
					'label'        => esc_html__( 'Show Tooltip', 'alpus-elementor-addon' ),
					'description'  => esc_html__( 'Choose whether tooltips should be displayed on hover. Default currently set to Yes.', 'alpus-elementor-addon' ),
					'type'         => Controls_Manager::SWITCHER,
					'default'      => 'true',
					'return_value' => 'true',
				)
			);
		$self->end_controls_section();
	}
}

