<?php
/**
 * Hotspot Partial
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Alpha_Controls_Manager;

/**
 * Register hotspot layout controls
 *
 * @since 1.0
 */
if ( ! function_exists( 'alpha_elementor_hotspot_layout_controls' ) ) {
	function alpha_elementor_hotspot_layout_controls( $self, $name_prefix = '', $condition_key = '', $condition_value = '', $repeater = false ) {
		$hotspot_content = class_exists( 'WooCommerce' ) ? array(
			'html'    => esc_html__( 'Custom Html', 'alpus-elementor-addon' ),
			'product' => esc_html__( 'Product', 'alpus-elementor-addon' ),
			'image'   => esc_html__( 'Image', 'alpus-elementor-addon' ),
		) : array(
			'html'  => esc_html__( 'Custom Html', 'alpus-elementor-addon' ),
			'image' => esc_html__( 'Image', 'alpus-elementor-addon' ),
		);

		if ( defined( 'ALPHA_CORE_VERSION' ) ) {
			$hotspot_content['block'] = esc_html__( 'Block', 'alpus-elementor-addon' );
		}

		if ( empty( $name_prefix ) ) {
			$self->start_controls_section(
				$name_prefix . 'section_hotspot',
				array(
					'label' => esc_html__( 'Hotspot', 'alpus-elementor-addon' ),
				)
			);
		}
			$self->add_control(
				$name_prefix . 'icon',
				array(
					'label'       => esc_html__( 'Icon', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Choose icon from icon library for hotspot on image.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::ICONS,
					'default'     => array(
						'value'   => 'fas fa-plus',
						'library' => 'fa-solid',
					),
					'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
				)
			);
			$self->add_responsive_control(
				$name_prefix . 'horizontal',
				array(
					'label'       => esc_html__( 'Horizontal', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls horizontal position of hotspot on image.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SLIDER,
					'default'     => array(
						'size' => 50,
						'unit' => '%',
					),
					'size_units'  => array(
						'px',
						'%',
						'vw',
					),
					'range'       => array(
						'px' => array(
							'step' => 1,
							'min'  => 0,
							'max'  => 500,
						),
						'%'  => array(
							'step' => 1,
							'min'  => 0,
							'max'  => 100,
						),
						'vw' => array(
							'step' => 1,
							'min'  => 0,
							'max'  => 100,
						),
					),
					'selectors'   => array(
						'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) => 'left: {{SIZE}}{{UNIT}};',
					),
					'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
				)
			);

			$self->add_responsive_control(
				$name_prefix . 'vertical',
				array(
					'label'       => esc_html__( 'Vertical', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls vertical position of hotspot on image.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SLIDER,
					'default'     => array(
						'size' => 50,
						'unit' => '%',
					),
					'size_units'  => array(
						'px',
						'%',
						'vw',
					),
					'range'       => array(
						'px' => array(
							'step' => 1,
							'min'  => 0,
							'max'  => 500,
						),
						'%'  => array(
							'step' => 1,
							'min'  => 0,
							'max'  => 100,
						),
						'vw' => array(
							'step' => 1,
							'min'  => 0,
							'max'  => 100,
						),
					),
					'selectors'   => array(
						'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) => 'top: {{SIZE}}{{UNIT}};',
					),
					'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
				)
			);

			$self->add_control(
				$name_prefix . 'effect',
				array(
					'label'       => esc_html__( 'Hotspot Effect', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Choose effect of hotspot item.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SELECT,
					'default'     => 'type1',
					'options'     => array(
						''      => esc_html__( 'None', 'alpus-elementor-addon' ),
						'type1' => esc_html__( 'Spread', 'alpus-elementor-addon' ),
						'type2' => esc_html__( 'Twinkle', 'alpus-elementor-addon' ),
					),
					'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
				)
			);

			$self->add_control(
				$name_prefix . 'el_class',
				array(
					'label'       => esc_html__( 'Custom Class', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Input custom class except dot to apply custom styles or codes.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::TEXT,
					'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
				)
			);

		if ( empty( $name_prefix ) ) {
			$self->end_controls_section();

			$self->start_controls_section(
				$name_prefix . 'section_content',
				array(
					'label' => esc_html__( 'Popup', 'alpus-elementor-addon' ),
				)
			);
		}

		$self->add_control(
			$name_prefix . 'type',
			array(
				'label'       => esc_html__( 'Type', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Determines how popup will be shown when hotspot is hovered.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '',
				'options'     => array(
					''       => esc_html__( 'Default', 'alpus-elementor-addon' ),
					'modern' => esc_html__( 'Modern', 'alpus-elementor-addon' ),
				),
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		$self->add_control(
			$name_prefix . 'popup_position',
			array(
				'label'       => esc_html__( 'Popup Position', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Determines where popup will be shown when hotspot is hovered.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::CHOOSE,
				'options'     => array(
					'none'   => array(
						'title' => esc_html__( 'Hide', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-ban',
					),
					'top'    => array(
						'title' => esc_html__( 'Up', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-arrow-up',
					),
					'bottom' => array(
						'title' => esc_html__( 'Down', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-arrow-down',
					),
					'left'   => array(
						'title' => esc_html__( 'Left', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-arrow-left',
					),
					'right'  => array(
						'title' => esc_html__( 'Right', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-arrow-right',
					),
				),
				'default'     => 'top',
				'toggle'      => false,
				'label_block' => true,
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		$self->add_control(
			$name_prefix . 'content',
			array(
				'label'       => esc_html__( 'Content', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Choose popup information content that will be displayed when hotspot is hovered.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'html',
				'options'     => $hotspot_content,
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);
		$self->add_control(
			$name_prefix . 'html',
			array(
				'label'       => esc_html__( 'Custom Html', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Input Html Code that will be shown in hotspot popup.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::TEXTAREA,
				'condition'   => $condition_key ? array(
					$name_prefix . 'content' => 'html',
					$condition_key           => $condition_value,
				) : array(
					$name_prefix . 'content' => 'html',
				),
			)
		);

		$self->add_control(
			$name_prefix . 'image',
			array(
				'label'       => esc_html__( 'Choose Image', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Choose image that will be shown in hotspot popup.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::MEDIA,
				'default'     => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
				'condition'   => $condition_key ? array(
					$name_prefix . 'content' => 'image',
					$condition_key           => $condition_value,
				) : array(
					$name_prefix . 'content' => 'image',
				),
			)
		);

		$self->add_control(
			$name_prefix . 'block',
			array(
				'label'       => esc_html__( 'Select a Block', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Choose block that will be shown in hotspot popup.', 'alpus-elementor-addon' ),
				'type'        => Alpha_Controls_Manager::AJAXSELECT2,
				'options'     => 'block',
				'label_block' => true,
				'condition'   => $condition_key ? array(
					$name_prefix . 'content' => 'block',
					$condition_key           => $condition_value,
				) : array(
					$name_prefix . 'content' => 'block',
				),
			)
		);

		$self->add_control(
			$name_prefix . 'link',
			array(
				'label'       => esc_html__( 'Link Url', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Input link url of hotspot where you will move to.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::URL,
				'default'     => array(
					'url' => '',
				),
				'condition'   => $condition_key ? array(
					$name_prefix . 'type!' => 'product',
					$condition_key         => $condition_value,
				) : array(
					$name_prefix . 'type!' => 'product',
				),
			)
		);

		$self->add_control(
			$name_prefix . 'product',
			array(
				'label'       => esc_html__( 'Product', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Choose product that will be shown in hotspot popup.', 'alpus-elementor-addon' ),
				'type'        => Alpha_Controls_Manager::AJAXSELECT2,
				'options'     => 'product',
				'label_block' => true,
				'condition'   => $condition_key ? array(
					$name_prefix . 'content' => 'product',
					$condition_key           => $condition_value,
				) : array(
					$name_prefix . 'content' => 'product',
				),
			)
		);

		if ( empty( $name_prefix ) ) {
			$self->end_controls_section();
		}
	}
}

/**
 * Register hotspot style controls
 *
 * @since 1.0
 */
if ( ! function_exists( 'alpha_elementor_hotspot_style_controls' ) ) {
	function alpha_elementor_hotspot_style_controls( $self, $name_prefix = '', $condition_key = '', $condition_value = '', $repeater = false ) {
		if ( empty( $name_prefix ) ) {
			$self->start_controls_section(
				$name_prefix . 'style_hotspot',
				array(
					'label' => esc_html__( 'Hotspot', 'alpus-elementor-addon' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
		}
		$self->add_control(
			$name_prefix . 'size',
			array(
				'label'       => esc_html__( 'Hotspot Size', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls hotspot size.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SLIDER,
				'default'     => array(
					'unit' => 'px',
				),
				'size_units'  => array(
					'px',
					'%',
				),
				'range'       => array(
					'px' => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 500,
					),
					'%'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : ' ' ) . '.hotspot-wrapper' => '--alpha-hotspot-bg-size: {{SIZE}}{{UNIT}};',
				),
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		$self->add_control(
			$name_prefix . 'icon_size',
			array(
				'label'       => esc_html__( 'Icon/Svg Size', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls icon size in hotspot.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SLIDER,
				'default'     => array(
					'unit' => 'px',
				),
				'size_units'  => array(
					'px',
					'em',
				),
				'range'       => array(
					'px' => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 500,
					),
					'em' => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) . ' .hotspot i' => 'font-size: {{SIZE}}{{UNIT}};',
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) . ' .hotspot svg' => 'width: {{SIZE}}{{UNIT}};',
				),
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		$self->add_control(
			$name_prefix . 'border_radius',
			array(
				'label'       => esc_html__( 'Border Radius', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls border radius value of hotspot.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => array(
					'px',
					'%',
					'em',
				),
				'selectors'   => array(
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) . ' .hotspot' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		$self->add_control(
			$name_prefix . 'spread_color',
			array(
				'label'       => esc_html__( 'Spread Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the color of spread effects.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'default'     => '#fff',
				'condition'   => $condition_key ? array(
					$name_prefix . 'effect' => 'type1',
					$condition_key          => $condition_value,
				) : array(
					$name_prefix . 'effect' => 'type1',
				),
				'selectors'   => array(
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : ' ' ) . '.hotspot-type1:not(:hover):before' => 'background: {{VALUE}};',
				),
			)
		);

		if ( empty( $name_prefix ) ) {
			$self->start_controls_tabs( $name_prefix . 'tabs_hotspot' );

			$self->start_controls_tab(
				$name_prefix . 'tab_btn_normal',
				array(
					'label' => esc_html__( 'Normal', 'alpus-elementor-addon' ),
				)
			);
		}

		$self->add_control(
			$name_prefix . 'btn_color',
			array(
				'label'       => esc_html__( 'Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the color of button.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) . ' .hotspot' => 'color: {{VALUE}};fill: {{VALUE}};',
				),
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		$self->add_control(
			$name_prefix . 'btn_back_color',
			array(
				'label'       => esc_html__( 'Background Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the background color of button.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) . ' .hotspot' => 'background-color: {{VALUE}};',
				),
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		if ( empty( $name_prefix ) ) {
			$self->end_controls_tab();

			$self->start_controls_tab(
				$name_prefix . 'tab_btn_hover',
				array(
					'label' => esc_html__( 'Hover', 'alpus-elementor-addon' ),
				)
			);
		}

		$self->add_control(
			$name_prefix . 'btn_color_hover',
			array(
				'label'       => esc_html__( 'Hover Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the hover color of button.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : ' ' ) . '.hotspot-wrapper:hover .hotspot' => 'color: {{VALUE}};fill: {{VALUE}};',
				),
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		$self->add_control(
			$name_prefix . 'btn_back_color_hover',
			array(
				'label'       => esc_html__( 'Hover Background Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the hover background color of button.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : ' ' ) . '.hotspot-wrapper:hover .hotspot' => 'background-color: {{VALUE}};',
				),
				'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
			)
		);

		if ( empty( $name_prefix ) ) {
			$self->end_controls_tab();

			$self->end_controls_tabs();

			$self->end_controls_section();

			$self->start_controls_section(
				$name_prefix . 'style_popup',
				array(
					'label' => esc_html__( 'Popup', 'alpus-elementor-addon' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
		}
			$self->add_responsive_control(
				$name_prefix . 'popup_size',
				array(
					'label'       => esc_html__( 'Popup Size', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls size hotspot popup.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SLIDER,
					'size_units'  => array(
						'px',
						'%',
						'rem',
					),
					'range'       => array(
						'px'  => array(
							'step' => 1,
							'min'  => 100,
							'max'  => 1000,
						),
						'rem' => array(
							'step' => 1,
							'min'  => 10,
							'max'  => 100,
						),
						'%'   => array(
							'step' => 1,
							'min'  => 1,
							'max'  => 100,
						),
					),
					'selectors'   => array(
						'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : ' ' ) . '.hotspot-wrapper:not(.hotspot-modern) .hotspot-box' => 'width: {{SIZE}}{{UNIT}}; min-width: {{SIZE}}{{UNIT}}',
						'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : ' ' ) . '.hotspot-modern .hotspot-box-horizontal' => 'width: {{SIZE}}{{UNIT}}; min-width: {{SIZE}}{{UNIT}}',
						'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : ' ' ) . '.hotspot-modern .hotspot-box-vertical' => 'height: {{SIZE}}{{UNIT}}',
					),
					'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
				)
			);

			$self->add_control(
				$name_prefix . 'popup_padding',
				array(
					'label'       => esc_html__( 'Popup Padding', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls padding value of hotspot popup.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::DIMENSIONS,
					'size_units'  => array(
						'px',
						'%',
						'em',
					),
					'selectors'   => array(
						'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) . ' .hotspot-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
					'condition'   => $condition_key ? array( $condition_key => $condition_value ) : '',
				)
			);

			$self->add_control(
				$name_prefix . 'popup_color',
				array(
					'label'     => esc_html__( 'Color', 'alpus-elementor-addon' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => array(
						'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) . ' .hotspot-box' => 'color: {{VALUE}};',
					),
					'condition' => $condition_key ? array(
						$condition_key        => $condition_value,
						$name_prefix . 'type' => '',
					) : array(
						$name_prefix . 'type' => '',
					),
				)
			);
			$self->add_control(
				$name_prefix . 'popup_bg_color',
				array(
					'label'     => esc_html__( 'Background Color', 'alpus-elementor-addon' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => array(
						'.elementor-element-{{ID}}' . ( $repeater ? ' {{CURRENT_ITEM}}' : '' ) . ' .hotspot-wrapper' => '--alpha-hotspot-bg-color: {{VALUE}};',
					),
					'condition' => $condition_key ? array(
						$condition_key        => $condition_value,
						$name_prefix . 'type' => '',
					) : array(
						$name_prefix . 'type' => '',
					),
				)
			);

		if ( empty( $name_prefix ) ) {
			$self->end_controls_section();
		}
	}
}
