<?php
/**
 * Elementor Floating Addon
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @version    1.0
 */

defined( 'ABSPATH' ) || exit;


use Elementor\Controls_Manager;
use Elementor\Alpha_Controls_Manager;

if ( ! class_exists( 'Alpha_Floating_Elementor' ) ) {
	/**
	 *  Elementor Floating Addon
	 *
	 * @since 1.0
	 */
	class Alpha_Floating_Elementor extends Alpus_Base {

		/**
		 * The Constructor.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			// Add controls to addon tab
			add_action( 'alpha_elementor_addon_controls', array( $this, 'add_controls' ), 10, 2 );

			// Add render options
			add_filter( 'alpha_elementor_addon_options', array( $this, 'addon_options' ), 10, 2 );

		}

		/**
		 * Add controls to addon tab.
		 *
		 * @since 1.0
		 */
		public function add_controls( $self, $source = '' ) {

			$left  = is_rtl() ? 'right' : 'left';
			$right = 'left' == $left ? 'right' : 'left';

			if ( 'banner' != $source ) {
				$self->start_controls_section(
					'_alpha_section_motion_effect',
					array(
						'label' => esc_html__( 'Motion Effects', 'alpus-elementor-addon' ),
						'tab'   => Alpha_Widget_Advanced_Tabs::TAB_CUSTOM,
					)
				);
			}
				$self->add_control(
					'alpha_scroll',
					array(
						'label'       => esc_html__( 'Scroll Effect', 'alpus-elementor-addon' ),
						'description' => esc_html__( 'Enable to apply floating effects when mouse scrolls.', 'alpus-elementor-addon' ),
						'type'        => Controls_Manager::SWITCHER,
						'condition'   => array(
							'alpha_track!' => 'yes',
						),
					)
				);

				$self->add_control(
					'alpha_scroll_horizontal_toggle',
					array(
						'label'     => esc_html__( 'Horizontal Movement', 'alpus-elementor-addon' ),
						'type'      => Controls_Manager::POPOVER_TOGGLE,
						'condition' => array(
							'alpha_scroll' => 'yes',
							'alpha_track!' => 'yes',
						),
					)
				);

				$self->start_popover();

					$self->add_control(
						'alpha_scroll_horizontal_dir',
						array(
							'type'    => Controls_Manager::SELECT,
							'label'   => esc_html__( 'Direction', 'alpus-elementor-addon' ),
							'default' => 'right',
							'options' => array(
								'left'  => esc_html__( 'To Left', 'alpus-elementor-addon' ),
								'right' => esc_html__( 'To Right', 'alpus-elementor-addon' ),
							),
						)
					);
					$self->add_control(
						'alpha_scroll_horizontal_speed',
						array(
							'label'      => esc_html__( 'Speed', 'alpus-elementor-addon' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => array( 'px' ),
							'default'    => array(
								'size' => 1,
							),
							'range'      => array(
								'px' => array(
									'step' => 0.1,
									'min'  => 0,
									'max'  => 10,
								),
							),
						)
					);

				$self->end_popover();

				$self->add_control(
					'alpha_scroll_vertical_toggle',
					array(
						'label'     => esc_html__( 'Vertical Movement', 'alpus-elementor-addon' ),
						'type'      => Controls_Manager::POPOVER_TOGGLE,
						'condition' => array(
							'alpha_scroll' => 'yes',
							'alpha_track!' => 'yes',
						),
					)
				);

				$self->start_popover();

					$self->add_control(
						'alpha_scroll_vertical_dir',
						array(
							'type'    => Controls_Manager::SELECT,
							'label'   => esc_html__( 'Direction', 'alpus-elementor-addon' ),
							'default' => 'up',
							'options' => array(
								'up'   => esc_html__( 'Up', 'alpus-elementor-addon' ),
								'down' => esc_html__( 'Down', 'alpus-elementor-addon' ),
							),
						)
					);
					$self->add_control(
						'alpha_scroll_vertical_speed',
						array(
							'label'      => esc_html__( 'Speed', 'alpus-elementor-addon' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => array( 'px' ),
							'default'    => array(
								'size' => 1,
							),
							'range'      => array(
								'px' => array(
									'step' => 0.1,
									'min'  => 0,
									'max'  => 10,
								),
							),
						)
					);

				$self->end_popover();

				$self->add_control(
					'alpha_scroll_opacity_toggle',
					array(
						'label'     => esc_html__( 'Transparency', 'alpus-elementor-addon' ),
						'type'      => Controls_Manager::POPOVER_TOGGLE,
						'condition' => array(
							'alpha_scroll' => 'yes',
							'alpha_track!' => 'yes',
						),
					)
				);

				$self->start_popover();

					$self->add_control(
						'alpha_scroll_opacity_dir',
						array(
							'type'    => Controls_Manager::SELECT,
							'label'   => esc_html__( 'Direction', 'alpus-elementor-addon' ),
							'default' => 'in',
							'options' => array(
								'in'  => esc_html__( 'Fade In', 'alpus-elementor-addon' ),
								'out' => esc_html__( 'Fade Out', 'alpus-elementor-addon' ),
							),
						)
					);
					$self->add_control(
						'alpha_scroll_opacity_speed',
						array(
							'label'      => esc_html__( 'Speed', 'alpus-elementor-addon' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => array( 'px' ),
							'default'    => array(
								'size' => 1,
							),
							'range'      => array(
								'px' => array(
									'step' => 0.1,
									'min'  => 0,
									'max'  => 10,
								),
							),
						)
					);

				$self->end_popover();

				$self->add_control(
					'alpha_scroll_rotate_toggle',
					array(
						'label'     => esc_html__( 'Rotate', 'alpus-elementor-addon' ),
						'type'      => Controls_Manager::POPOVER_TOGGLE,
						'condition' => array(
							'alpha_scroll' => 'yes',
							'alpha_track!' => 'yes',
						),
					)
				);

				$self->start_popover();

					$self->add_control(
						'alpha_scroll_rotate_dir',
						array(
							'type'    => Controls_Manager::SELECT,
							'label'   => esc_html__( 'Direction', 'alpus-elementor-addon' ),
							'default' => 'right',
							'options' => array(
								'left'  => esc_html__( 'To Left', 'alpus-elementor-addon' ),
								'right' => esc_html__( 'To Right', 'alpus-elementor-addon' ),
							),
						)
					);
					$self->add_control(
						'alpha_scroll_rotate_speed',
						array(
							'label'      => esc_html__( 'Speed', 'alpus-elementor-addon' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => array( 'px' ),
							'default'    => array(
								'size' => 1,
							),
							'range'      => array(
								'px' => array(
									'step' => 0.1,
									'min'  => 0,
									'max'  => 10,
								),
							),
						)
					);

				$self->end_popover();

				$self->add_control(
					'alpha_scroll_zoom_toggle',
					array(
						'label'     => esc_html__( 'Zoom', 'alpus-elementor-addon' ),
						'type'      => Controls_Manager::POPOVER_TOGGLE,
						'condition' => array(
							'alpha_scroll' => 'yes',
							'alpha_track!' => 'yes',
						),
					)
				);

				$self->start_popover();

					$self->add_control(
						'alpha_scroll_zoom_dir',
						array(
							'type'    => Controls_Manager::SELECT,
							'label'   => esc_html__( 'Direction', 'alpus-elementor-addon' ),
							'default' => 'in',
							'options' => array(
								'in'    => esc_html__( 'In', 'alpus-elementor-addon' ),
								'out'   => esc_html__( 'Out', 'alpus-elementor-addon' ),
								'in-x'  => esc_html__( 'In Horizontal', 'alpus-elementor-addon' ),
								'out-x' => esc_html__( 'Out Horizontal', 'alpus-elementor-addon' ),
							),
						)
					);
					$self->add_control(
						'alpha_scroll_zoom_speed',
						array(
							'label'      => esc_html__( 'Speed', 'alpus-elementor-addon' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => array( 'px' ),
							'default'    => array(
								'size' => 1,
							),
							'range'      => array(
								'px' => array(
									'step' => 0.1,
									'min'  => 0,
									'max'  => 10,
								),
							),
						)
					);

				$self->end_popover();

				$self->add_control(
					'alpha_scroll_stop',
					array(
						'label'       => esc_html__( 'When scrolling effect should be stopped', 'alpus-elementor-addon' ),
						'type'        => Controls_Manager::SELECT,
						'default'     => 'center',
						'options'     => array(
							'top'        => esc_html__( 'After Top of Object reaches Top of Screen', 'alpus-elementor-addon' ),
							'center-top' => esc_html__( 'After Top of Object reaches Center of Screen', 'alpus-elementor-addon' ),
							'center'     => esc_html__( 'After Center of Object reaches Center of Screen', 'alpus-elementor-addon' ),
						),
						'condition'   => array(
							'alpha_scroll' => 'yes',
							'alpha_track!' => 'yes',
						),
						'description' => esc_html__( 'Determine how to stop scrolling effect.', 'alpus-elementor-addon' ),
					)
				);
			if ( 'section' != $source ) {
				$self->add_control(
					'alpha_track',
					array(
						'label'       => esc_html__( 'Track Effect', 'alpus-elementor-addon' ),
						'description' => esc_html__( 'Enable to apply floating effects as mouse tracking.', 'alpus-elementor-addon' ),
						'type'        => Controls_Manager::SWITCHER,
						'condition'   => array(
							'alpha_scroll!' => 'yes',
						),
					)
				);
			}

			if ( 'section' == $source ) {
				$self->add_control(
					'alpha_track',
					array(
						'label'       => esc_html__( 'Track Effect', 'alpus-elementor-addon' ),
						'description' => esc_html__( 'Enable to apply floating effects as mouse tracking.', 'alpus-elementor-addon' ),
						'type'        => Controls_Manager::HIDDEN,
						'condition'   => array(
							'alpha_scroll!' => 'yes',
						),
					)
				);
			}

				$self->add_control(
					'alpha_track_dir',
					array(
						'label'     => esc_html__( 'Direction', 'alpus-elementor-addon' ),
						'type'      => Controls_Manager::SELECT,
						'default'   => '',
						'options'   => array(
							''           => esc_html__( 'Both', 'alpus-elementor-addon' ),
							'horizontal' => esc_html__( 'Horizontal', 'alpus-elementor-addon' ),
							'vertical'   => esc_html__( 'Vertical', 'alpus-elementor-addon' ),
						),
						'condition' => array(
							'alpha_track'   => 'yes',
							'alpha_scroll!' => 'yes',
						),
					)
				);

				$self->add_control(
					'alpha_track_oppisite',
					array(
						'label'       => esc_html__( 'Opposite to Mouse Move', 'alpus-elementor-addon' ),
						'type'        => Controls_Manager::SWITCHER,
						'description' => esc_html__( 'Move object in opposite direction of mouse move.', 'alpus-elementor-addon' ),
						'condition'   => array(
							'alpha_track'   => 'yes',
							'alpha_scroll!' => 'yes',
						),
					)
				);

				$self->add_control(
					'alpha_track_speed',
					array(
						'label'       => esc_html__( 'Track Speed', 'alpus-elementor-addon' ),
						'type'        => Controls_Manager::SLIDER,
						'description' => esc_html__( 'Controls speed of floating object while mouse is moving.', 'alpus-elementor-addon' ),
						'default'     => array(
							'size' => 0.5,
						),
						'range'       => array(
							'px' => array(
								'step' => 0.1,
								'min'  => 0,
								'max'  => 5,
							),
						),
						'condition'   => array(
							'alpha_track'   => 'yes',
							'alpha_scroll!' => 'yes',
						),
					)
				);

			if ( 'banner' != $source ) {
				$self->end_controls_section();
			}
		}

		/**
		 * Add render options.
		 *
		 * @since 1.0
		 */
		public function addon_options( $options, $settings ) {
			// Floating Options
			if ( 'yes' == $settings['alpha_track'] ) { // mouse tracking
				$track_settings = array();
				if ( 'yes' == $settings['alpha_track_oppisite'] ) {
					$track_settings['invertX'] = true;
					$track_settings['invertY'] = true;
				} else {
					$track_settings['invertX'] = false;
					$track_settings['invertY'] = false;
				}

				if ( 'horizontal' == $settings['alpha_track_dir'] ) {
					$track_settings['limitY'] = '0';
				} elseif ( 'vertical' == $settings['alpha_track_dir'] ) {
					$track_settings['limitX'] = '0';
				}

				if ( ! empty( $settings['builder'] ) && 'wpb' == $settings['builder'] ) {
					$speed = empty( $settings['alpha_track_speed'] ) ? 0.5 : floatval( $settings['alpha_track_speed'] );
				} else {
					$speed = empty( $settings['alpha_track_speed']['size'] ) ? 0.5 : floatval( $settings['alpha_track_speed']['size'] );
				}

				wp_enqueue_script( 'jquery-floating' );
				$options = $options +
					array(
						'data-plugin'         => 'floating',
						'data-options'        => json_encode( $track_settings ),
						'data-floating-depth' => $speed,
					);
			}
			if ( 'yes' == $settings['alpha_scroll'] ) { // scrolling effect
				$scroll_settings = array();
				$pos             = isset( $settings['alpha_scroll_stop'] ) ? esc_attr( $settings['alpha_scroll_stop'] ) : 'center';

				$from = array();
				$to   = array();
				if ( 'yes' == $settings['alpha_scroll_horizontal_toggle'] ) {
					$size = '' !== $settings['alpha_scroll_horizontal_speed']['size'] ? floatval( $settings['alpha_scroll_horizontal_speed']['size'] ) * 50 : 50;
					if ( 'left' == $settings['alpha_scroll_horizontal_dir'] ) {
						$from['transform']['translate']['translateX'] = $size . '%';
						$to['transform']['translate']['translateX']   = -$size . '%';
					} else {
						$from['transform']['translate']['translateX'] = -$size . '%';
						$to['transform']['translate']['translateX']   = $size . '%';
					}
				}
				if ( 'yes' == $settings['alpha_scroll_vertical_toggle'] ) {
					$size = '' !== $settings['alpha_scroll_vertical_speed']['size'] ? floatval( $settings['alpha_scroll_vertical_speed']['size'] ) * 50 : 50;
					if ( 'up' == $settings['alpha_scroll_vertical_dir'] ) {
						$from['transform']['translate']['translateY'] = $size . '%';
						$to['transform']['translate']['translateY']   = -$size . '%';
					} else {
						$from['transform']['translate']['translateY'] = -$size . '%';
						$to['transform']['translate']['translateY']   = $size . '%';
					}
				}
				if ( 'yes' == $settings['alpha_scroll_opacity_toggle'] ) {
					$size = '' !== $settings['alpha_scroll_opacity_speed']['size'] ? max( 0, 1 - floatval( $settings['alpha_scroll_opacity_speed']['size'] ) / 5 ) : 0.4;
					if ( 'in' == $settings['alpha_scroll_opacity_dir'] ) {
						$from['opacity'] = $size;
						$to['opacity']   = 1;
					} else {
						$from['opacity'] = 1;
						$to['opacity']   = $size;
					}
				}
				if ( 'yes' == $settings['alpha_scroll_rotate_toggle'] ) {
					$size = '' !== $settings['alpha_scroll_rotate_speed']['size'] ? floatval( $settings['alpha_scroll_rotate_speed']['size'] ) * 50 : 50;
					if ( 'left' == $settings['alpha_scroll_rotate_dir'] ) {
						$from['transform']['rotate'] = '0deg';
						$to['transform']['rotate']   = ( -360 * $size / 50 ) . 'deg';
					} else {
						$from['transform']['rotate'] = '0deg';
						$to['transform']['rotate']   = ( 360 * $size / 50 ) . 'deg';
					}
				}
				if ( 'yes' == $settings['alpha_scroll_zoom_toggle'] ) {
					$size = '' !== $settings['alpha_scroll_zoom_speed']['size'] ? floatval( $settings['alpha_scroll_zoom_speed']['size'] ) : 1;
					if ( 'in' == $settings['alpha_scroll_zoom_dir'] ) {
						$from['transform']['scale'] = max( 0, 1 - $size / 10 );
						$to['transform']['scale']   = 1;
					} elseif ( 'out' == $settings['alpha_scroll_zoom_dir'] ) {
						$from['transform']['scale'] = 1 + $size / 10;
						$to['transform']['scale']   = 1;
					} elseif ( 'in-x' == $settings['alpha_scroll_zoom_dir'] ) {
						$from['width']  = ( max( 0, 100 - $size * 10 ) ) . '%';
						$to['width']    = '100%';
						$from['margin'] = '0 auto';
						$to['margin']   = '0 auto';
					} else {
						$from['width']  = '100%';
						$to['width']    = $size * 10 . '%';
						$from['margin'] = '0 auto';
						$to['margin']   = '0 auto';
					}
				}

				$scroll_settings['options']['data-bottom-top'] = '';
				$scroll_settings['options'][ 'data-' . $pos ]  = '';
				foreach ( $from as $key => $styles ) {
					$scroll_settings['options']['data-bottom-top'] .= $key . ': ';
					if ( 'transform' == $key ) {
						foreach ( $styles as $transform => $style ) {
							if ( 'translate' == $transform ) {
								if ( isset( $style['translateX'] ) && isset( $style['translateY'] ) ) {
									$scroll_settings['options']['data-bottom-top'] .= $transform . '(' . $style['translateX'] . ', ' . $style['translateY'] . ')';
								} elseif ( isset( $style['translateX'] ) ) {
									$scroll_settings['options']['data-bottom-top'] .= $transform . '(' . $style['translateX'] . ', 0' . ')';
								} else {
									$scroll_settings['options']['data-bottom-top'] .= $transform . '(0, ' . $style['translateY'] . ')';
								}
							} else {
								$scroll_settings['options']['data-bottom-top'] .= ' ' . $transform . '(' . $style . ')';
							}
						}
						$scroll_settings['options']['data-bottom-top'] .= ';';
					} else {
						$scroll_settings['options']['data-bottom-top'] .= $styles . ';';
					}
					$scroll_settings['options']['data-bottom-top'] .= ' ';
				}

				foreach ( $to as $key => $styles ) {
					$scroll_settings['options'][ 'data-' . $pos ] .= $key . ': ';
					if ( 'transform' == $key ) {
						foreach ( $styles as $transform => $style ) {
							if ( 'translate' == $transform ) {
								if ( isset( $style['translateX'] ) && isset( $style['translateY'] ) ) {
									$scroll_settings['options'][ 'data-' . $pos ] .= $transform . '(' . $style['translateX'] . ', ' . $style['translateY'] . ')';
								} elseif ( isset( $style['translateX'] ) ) {
									$scroll_settings['options'][ 'data-' . $pos ] .= $transform . '(' . $style['translateX'] . ', 0' . ')';
								} else {
									$scroll_settings['options'][ 'data-' . $pos ] .= $transform . '(0, ' . $style['translateY'] . ')';
								}
							} else {
								$scroll_settings['options'][ 'data-' . $pos ] .= ' ' . $transform . '(' . $style . ')';
							}
						}
						$scroll_settings['options'][ 'data-' . $pos ] .= ';';
					} else {
						$scroll_settings['options'][ 'data-' . $pos ] .= $styles . ';';
					}
					$scroll_settings['options'][ 'data-' . $pos ] .= ' ';
				}

				wp_enqueue_script( 'jquery-skrollr' );
				$options = $options +
					array(
						'data-plugin'  => 'skrollr',
						'data-options' => json_encode( $scroll_settings['options'] ),
					);
			}
			return $options;
		}
	}
	Alpha_Floating_Elementor::get_instance();
}
