<?php
/**
 *  360 degree elementor widget
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0.0
 */

// direct load is not allowed
defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;

class Alpha_360_Degree_Elementor_Widget extends \Elementor\Widget_Base {

	public function get_name() {
		return ALPHA_NAME . '_widget_360_degree';
	}

	public function get_title() {
		return esc_html__( '360 Degree View', 'alpus-elementor-addon' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon alpha-widget-icon-degree';
	}

	public function get_categories() {
		return array( 'alpha_addon_widget' );
	}

	public function get_keywords() {
		return array( '360', 'degree', 'gallery', 'view' );
	}

	/**
	 * Get the style depends.
	 *
	 * @since 1.0
	 */
	public function get_style_depends() {
		wp_register_style( 'alpha-three-sixty', alpus_plugin_uri( ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/360-degree/360-degree' . ( is_rtl() ? '-rtl' : '' ) . '.min.css', 'alpus-elementor-addon' ), array(), ALPUS_ELEMENTOR_ADDON_VERSION );
		return array( 'alpha-three-sixty' );
	}

	/**
	 * Get the script depends.
	 *
	 * @since 1.0
	 */
	public function get_script_depends() {
		wp_register_script( 'three-sixty', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/360-degree/threesixty.min.js', array(), false, true );
		wp_register_script( 'alpha-three-sixty', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/360-degree/360-degree' . ALPUS_PLUGIN_JS_SUFFIX, array( 'three-sixty' ), ALPUS_ELEMENTOR_ADDON_VERSION, true );
		return array( 'three-sixty', 'alpha-three-sixty' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_360_degree',
			array(
				'label' => esc_html__( '360 Degree', 'alpus-elementor-addon' ),
			)
		);

			$this->add_control(
				'images',
				array(
					'label'       => esc_html__( 'Upload Images', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::GALLERY,
					'default'     => array(),
					'show_label'  => false,
					'description' => esc_html__( 'Upload bundle of images that you want to show in 360 degree gallery.', 'alpus-elementor-addon' ),
				)
			);

			$this->add_group_control(
				Group_Control_Image_Size::get_type(),
				array(
					'name'        => 'thumbnail',
					'separator'   => 'none',
					'description' => esc_html__( 'Select fit image size that are suitable for rendering area.', 'alpus-elementor-addon' ),
					'exclude'     => array( 'custom' ),
				)
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_360_degree_style',
			array(
				'label' => esc_html__( 'Button Settings', 'alpus-elementor-addon' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

			$this->add_control(
				'btn_group_heading',
				array(
					'label' => esc_html__( 'Buttons Group', 'alpus-elementor-addon' ),
					'type'  => Controls_Manager::HEADING,
				)
			);

			$this->add_control(
				'btn_group_position',
				array(
					'label'       => esc_html__( 'Position', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls position of buttons group.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SLIDER,
					'size_units'  => array(
						'px',
					),
					'selectors'   => array(
						'{{WRAPPER}} .nav_bar' => 'bottom: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'btn_group_bg_color',
				array(
					'label'       => esc_html__( 'Background Color', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Control the buttons group background color.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::COLOR,
					'selectors'   => array(
						'.elementor-element-{{ID}} .nav_bar' => 'background-color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'btn_group_padding',
				array(
					'label'       => esc_html__( 'Padding', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Control the buttons group\'s padding.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::DIMENSIONS,
					'size_units'  => array(
						'px',
						'rem',
						'%',
					),
					'selectors'   => array(
						'{{WRAPPER}} .nav_bar' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'btn_group_br',
				array(
					'label'       => esc_html__( 'Border Radius', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Control the buttons group\'s border radius.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::DIMENSIONS,
					'size_units'  => array(
						'px',
						'rem',
						'%',
					),
					'selectors'   => array(
						'{{WRAPPER}} .nav_bar' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'button_group_heading',
				array(
					'label'     => esc_html__( 'Button', 'alpus-elementor-addon' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				)
			);

			$this->add_control(
				'prev_icon',
				array(
					'label'       => esc_html__( 'Prev / Next Button Size (px)', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls size of prev frame button.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SLIDER,
					'size_units'  => array(
						'px',
					),
					'selectors'   => array(
						'.elementor-element-{{ID}} .nav_bar .nav_bar_previous:before' => 'font-size: {{SIZE}}{{UNIT}};',
						'.elementor-element-{{ID}} .nav_bar .nav_bar_next:before' => 'font-size: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'play_icon',
				array(
					'label'       => esc_html__( 'Play/Pause Button Size (px)', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls size of play/pause button.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SLIDER,
					'size_units'  => array(
						'px',
					),
					'selectors'   => array(
						'.elementor-element-{{ID}} .nav_bar .nav_bar_play:before' => 'font-size: {{SIZE}}{{UNIT}};',
						'.elementor-element-{{ID}} .nav_bar .nav_bar_stop:before' => 'font-size: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'button_responsive_padding',
				array(
					'label'       => esc_html__( 'Padding', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Control the buttons` padding.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::DIMENSIONS,
					'size_units'  => array(
						'px',
						'rem',
						'%',
					),
					'selectors'   => array(
						'{{WRAPPER}} .nav_bar>a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				)
			);

			$this->start_controls_tabs( 'tabs_btn_colors' );

				$this->start_controls_tab(
					'tab_btn_normal',
					array(
						'label' => esc_html__( 'Normal', 'alpus-elementor-addon' ),
					)
				);

					$this->add_control(
						'btn_color',
						array(
							'label'       => esc_html__( 'Color', 'alpus-elementor-addon' ),
							'description' => esc_html__( 'Control the buttons color.', 'alpus-elementor-addon' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'.elementor-element-{{ID}} .alpha-360-gallery-wrapper .nav_bar a' => 'color: {{VALUE}};',
							),
						)
					);

					$this->add_control(
						'btn_bg_color',
						array(
							'label'       => esc_html__( 'Background Color', 'alpus-elementor-addon' ),
							'description' => esc_html__( 'Control the buttons background color.', 'alpus-elementor-addon' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'.elementor-element-{{ID}} .alpha-360-gallery-wrapper .nav_bar a' => 'background-color: {{VALUE}};',
							),
						)
					);

					$this->add_control(
						'btn_bd_color',
						array(
							'label'       => esc_html__( 'Border Color', 'alpus-elementor-addon' ),
							'description' => esc_html__( 'Control the buttons border color.', 'alpus-elementor-addon' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'.elementor-element-{{ID}} .alpha-360-gallery-wrapper .nav_bar a' => 'border-color: {{VALUE}};',
							),
						)
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'tab_btn_hover',
					array(
						'label' => esc_html__( 'Hover', 'alpus-elementor-addon' ),
					)
				);

					$this->add_control(
						'btn_hover_color',
						array(
							'label'       => esc_html__( 'Hover Color', 'alpus-elementor-addon' ),
							'description' => esc_html__( 'Control the buttons hover color.', 'alpus-elementor-addon' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'.elementor-element-{{ID}} .alpha-360-gallery-wrapper .nav_bar a:hover' => 'color: {{VALUE}};',
							),
						)
					);

					$this->add_control(
						'btn_hover_bg_color',
						array(
							'label'       => esc_html__( 'Hover Background Color', 'alpus-elementor-addon' ),
							'description' => esc_html__( 'Control the buttons hover background color.', 'alpus-elementor-addon' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'.elementor-element-{{ID}} .alpha-360-gallery-wrapper .nav_bar a:hover' => 'background-color: {{VALUE}};',
							),
						)
					);

					$this->add_control(
						'btn_hover_bd_color',
						array(
							'label'       => esc_html__( 'Hover Border Color', 'alpus-elementor-addon' ),
							'description' => esc_html__( 'Control the buttons hover border color.', 'alpus-elementor-addon' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'.elementor-element-{{ID}} .alpha-360-gallery-wrapper .nav_bar a:hover' => 'border-color: {{VALUE}};',
							),
						)
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function render() {
		$atts = $this->get_settings_for_display();

		require ALPUS_ELEMENTOR_ADDON_PATH . '/inc/widgets/360-degree/render-360-degree-elementor.php';
	}

	protected function content_template() {}
}
