<?php
defined( 'ABSPATH' ) || die;

/**
 *  Contact Form Widget
 *
 *  Widget to display contact form with cf7.
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0
 */

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;
use Elementor\Alpha_Controls_Manager;

class Alpha_Contact_Form_Elementor_Widget extends \Elementor\Widget_Base {

	public function get_name() {
		return ALPHA_NAME . '_widget_contact_form';
	}

	public function get_title() {
		return esc_html__( 'Contact Form 7', 'alpus-elementor-addon' );
	}

	public function get_categories() {
		return array( 'alpha_addon_widget' );
	}

	public function get_keywords() {
		return array( 'forms', 'field', 'button', 'submit', 'mail', 'wpform', 'newsletter' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon eicon-form-horizontal';
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_contact_form',
			array(
				'label' => esc_html__( 'Contact Form', 'alpus-elementor-addon' ),
			)
		);

		if ( ! class_exists( 'WPCF7' ) ) {

			$this->add_control(
				'cf7_missing_notice',
				array(
					'type'            => Controls_Manager::RAW_HTML,
					'raw'             => sprintf(
						esc_html__( 'It looks like %1$s is missing in your site. Please click on the link below and install/activate %1$s. Make sure to refresh this page after installation or activation.', 'alpus-elementor-addon' ),
						'<a href="' . esc_url( admin_url( 'plugin-install.php?s=Contact+Form+7&tab=search&type=term' ) )
						. '" target="_blank" rel="noopener">' . esc_html__( 'Contact Form 7', 'alpus-elementor-addon' ) . '</a>',
					),
					'content_classes' => 'elementor-panel-alert elementor-panel-alert-danger',
				)
			);

			$this->add_control(
				'cf7_install',
				array(
					'type' => Controls_Manager::RAW_HTML,
					'raw'  => '<a href="' . esc_url( admin_url( 'plugin-install.php?s=Contact+Form+7&tab=search&type=term' ) ) . '" target="_blank" rel="noopener">' . esc_html__( 'Click to install or activate Contact Form 7', 'alpus-elementor-addon' ) . '</a>',
				)
			);

		} else {
			$this->add_control(
				'cf7_form',
				array(
					'type'        => Alpha_Controls_Manager::AJAXSELECT2,
					'label'       => esc_html__( 'Contact Forms', 'alpus-elementor-addon' ),
					'options'     => 'wpcf7_contact_form',
					'label_block' => true,
				)
			);
		}

		$this->end_controls_section();

		$this->start_controls_section(
			'section_contact_form_fields',
			array(
				'label' => esc_html__( 'Form Fields', 'alpus-elementor-addon' ),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'tg',
				'scheme'   => Elementor\Core\Schemes\Typography::TYPOGRAPHY_1,
				'label'    => esc_html__( 'Typography', 'alpus-elementor-addon' ),
				'selector' => '.elementor-element-{{ID}}',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'lbl_tg',
				'scheme'   => Elementor\Core\Schemes\Typography::TYPOGRAPHY_1,
				'label'    => esc_html__( 'Label Typography', 'alpus-elementor-addon' ),
				'selector' => '.elementor-element-{{ID}} label',
			)
		);

		$this->add_control(
			'lbl_mb',
			array(
				'type'       => Controls_Manager::SLIDER,
				'label'      => esc_html__( 'Label Bottom Spacing', 'alpus-elementor-addon' ),
				'range'      => array(
					'px'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 50,
					),
					'em'  => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 5,
					),
					'rem' => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 5,
					),
				),
				'default'    => array(
					'unit' => 'px',
				),
				'size_units' => array(
					'px',
					'em',
					'rem',
				),
				'selectors'  => array(
					'.elementor-element-{{ID}} label' => 'display: inline-block;margin-bottom: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'ih',
			array(
				'type'       => Controls_Manager::SLIDER,
				'label'      => esc_html__( 'The Height of input and select box', 'alpus-elementor-addon' ),
				'range'      => array(
					'px'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
					'em'  => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 10,
					),
					'rem' => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 10,
					),
				),
				'default'    => array(
					'unit' => 'px',
				),
				'size_units' => array(
					'px',
					'em',
					'rem',
				),
				'selectors'  => array(
					'.elementor-element-{{ID}} input[type="text"], .elementor-element-{{ID}} input[type="email"], .elementor-element-{{ID}} input[type="date"], .elementor-element-{{ID}} input[type="datetime"], .elementor-element-{{ID}} input[type="number"], .elementor-element-{{ID}} input[type="tel"], .elementor-element-{{ID}} select.wpcf7-select' => 'height: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'tah',
			array(
				'type'       => Controls_Manager::SLIDER,
				'label'      => esc_html__( 'The Height of textarea', 'alpus-elementor-addon' ),
				'range'      => array(
					'px'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 400,
					),
					'em'  => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 40,
					),
					'rem' => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 40,
					),
				),
				'default'    => array(
					'unit' => 'px',
				),
				'size_units' => array(
					'px',
					'em',
					'rem',
				),
				'selectors'  => array(
					'.elementor-element-{{ID}} textarea.wpcf7-textarea' => 'height: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'fs',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Font Size', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Inputs the font size of form and form fields.', 'alpus-elementor-addon' ),
				'range'       => array(
					'px'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 40,
					),
					'em'  => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 5,
					),
					'rem' => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 5,
					),
				),
				'default'     => array(
					'unit' => 'px',
				),
				'size_units'  => array(
					'px',
					'em',
					'rem',
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} input[type="text"], .elementor-element-{{ID}} input[type="email"], .elementor-element-{{ID}} input[type="date"], .elementor-element-{{ID}} input[type="datetime"], .elementor-element-{{ID}} input[type="number"], .elementor-element-{{ID}} input[type="tel"], .elementor-element-{{ID}} textarea, .elementor-element-{{ID}} .form-control, .elementor-element-{{ID}} select.wpcf7-select' => 'font-size: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_control(
			'clr',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Text Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the color of the form and form fields.', 'alpus-elementor-addon' ),
				'selectors'   => array(
					'.elementor-element-{{ID}} input[type="text"], .elementor-element-{{ID}} input[type="email"], .elementor-element-{{ID}} input[type="date"], .elementor-element-{{ID}} input[type="datetime"], .elementor-element-{{ID}} input[type="number"], .elementor-element-{{ID}} input[type="tel"], .elementor-element-{{ID}} textarea, .elementor-element-{{ID}} .form-control, .elementor-element-{{ID}} select.wpcf7-select' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'ph_clr',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Placeholder Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the placeholder color of form fields.', 'alpus-elementor-addon' ),
				'selectors'   => array(
					'.elementor-element-{{ID}} input[type="text"]::placeholder, .elementor-element-{{ID}} input[type="email"]::placeholder, .elementor-element-{{ID}} textarea::placeholder, .elementor-element-{{ID}} .form-control::placeholder' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'field_bgc',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Form Field Background Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the background color of form fields such as input and select boxes.', 'alpus-elementor-addon' ),
				'selectors'   => array(
					'.elementor-element-{{ID}} input[type="text"], .elementor-element-{{ID}} input[type="email"], .elementor-element-{{ID}} input[type="date"], .elementor-element-{{ID}} input[type="datetime"], .elementor-element-{{ID}} input[type="number"], .elementor-element-{{ID}} input[type="tel"], .elementor-element-{{ID}} textarea, .elementor-element-{{ID}} .form-control, .elementor-element-{{ID}} select.wpcf7-select' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'field_bw',
			array(
				'type'        => Controls_Manager::DIMENSIONS,
				'label'       => esc_html__( 'Form Field Border Width (px)', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the border size of the form fields such as input and select boxes.', 'alpus-elementor-addon' ),
				'selectors'   => array(
					'.elementor-element-{{ID}} input[type="text"], .elementor-element-{{ID}} input[type="email"], .elementor-element-{{ID}} input[type="date"], .elementor-element-{{ID}} input[type="datetime"], .elementor-element-{{ID}} input[type="number"], .elementor-element-{{ID}} input[type="tel"], .elementor-element-{{ID}} textarea, .elementor-element-{{ID}} .form-control, .elementor-element-{{ID}} select.wpcf7-select' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units'  => array( 'px' ),
			)
		);

		$this->add_control(
			'field_bc',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Form Field Border Color', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the border color of form fields such as input and select boxes.', 'alpus-elementor-addon' ),
				'selectors'   => array(
					'.elementor-element-{{ID}} input[type="text"], .elementor-element-{{ID}} input[type="email"], .elementor-element-{{ID}} input[type="date"], .elementor-element-{{ID}} input[type="datetime"], .elementor-element-{{ID}} input[type="number"], .elementor-element-{{ID}} input[type="tel"], .elementor-element-{{ID}} textarea, .elementor-element-{{ID}} .form-control, .elementor-element-{{ID}} select.wpcf7-select' => 'border-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'field_bcf',
			array(
				'type'        => Controls_Manager::COLOR,
				'label'       => esc_html__( 'Form Field Border Color on Focus', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the border color of form fields such as input and select boxes on focus status.', 'alpus-elementor-addon' ),
				'selectors'   => array(
					'.elementor-element-{{ID}} input[type="text"]:focus, .elementor-element-{{ID}} input[type="email"]:focus, .elementor-element-{{ID}} textarea:focus, .elementor-element-{{ID}} .form-control:focus, .elementor-element-{{ID}} select.wpcf7-select:focus' => 'border-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'br',
			array(
				'type'        => Controls_Manager::DIMENSIONS,
				'label'       => esc_html__( 'Form Field Border Radius (px)', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the border radius of form fields such as input, select boxes and buttons.', 'alpus-elementor-addon' ),
				'selectors'   => array(
					'.elementor-element-{{ID}} input.wpcf7-form-control, .elementor-element-{{ID}} textarea, .elementor-element-{{ID}} .form-control, .elementor-element-{{ID}} select.wpcf7-select' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units'  => array( 'px' ),
			)
		);

		$this->add_responsive_control(
			'form_space',
			array(
				'type'       => Controls_Manager::DIMENSIONS,
				'label'      => esc_html__( 'Form Field Padding(px)', 'alpus-elementor-addon' ),
				'selectors'  => array(
					'{{WRAPPER}} input[type="email"],{{WRAPPER}} input[type="number"],{{WRAPPER}} input[type="password"],{{WRAPPER}} input[type="search"],{{WRAPPER}} input[type="tel"],{{WRAPPER}} input[type="text"],{{WRAPPER}} input[type="url"],{{WRAPPER}} input[type="color"],{{WRAPPER}} input[type="date"],{{WRAPPER}} input[type="datetime"],{{WRAPPER}} input[type="datetime-local"],{{WRAPPER}} input[type="month"],{{WRAPPER}} input[type="time"],{{WRAPPER}} input[type="week"],{{WRAPPER}} textarea,{{WRAPPER}} .form-control,{{WRAPPER}} select' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units' => array( 'px' ),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_contact_form_buttons',
			array(
				'label' => esc_html__( 'Buttons', 'alpus-elementor-addon' ),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'btn_tg',
				'scheme'   => Elementor\Core\Schemes\Typography::TYPOGRAPHY_1,
				'label'    => esc_html__( 'Typography', 'alpus-elementor-addon' ),
				'selector' => '.elementor-element-{{ID}} button.wpcf7-form-control, .elementor-element-{{ID}} .btn.wpcf7-form-control, .elementor-element-{{ID}} input[type="submit"], .elementor-element-{{ID}} input[type="button"]',
			)
		);

		$this->add_control(
			'bh',
			array(
				'type'       => Controls_Manager::SLIDER,
				'label'      => esc_html__( 'The Height of Buttons', 'alpus-elementor-addon' ),
				'range'      => array(
					'px'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
					'em'  => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 10,
					),
					'rem' => array(
						'step' => 0.1,
						'min'  => 0,
						'max'  => 10,
					),
				),
				'default'    => array(
					'unit' => 'px',
				),
				'size_units' => array(
					'px',
					'em',
					'rem',
				),
				'selectors'  => array(
					'.elementor-element-{{ID}} button.wpcf7-form-control, .elementor-element-{{ID}} .btn.wpcf7-form-control, .elementor-element-{{ID}} input[type="submit"], .elementor-element-{{ID}} input[type="button"]' => 'height: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->add_responsive_control(
			'btn_pd',
			array(
				'type'       => Controls_Manager::DIMENSIONS,
				'label'      => esc_html__( 'Padding', 'alpus-elementor-addon' ),
				'selectors'  => array(
					'.elementor-element-{{ID}} button.wpcf7-form-control, .elementor-element-{{ID}} .btn.wpcf7-form-control, .elementor-element-{{ID}} input[type="submit"], .elementor-element-{{ID}} input[type="button"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units' => array( 'px', 'em', 'rem' ),
			)
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			array(
				'name'     => 'btn_bd',
				'selector' => '.elementor-element-{{ID}} button.wpcf7-form-control, .elementor-element-{{ID}} .btn.wpcf7-form-control, .elementor-element-{{ID}} input[type="submit"], .elementor-element-{{ID}} input[type="button"]',
				'exclude'  => array(
					'color',
				),
			)
		);

		$this->add_control(
			'btn_br',
			array(
				'type'       => Controls_Manager::DIMENSIONS,
				'label'      => esc_html__( 'Border Radius (px)', 'alpus-elementor-addon' ),
				'selectors'  => array(
					'.elementor-element-{{ID}} button.wpcf7-form-control, .elementor-element-{{ID}} .btn.wpcf7-form-control, .elementor-element-{{ID}} input[type="submit"], .elementor-element-{{ID}} input[type="button"]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units' => array( 'px' ),
			)
		);

		$this->start_controls_tabs( 'tabs_btn_style' );

		$this->start_controls_tab(
			'tabs_btn_normal',
			array(
				'label' => esc_html__( 'Normal', 'alpus-elementor-addon' ),
			)
		);

		$this->add_control(
			'btn_bgc',
			array(
				'label'     => esc_html__( 'Background Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} button.wpcf7-form-control, {{WRAPPER}} .btn.wpcf7-form-control, {{WRAPPER}} input[type="submit"], {{WRAPPER}} input[type="button"]' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'btn_clr',
			array(
				'label'     => esc_html__( 'Text Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} button.wpcf7-form-control, {{WRAPPER}} .btn.wpcf7-form-control, {{WRAPPER}} input[type="submit"], {{WRAPPER}} input[type="button"]' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'btn_bc',
			array(
				'label'     => esc_html__( 'Border Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} button.wpcf7-form-control, {{WRAPPER}} .btn.wpcf7-form-control, {{WRAPPER}} input[type="submit"], {{WRAPPER}} input[type="button"]' => 'border-color: {{VALUE}};',
				),
				'condition' => array(
					'btn_bd_border!' => '',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_btn_hover',
			array(
				'label' => esc_html__( 'Hover', 'alpus-elementor-addon' ),
			)
		);

		$this->add_control(
			'btn_hover_bgc',
			array(
				'label'     => esc_html__( 'Background Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} button.wpcf7-form-control:hover, {{WRAPPER}} .btn.wpcf7-form-control:hover, {{WRAPPER}} input[type="submit"]:hover, {{WRAPPER}} input[type="button"]:hover' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'btn_hover_clr',
			array(
				'label'     => esc_html__( 'Text Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} button.wpcf7-form-control:hover, {{WRAPPER}} .btn.wpcf7-form-control:hover, {{WRAPPER}} input[type="submit"]:hover, {{WRAPPER}} input[type="button"]:hover' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'btn_hover_bc',
			array(
				'label'     => esc_html__( 'Border Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} button.wpcf7-form-control:hover, {{WRAPPER}} .btn.wpcf7-form-control:hover, {{WRAPPER}} input[type="submit"]:hover, {{WRAPPER}} input[type="button"]:hover' => 'border-color: {{VALUE}};',
				),
				'condition' => array(
					'btn_bd_border!' => '',
				),
			)
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section(
			'section_contact_form_messages',
			array(
				'label' => esc_html__( 'Messages', 'alpus-elementor-addon' ),
			)
		);

		$this->add_control(
			'error_heading',
			array(
				'label'     => esc_html__( 'Error Message', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'error_tg',
				'scheme'   => Elementor\Core\Schemes\Typography::TYPOGRAPHY_1,
				'label'    => esc_html__( 'Typography', 'alpus-elementor-addon' ),
				'selector' => '.elementor-element-{{ID}} .wpcf7-not-valid-tip',
			)
		);

		$this->add_control(
			'error_clr',
			array(
				'label'     => esc_html__( 'Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'.elementor-element-{{ID}} .wpcf7-not-valid-tip' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'msg_heading',
			array(
				'label'     => esc_html__( 'General Message', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'msg_tg',
				'scheme'   => Elementor\Core\Schemes\Typography::TYPOGRAPHY_1,
				'label'    => esc_html__( 'Typography', 'alpus-elementor-addon' ),
				'selector' => '.elementor-element-{{ID}} form .wpcf7-response-output',
			)
		);

		$this->add_control(
			'msg_clr',
			array(
				'label'     => esc_html__( 'Text Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'.elementor-element-{{ID}} form.wpcf7-form .wpcf7-response-output' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'msg_bgc',
			array(
				'label'     => esc_html__( 'Background Color', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'.elementor-element-{{ID}} form.wpcf7-form .wpcf7-response-output' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			array(
				'name'     => 'msg_bd',
				'selector' => '.elementor-element-{{ID}} form.wpcf7-form .wpcf7-response-output',
			)
		);

		$this->end_controls_section();
	}

	protected function render() {
		if ( ! class_exists( 'WPCF7' ) ) {
			alpha_show_plugin_missing_alert( esc_html__( 'Contact Forms 7', 'alpus-elementor-addon' ) );
			return;
		}

		$atts = $this->get_settings_for_display();

		require ALPUS_ELEMENTOR_ADDON_PATH . '/inc/widgets/contact-form/render-contact-form-elementor.php';
	}
}
