<?php
defined( 'ABSPATH' ) || die;

/**
 *  Countdown Widget
 *
 *  Widget to display countdown.
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0.0
 */

use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

class Alpha_Countdown_Elementor_Widget extends \Elementor\Widget_Base {

	public function get_name() {
		return ALPHA_NAME . '_widget_countdown';
	}

	public function get_title() {
		return esc_html__( 'Countdown', 'alpus-elementor-addon' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon alpha-widget-icon-countdown';
	}

	public function get_categories() {
		return array( 'alpha_addon_widget' );
	}

	public function get_keywords() {
		return array( 'countdown', 'counter', 'timer' );
	}

	/**
	 * Get the style depends.
	 *
	 * @since 1.0
	 */
	public function get_style_depends() {
		wp_register_style( 'alpha-countdown', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/countdown/countdown' . ( is_rtl() ? '-rtl' : '' ) . '.min.css', array(), ALPUS_ELEMENTOR_ADDON_VERSION );
		return array( 'alpha-countdown' );
	}

	/**
	 * Get the script depends.
	 *
	 * @since 1.0.0
	 */
	public function get_script_depends() {
		wp_register_script( 'jquery-countdown', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/countdown/jquery.countdown.min.js', array(), false, true );
		wp_register_script( 'alpha-countdown', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/countdown/countdown' . ALPUS_PLUGIN_JS_SUFFIX, array( 'jquery-countdown' ), ALPUS_ELEMENTOR_ADDON_VERSION, true );
		return array( 'jquery-countdown', 'alpha-countdown' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_countdown',
			array(
				'label' => esc_html__( 'Countdown', 'alpus-elementor-addon' ),
			)
		);
		$this->add_control(
			'align',
			array(
				'label'       => esc_html__( 'Alignment', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Determine where the countdown is located, left, center or right.​', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::CHOOSE,
				'toggle'      => false,
				'default'     => 'flex-start',
				'options'     => array(
					'flex-start' => array(
						'title' => esc_html__( 'Left', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-text-align-left',
					),
					'center'     => array(
						'title' => esc_html__( 'Center', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-text-align-center',
					),
					'flex-end'   => array(
						'title' => esc_html__( 'Right', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-text-align-right',
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .countdown-container' => 'justify-content: {{VALUE}}',
				),
			)
		);
		$this->add_control(
			'type',
			array(
				'label'       => esc_html__( 'Type', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Select countdown type from block and inline types.​', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'block',
				'options'     => array(
					'block'  => esc_html__( 'Block', 'alpus-elementor-addon' ),
					'inline' => esc_html__( 'Inline', 'alpus-elementor-addon' ),
				),
			)
		);
		$this->add_control(
			'date',
			array(
				'label'       => esc_html__( 'Target Date', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Set the certain date the countdown element will count down to.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::DATE_TIME,
				'default'     => date( 'Y-m-d H:i:s', strtotime( '+1 day' ) ),
			)
		);
		$this->add_control(
			'timezone',
			array(
				'label'       => esc_html__( 'Timezone', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Allows you to specify which timezone is used, the sites or the viewer timezone.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '',
				'options'     => array(
					''              => esc_html__( 'WordPress Defined Timezone', 'alpus-elementor-addon' ),
					'user_timezone' => esc_html__( 'User System Timezone', 'alpus-elementor-addon' ),
				),
			)
		);
		$this->add_control(
			'label',
			array(
				'label'       => esc_html__( 'Label', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Set label text.​', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Offer Ends In',
				'condition'   => array(
					'type' => 'inline',
				),
			)
		);
		$this->add_control(
			'label_type',
			array(
				'label'       => esc_html__( 'Unit Type', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Select time unit type from full and short. The default type is the full type.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '',
				'options'     => array(
					''      => esc_html__( 'Full', 'alpus-elementor-addon' ),
					'short' => esc_html__( 'Short', 'alpus-elementor-addon' ),
				),
				'condition'   => array(
					'type' => 'block',
				),
			)
		);
		$this->add_control(
			'label_pos',
			array(
				'label'       => esc_html__( 'Unit Position', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Select unit position from inner, outer and custom. The default position is inner.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '',
				'options'     => array(
					''       => esc_html__( 'Inner', 'alpus-elementor-addon' ),
					'outer'  => esc_html__( 'Outer', 'alpus-elementor-addon' ),
					'custom' => esc_html__( 'Custom', 'alpus-elementor-addon' ),
				),
				'condition'   => array(
					'type' => 'block',
				),
			)
		);

		$this->add_control(
			'label_dimension',
			array(
				'label'       => esc_html__( 'Custom Position', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls custom poistion of unit.​', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SLIDER,
				'size_units'  => array(
					'px',
					'%',
				),
				'range'       => array(
					'px' => array(
						'step' => 1,
						'min'  => -50,
						'max'  => 50,
					),
					'%'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
				),
				'selectors'   => array(
					'{{WRAPPER}} .countdown .countdown-period' => 'bottom: {{SIZE}}{{UNIT}};',
				),
				'condition'   => array(
					'type'      => 'block',
					'label_pos' => 'custom',
				),
			)
		);

		$this->add_control(
			'date_format',
			array(
				'label'       => esc_html__( 'Units', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Allows to show or hide the amount of time aspects used in the countdown element.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SELECT2,
				'multiple'    => true,
				'default'     => array(
					'D',
					'H',
					'M',
					'S',
				),
				'options'     => array(
					'Y' => esc_html__( 'Year', 'alpus-elementor-addon' ),
					'O' => esc_html__( 'Month', 'alpus-elementor-addon' ),
					'W' => esc_html__( 'Week', 'alpus-elementor-addon' ),
					'D' => esc_html__( 'Day', 'alpus-elementor-addon' ),
					'H' => esc_html__( 'Hour', 'alpus-elementor-addon' ),
					'M' => esc_html__( 'Minute', 'alpus-elementor-addon' ),
					'S' => esc_html__( 'Second', 'alpus-elementor-addon' ),
				),
			)
		);
		$this->add_control(
			'hide_split',
			array(
				'label'       => esc_html__( 'Hide Separator', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Allows you to show or hide the splitters between time amounts.​', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::SWITCHER,
				'condition'   => array(
					'type' => 'block',
				),
			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'countdown_dimension',
			array(
				'label' => esc_html__( 'Dimension', 'alpus-elementor-addon' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_responsive_control(
			'item_padding',
			array(
				'label'       => esc_html__( 'Item Padding', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the padding of each countdown section.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => array(
					'px',
					'%',
					'em',
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .countdown-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'condition'   => array(
					'type' => 'block',
				),
			)
		);

		$this->add_responsive_control(
			'item_spacing',
			array(
				'label'       => esc_html__( 'Item Spacing (px)', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls spacing of each countdown section.​', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::NUMBER,
				'default'     => '20',
				'selectors'   => array(
					'.elementor-element-{{ID}} .countdown' => '--alpha-countdown-section-gap: {{VALUE}}px;',
				),
				'condition'   => array(
					'type' => 'block',
				),
			)
		);

		$this->add_control(
			'label_margin',
			array(
				'label'      => esc_html__( 'Label Margin', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => array(
					'px',
					'rem',
				),
				'selectors'  => array(
					'.elementor-element-{{ID}} .countdown-label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'condition'  => array(
					'type' => 'inline',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'countdown_typography',
			array(
				'label' => esc_html__( 'Typography', 'alpus-elementor-addon' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'      => 'countdown_label',
				'label'     => esc_html__( 'Label', 'alpus-elementor-addon' ),
				'selector'  => '.elementor-element-{{ID}} .countdown-label',
				'condition' => array( 'type' => 'inline' ),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'countdown_amount',
				'label'    => esc_html__( 'Amount', 'alpus-elementor-addon' ),
				'selector' => '.elementor-element-{{ID}} .countdown-container .countdown-amount',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'      => 'countdown_unit',
				'label'     => esc_html__( 'Unit', 'alpus-elementor-addon' ),
				'selector'  => '.elementor-element-{{ID}} .countdown-period',
				'condition' => array( 'type' => 'block' ),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'      => 'countdown_separator',
				'label'     => esc_html__( 'Separator', 'alpus-elementor-addon' ),
				'selector'  => '.elementor-element-{{ID}} .countdown-section:not(:last-child):after',
				'condition' => array(
					'type'       => 'block',
					'hide_split' => '',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'countdown_color',
			array(
				'label' => esc_html__( 'Color', 'alpus-elementor-addon' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'countdown_section_color',
			array(
				'label'       => esc_html__( 'Section Background', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the backgorund color of the countdown section.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .countdown-section' => 'background: {{VALUE}};',
				),
				'condition'   => array(
					'type' => 'block',
				),
			)
		);

		$this->add_control(
			'countdown_label_color',
			array(
				'label'       => esc_html__( 'Label', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the color of the countdown label.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .countdown-label'  => 'color: {{VALUE}};',
				),
				'condition'   => array( 'type' => 'inline' ),
			)
		);

		$this->add_control(
			'countdown_amount_color',
			array(
				'label'       => esc_html__( 'Amount', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the color of the countdown amount.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .countdown-amount' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'countdown_unit_color',
			array(
				'label'       => esc_html__( 'Unit', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the color of the countdown unit.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'.elementor-element-{{ID}} .countdown-period' => 'color: {{VALUE}};',
				),
				'condition'   => array( 'type' => 'block' ),
			)
		);

		$this->add_control(
			'countdown_separator_color',
			array(
				'label'       => esc_html__( 'Separator', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the color of the countdown separator.', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => array(
					'{{WRAPPER}} .countdown-section:after' => 'color: {{VALUE}};',
				),
				'condition'   => array(
					'type'       => 'block',
					'hide_split' => '',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'countdown_border',
			array(
				'label'     => esc_html__( 'Border', 'alpus-elementor-addon' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => array(
					'type' => 'block',
				),
			)
		);

		$this->add_control(
			'border',
			array(
				'label'     => _x( 'Border Type', 'Border Control', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => array(
					''       => esc_html__( 'None', 'alpus-elementor-addon' ),
					'solid'  => _x( 'Solid', 'Border Control', 'alpus-elementor-addon' ),
					'double' => _x( 'Double', 'Border Control', 'alpus-elementor-addon' ),
					'dotted' => _x( 'Dotted', 'Border Control', 'alpus-elementor-addon' ),
					'dashed' => _x( 'Dashed', 'Border Control', 'alpus-elementor-addon' ),
					'groove' => _x( 'Groove', 'Border Control', 'alpus-elementor-addon' ),
				),
				'selectors' => array(
					'.elementor-element-{{ID}} .countdown-section' => 'border-style: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'border-width',
			array(
				'label'      => _x( 'Width', 'Border Control', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'selectors'  => array(
					'.elementor-element-{{ID}} .countdown-section' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'.elementor-element-{{ID}} .countdown-section:not(:last-child):after' => 'padding-left: {{LEFT}}{{UNIT}};padding-right: {{RIGHT}}{{UNIT}}',
					'.elementor-element-{{ID}} .countdown.outer-period .countdown-period' => 'padding-top: {{BOTTOM}}{{UNIT}};',
				),
				'condition'  => array(
					'border!' => '',
				),
				'responsive' => true,
			)
		);

		$this->add_control(
			'border-color',
			array(
				'label'     => _x( 'Color', 'Border Control', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'.elementor-element-{{ID}} .countdown-section' => 'border-color: {{VALUE}};',
				),
				'condition' => array(
					'border!' => '',
				),
			)
		);

		$this->add_control(
			'border-radius',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Border-radius', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the border radius of the countdown section.', 'alpus-elementor-addon' ),
				'size_units'  => array(
					'px',
					'%',
				),
				'range'       => array(
					'%'  => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
					'px' => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .countdown-section' => 'border-radius: {{SIZE}}{{UNIT}};',
				),
			)
		);
	}

	protected function render() {
		$atts = $this->get_settings_for_display();
		require ALPUS_ELEMENTOR_ADDON_PATH . '/inc/widgets/countdown/render-countdown-elementor.php';
	}

	protected function content_template() {
		?>
		<#

		var html = '',
			className = '';	

		if ( settings.date ) {			
			className = 'countdown';

			if ( settings.label_pos ) {
				className += ' outer-period';
			}
			if ( settings.timezone ) {
				className += ' user-tz';
			}
			if ( settings.hide_split ) {
				className += ' no-split';
			}

			var format = '';
			if ( settings.date_format.length > 0 ) {
				settings.date_format.forEach(function(f) {
					format += f;
				});
			} else {
				format = settings.date_format.replace(',', '');
			}

			html += '<div class="countdown-container ' + settings.type + '-type">';

			view.addInlineEditingAttributes( 'label' );
			view.addRenderAttribute( 'label', 'class', 'countdown-label' );
			if ( 'inline' == settings.type ) {
				html += '<label ' + view.getRenderAttributeString( 'label' ) + '>' + settings.label + '</label>';
			}

			var options = {
				year: 'numeric', month: 'numeric', day: 'numeric',
				hour: 'numeric', minute: 'numeric', second: 'numeric',
				hour12: false,
			};
			html += '<div class="' + className + '" data-until="' + settings.date + '" data-relative="" ' + ('inline' == settings.type ? 'data-compact="true" ' : ' ') + ('short' == settings.label_type ? 'data-labels-short="true" ' : ' ') + 'data-format="' + format + '" data-time-now="<?php echo esc_attr( str_replace( '-', '/', current_time( 'mysql' ) ) ); ?>">';

			if ( 'block' == settings.type ) {
				html += '<span class="countdown-row countdown-show ' + settings.date_format.length + '">';
				

				formats = 'short' == settings.label_type ? {
					Y: <?php echo json_encode( esc_html__( 'Years', 'alpus-elementor-addon' ) ); ?>,
					O: <?php echo json_encode( esc_html__( 'Months', 'alpus-elementor-addon' ) ); ?>,
					W: <?php echo json_encode( esc_html__( 'Weeks', 'alpus-elementor-addon' ) ); ?>,
					D: <?php echo json_encode( esc_html__( 'Days', 'alpus-elementor-addon' ) ); ?>,
					H: <?php echo json_encode( esc_html__( 'Hours', 'alpus-elementor-addon' ) ); ?>,
					M: <?php echo json_encode( esc_html__( 'Mins', 'alpus-elementor-addon' ) ); ?>,
					S: <?php echo json_encode( esc_html__( 'Secs', 'alpus-elementor-addon' ) ); ?>
				} : {
					Y: <?php echo json_encode( esc_html__( 'Years', 'alpus-elementor-addon' ) ); ?>,
					O: <?php echo json_encode( esc_html__( 'Months', 'alpus-elementor-addon' ) ); ?>,
					W: <?php echo json_encode( esc_html__( 'Weeks', 'alpus-elementor-addon' ) ); ?>,
					D: <?php echo json_encode( esc_html__( 'Days', 'alpus-elementor-addon' ) ); ?>,
					H: <?php echo json_encode( esc_html__( 'Hours', 'alpus-elementor-addon' ) ); ?>,
					M: <?php echo json_encode( esc_html__( 'Minutes', 'alpus-elementor-addon' ) ); ?>,
					S: <?php echo json_encode( esc_html__( 'Seconds', 'alpus-elementor-addon' ) ); ?>
				};

				if ( settings.date_format.length ) {
					settings.date_format.forEach(function(f) {;
						html += '<span class="countdown-section"><span class="countdown-amount">00</span><span class="countdown-period">' + formats[f] + '</span></span>';
					})
				}

				html += '</span>';
			} else {
				html += '00 : 00 : 00';
			}
		}

		html += '</div>';
		html += '</div>';

		print( html );
		#>
		<?php
	}

}
