<?php
/**
 *  Filter Widget
 *
 *  Widget to display filter for products.
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0.0
 */

defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Repeater;
use Elementor\Group_Control_Border;
use Elementor\Alpha_Controls_Manager;

class Alpha_Filter_Elementor_Widget extends \Elementor\Widget_Base {
	public $attributes;

	public function get_name() {
		return ALPHA_NAME . '_widget_filter';
	}

	public function get_title() {
		return esc_html__( 'Advanced Filter', 'alpus-elementor-addon' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon eicon-filter';
	}

	public function get_categories() {
		return array( 'alpha_addon_widget' );
	}

	public function get_keywords() {
		return array( 'filter', 'product', 'attribute', 'category', 'tag', 'search' );
	}

	/**
	 * Get the style depends.
	 *
	 * @since 1.0
	 */
	public function get_style_depends() {
		wp_register_style( 'alpha-filter', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/filter/filter' . ( is_rtl() ? '-rtl' : '' ) . '.min.css', array(), ALPUS_ELEMENTOR_ADDON_VERSION );
		return array( 'alpus-elementor-addon-button', 'alpha-filter' );
	}

	public function get_script_depends() {
		wp_register_script( 'alpha-filter', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/filter/filter' . ALPUS_PLUGIN_JS_SUFFIX, array(), ALPUS_ELEMENTOR_ADDON_VERSION, true );
		return array( 'alpha-shop', 'alpha-filter' );
	}

	protected function register_controls() {

		$post_types          = get_post_types(
			array(
				'public'            => true,
				'show_in_nav_menus' => true,
			),
			'objects',
			'and'
		);
		$disabled_post_types = array( 'attachment', ALPHA_NAME . '_template', 'page', 'e-landing-page' );
		foreach ( $disabled_post_types as $disabled ) {
			unset( $post_types[ $disabled ] );
		}
		foreach ( $post_types as $key => $p_type ) {
			$post_types[ $key ] = esc_html( $p_type->label );
		}
		$post_types = apply_filters( 'alpha_posts_grid_post_types', $post_types );

		$taxes = get_taxonomies( array(), 'objects' );
		unset( $taxes['post_format'], $taxes['product_visibility'] );
		foreach ( $taxes as $tax_name => $tax ) {
			$taxes[ $tax_name ] = esc_html( $tax->label );
		}
		$taxes = apply_filters( 'alpha_posts_grid_taxonomies', $taxes );

		$left  = is_rtl() ? 'right' : 'left';
		$right = 'left' == $left ? 'right' : 'left';

		$this->start_controls_section(
			'section_filter_content',
			array(
				'label' => esc_html__( 'Filter', 'alpus-elementor-addon' ),
			)
		);

		$this->add_control(
			'post_type',
			array(
				'type'        => Controls_Manager::SELECT,
				'label'       => esc_html__( 'Filter Post Type', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Please select a post type of posts to filter.', 'alpus-elementor-addon' ),
				'options'     => $post_types,
			)
		);

		// $this->add_control(
		// 	'query_opt',
		// 	array(
		// 		'label'       => esc_html__( 'Query Type', 'alpus-elementor-addon' ),
		// 		'description' => esc_html__( 'Select query type.', 'alpus-elementor-addon' ),
		// 		'type'        => Controls_Manager::SELECT,
		// 		'options'     => array(
		// 			'and' => esc_html__( 'AND', 'alpus-elementor-addon' ),
		// 			'or'  => esc_html__( 'OR', 'alpus-elementor-addon' ),
		// 		),
		// 		'default'     => 'and',
		// 	)
		// );

		$repeater = new Repeater();

		$repeater->add_control(
			'filter_type',
			array(
				'type'        => Alpha_Controls_Manager::SELECT,
				'label'       => esc_html__( 'Type', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Select one of filter item type from search or taxonomy.', 'alpus-elementor-addon' ),
				'default'     => 'taxonomy',
				'options'     => array(
					'search'   => esc_html__( 'Search', 'alpus-elementor-addon' ),
					'taxonomy' => esc_html__( 'Taxonomy', 'alpus-elementor-addon' ),
				),
			)
		);

		$repeater->add_control(
			'post_tax',
			array(
				'type'        => Alpha_Controls_Manager::AJAXSELECT2,
				'label'       => esc_html__( 'Taxonomy', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Please select a post taxonomy to pull posts from.', 'alpus-elementor-addon' ),
				'options'     => '%post_type%_alltax',
				'label_block' => true,
				'condition'   => array(
					'filter_type' => 'taxonomy',
				),
			)
		);

		$repeater->add_responsive_control(
			'filter_width',
			array(
				'type'        => Controls_Manager::SLIDER,
				'label'       => esc_html__( 'Width (%)', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Controls the width of the filter item.', 'alpus-elementor-addon' ),
				'default'     => array(
					'size' => '',
					'unit' => '%',
				),
				'size_units'  => array(
					'%',
				),
				'range'       => array(
					'%' => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} {{CURRENT_ITEM}}' => 'width: {{SIZE}}%;',
				),
			)
		);

		$repeater->add_control(
			'search_placeholder',
			array(
				'type'      => Alpha_Controls_Manager::TEXT,
				'label'     => esc_html__( 'Placeholder', 'alpus-elementor-addon' ),
				'default'   => esc_html__( 'Enter your keyword...', 'alpus-elementor-addon' ),
				'condition' => array(
					'filter_type' => 'search',
				),
			)
		);

		$repeater->add_control(
			'dropdown_title',
			array(
				'type'        => Alpha_Controls_Manager::TEXT,
				'label'       => esc_html__( 'Dropdown Title', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Enter your title to show when no terms are selected in taxonomy dropdown.', 'alpus-elementor-addon' ),
				'condition'   => array(
					'filter_type' => 'taxonomy',
				),
			)
		);

		$presets = array(
			array(
				'filter_type' => 'search',
			),
			array(
				'filter_type' => 'taxonomy',
			),
		);

		$this->add_control(
			'filter_items',
			array(
				'label'       => esc_html__( 'Filter Items', 'alpus-elementor-addon' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => $presets,
				'title_field' => sprintf( '{{{ filter_type == "search" ? \'%1$s\' : post_tax }}}', esc_html__( 'Search', 'alpus-elementor-addon' ) ),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_button_content',
			array(
				'label' => esc_html__( 'Button', 'alpus-elementor-addon' ),
			)
		);

		$this->add_responsive_control(
			'button_width',
			array(
				'label'      => esc_html__( 'Width (%)', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array(
					'%',
				),
				'range'      => array(
					'%' => array(
						'step' => 1,
						'min'  => 0,
						'max'  => 100,
					),
				),
				'selectors'  => array(
					'{{WRAPPER}} .form-field-button' => 'width: {{SIZE}}%;',
				),
			)
		);

		$this->add_control(
			'button_label',
			array(
				'label'   => esc_html__( 'Label', 'alpus-elementor-addon' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Search', 'alpus-elementor-addon' ),
			)
		);

		alpha_elementor_button_layout_controls( $this );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_filter_style',
			array(
				'label' => esc_html__( 'Filter', 'alpus-elementor-addon' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

			$this->add_control(
				'filter_gap',
				array(
					'type'        => Controls_Manager::SLIDER,
					'label'       => esc_html__( 'Gap Spacing', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls the size of spacing between filter items.', 'alpus-elementor-addon' ),
					'default'     => array(
						'size' => '',
						'unit' => 'px',
					),
					'size_units'  => array(
						'px',
					),
					'range'       => array(
						'px' => array(
							'step' => 1,
							'min'  => 0,
							'max'  => 60,
						),
					),
					'render_type' => 'template',
					'selectors'   => array(
						'.elementor-element-{{ID}} .alpha-filters' => '--alpha-gap: calc({{SIZE}}{{UNIT}} / 2);',
					),
				)
			);

			$this->add_control(
				'filter_item_height',
				array(
					'type'        => Controls_Manager::SLIDER,
					'label'       => esc_html__( 'Filter Item Height (px)', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls the height of filter items.', 'alpus-elementor-addon' ),
					'default'     => array(
						'size' => '',
						'unit' => 'px',
					),
					'size_units'  => array(
						'px',
					),
					'range'       => array(
						'px' => array(
							'step' => 1,
							'min'  => 0,
							'max'  => 100,
						),
					),
					'selectors'   => array(
						'.elementor-element-{{ID}} .filter-form-field' => 'height: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_responsive_control(
				'filter_item_padding',
				array(
					'label'       => esc_html__( 'Filter Item Padding', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls padding of filter items.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::DIMENSIONS,
					'default'     => array(
						'unit' => 'px',
					),
					'size_units'  => array( 'px', '%', 'em' ),
					'selectors'   => array(
						'.elementor-element-{{ID}} .filter-form-field > *' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				)
			);

		$this->end_controls_section();

		alpha_elementor_button_style_controls( $this );

		$this->remove_control( 'btn_min_width' );
	}

	protected function render() {
		$atts = $this->get_settings_for_display();
		$this->add_inline_editing_attributes( 'button_label' );

		require ALPUS_ELEMENTOR_ADDON_PATH . '/inc/widgets/filter/render-filter.php';
	}
}
