<?php
defined( 'ABSPATH' ) || die;

/**
 *  Scroll Button Widget
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0
 */

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;

class Alpha_Scroll_Button_Elementor_Widget extends \Elementor\Widget_Base {

	public function get_name() {
		return ALPHA_NAME . '_widget_scroll_button';
	}

	public function get_title() {
		return esc_html__( 'Scroll Button', 'alpus-elementor-addon' );
	}

	public function get_categories() {
		return array( 'alpha_addon_widget' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon eicon-scroll';
	}

	public function get_keywords() {
		return array( 'button', 'scroll', 'page scroll', 'alpha' );
	}

	public function get_style_depends() {
		wp_register_style( 'alpha-page-scroll', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/scroll-button/scroll-button.min.css', array(), ALPUS_ELEMENTOR_ADDON_VERSION );
		return array( 'alpha-page-scroll' );
	}

	public function get_script_depends() {
		return array();
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			array(
				'label' => esc_html__( 'Scroll Button', 'alpus-elementor-addon' ),
			)
		);

			$this->add_control(
				'scroll_target',
				array(
					'type'        => Controls_Manager::TEXT,
					'label'       => esc_html__( 'Target Selector', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Input target\'s selector to scroll.' ),
				)
			);

			$this->add_responsive_control(
				'button_size',
				array(
					'label'       => esc_html__( 'Size', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls the size of button.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SLIDER,
					'range'       => array(
						'px' => array(
							'min' => 0,
							'max' => 100,
						),
					),
					'selectors'   => array(
						'.elementor-element-{{ID}} .scroll-btn' => '--alpha-scroll-btn-size: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'button_border_width',
				array(
					'label'     => esc_html__( 'Border Width', 'alpus-elementor-addon' ),
					'type'      => Controls_Manager::SLIDER,
					'range'     => array(
						'px' => array(
							'min' => 0,
							'max' => 100,
						),
					),
					'selectors' => array(
						'.elementor-element-{{ID}} .scroll-btn' => 'border-width: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'button_border_radius',
				array(
					'label'      => esc_html__( 'Border Radius', 'alpus-elementor-addon' ),
					'type'       => Controls_Manager::SLIDER,
					'size_units' => array(
						'px',
						'rem',
						'%',
					),
					'range'      => array(
						'px' => array(
							'min' => 0,
							'max' => 100,
						),
					),
					'selectors'  => array(
						'.elementor-element-{{ID}} .scroll-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'button_border_color',
				array(
					'label'       => esc_html__( 'Border Color', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls the border color of the button.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::COLOR,
					'selectors'   => array(
						'.elementor-element-{{ID}} .scroll-btn' => 'border-color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'button_bg_color',
				array(
					'label'       => esc_html__( 'Background Color', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls the background color of the button.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::COLOR,
					'selectors'   => array(
						'.elementor-element-{{ID}} .scroll-btn' => 'background-color: {{VALUE}};',
					),
				)
			);

			$this->add_responsive_control(
				'dot_size',
				array(
					'label'       => esc_html__( 'Dot Size', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls the size of dot inside of the button.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::SLIDER,
					'range'       => array(
						'px' => array(
							'min' => 0,
							'max' => 100,
						),
					),
					'selectors'   => array(
						'.elementor-element-{{ID}} .scroll-btn' => '--alpha-scroll-btn-dot-size: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'dot_bg_color',
				array(
					'label'       => esc_html__( 'Dot Color', 'alpus-elementor-addon' ),
					'description' => esc_html__( 'Controls the background color of inside of the button.', 'alpus-elementor-addon' ),
					'type'        => Controls_Manager::COLOR,
					'selectors'   => array(
						'.elementor-element-{{ID}} .scroll-btn:before' => 'background-color: {{VALUE}};',
					),
				)
			);

		$this->end_controls_section();
	}

	protected function render() {
		$atts = $this->get_settings_for_display();
		require ALPUS_ELEMENTOR_ADDON_PATH . '/inc/widgets/scroll-button/render-scroll-button-elementor.php';
	}
}
