<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Sticky Nav Element
 *
 * @author     AlpusTheme
 * @package    Alpus Elementor Addon
 * @subpackage Addon
 * @since      1.0
 */

use Elementor\Controls_Manager;

class Alpha_Sticky_Nav_Elementor_Widget extends \Elementor\Widget_Base {

	public function get_name() {
		return ALPHA_NAME . '_widget_sticky_nav';
	}

	public function get_title() {
		return esc_html__( 'Sticky Navigation', 'alpus-elementor-addon' );
	}

	public function get_categories() {
		return array( 'alpha_addon_widget' );
	}

	public function get_keywords() {
		return array( 'sticky', 'navigation', 'menu', 'nav' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon eicon-navigation-horizontal';
	}

	/**
	 * Get the style depends.
	 *
	 * @since 1.0
	 */
	public function get_style_depends() {
		wp_register_style( 'alpha-sticky-nav', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/sticky-nav/sticky-nav' . ( is_rtl() ? '-rtl' : '' ) . '.min.css', array(), ALPUS_ELEMENTOR_ADDON_VERSION );
		return array( 'alpha-sticky-nav' );
	}

	public function get_script_depends() {
		wp_register_script( 'alpha-sticky-nav', ALPUS_ELEMENTOR_ADDON_URI . '/inc/widgets/sticky-nav/sticky-nav' . ALPUS_PLUGIN_JS_SUFFIX, array( 'jquery-core' ), ALPUS_ELEMENTOR_ADDON_VERSION, true );
		return array( 'alpha-sticky-nav' );
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_sticky_nav',
			array(
				'label' => esc_html__( 'Sticky Navigation', 'alpus-elementor-addon' ),
			)
		);

		$this->add_control(
			'show_type',
			array(
				'label'       => esc_html__( 'Show Type', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Determine whether to arrange navs horizontally or vertically.', 'alpus-elementor-addon' ),
				'default'     => '',
				'type'        => Controls_Manager::CHOOSE,
				'options'     => array(
					''             => array(
						'title' => esc_html__( 'Horizontal', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-ellipsis-h',
					),
					'vertical-nav' => array(
						'title' => esc_html__( 'Vertical', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-ellipsis-v',
					),
				),
			),
		);
		$repeater = new Elementor\Repeater();

		$repeater->start_controls_tabs(
			'sticky_nav_items'
		);

		$repeater->add_control(
			'label',
			array(
				'type'  => Controls_Manager::TEXT,
				'label' => esc_html__( 'Label', 'alpus-elementor-addon' ),
			)
		);

		$repeater->add_control(
			'tooltip',
			array(
				'type'  => Controls_Manager::TEXT,
				'label' => esc_html__( 'Tooltip', 'alpus-elementor-addon' ),
			)
		);

		$repeater->add_control(
			'link',
			array(
				'type'  => Controls_Manager::URL,
				'label' => esc_html__( 'Link', 'alpus-elementor-addon' ),
			)
		);
		$repeater->add_control(
			'icon_cl',
			array(
				'type'                   => Controls_Manager::ICONS,
				'label'                  => esc_html__( 'Icon', 'alpus-elementor-addon' ),
				'fa4compatibility'       => 'icon',
				'default'                => array(
					'value'   => 'fas fa-star',
					'library' => 'fa-solid',
				),
				'skin'                   => 'inline',
				'exclude_inline_options' => array( 'svg' ),
				'label_block'            => false,
			)
		);

		$repeater->end_controls_tab();

		$repeater->end_controls_tabs();

		$presets = array(
			array(
				'label' => esc_html__( 'Item 1', 'alpus-elementor-addon' ),
				'link'  => '#',
			),
			array(
				'label' => esc_html__( 'Item 2', 'alpus-elementor-addon' ),
				'link'  => '#',
			),
		);
		$this->add_control(
			'sticky_nav_item_list',
			array(
				'label'   => esc_html__( 'Sticky Nav Items', 'alpus-elementor-addon' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => $presets,
			)
		);

		$this->add_control(
			'show_icon',
			array(
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Show Icon', 'alpus-elementor-addon' ),
				'condition' => array(
					'hide_label!' => 'yes',
				),
			)
		);

		$this->add_control(
			'hide_label',
			array(
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Show as tooltip?', 'alpus-elementor-addon' ),
				'condition' => array(
					'show_icon' => 'yes',
				),
			)
		);

		$this->add_control(
			'is_sticky',
			array(
				'type'    => Controls_Manager::SWITCHER,
				'label'   => esc_html__( 'Is Sticky?', 'alpus-elementor-addon' ),
				'default' => 'yes',
			)
		);

		$this->add_control(
			'tooltip_type',
			array(
				'label'     => esc_html__( 'Tooltip Type', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => '',
				'options'   => array(
					''           => esc_html__( 'Type 1', 'alpus-elementor-addon' ),
					'rect-hover' => esc_html__( 'Type 2', 'alpus-elementor-addon' ),
				),
				'condition' => array(
					'show_type'  => 'vertical-nav',
					'hide_label' => 'yes',
				),
			)
		);

		$this->add_control(
			'min_width',
			array(
				'type'        => Controls_Manager::NUMBER,
				'label'       => esc_html__( 'Min Width (unit: px)', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Will be disable sticky if window width is smaller than min width', 'alpus-elementor-addon' ),
				'min'         => 320,
				'max'         => 1920,
				'default'     => 991,
				'condition'   => array(
					'show_type' => '',
					'is_sticky' => 'yes',
				),
			)
		);

		$this->add_control(
			'top_space',
			array(
				'type'        => Controls_Manager::NUMBER,
				'label'       => esc_html__( 'Top Space (unit: px)', 'alpus-elementor-addon' ),
				'description' => esc_html__( 'Set the top space of sticky nav', 'alpus-elementor-addon' ),
				'min'         => 0,
				'max'         => 100,
				'default'     => 0,
				'size_units'  => array(
					'px',
				),
				'selectors'   => array(
					'.elementor-element-{{ID}} .sticky-content.fixed' => 'top: {{VALUE}}px;',
				),
				'condition'   => array(
					'show_type' => '',
					'is_sticky' => 'yes',
				),
			)
		);

		$this->add_control(
			'alignment',
			array(
				'label'     => esc_html__( 'Alignment', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::CHOOSE,
				'default'   => 'center',
				'options'   => array(
					'left'   => array(
						'title' => esc_html__( 'Left', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-h-align-left',
					),
					'center' => array(
						'title' => esc_html__( 'Center', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-h-align-center',
					),
					'right'  => array(
						'title' => esc_html__( 'Right', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs' => 'text-align: {{VALUE}};',
				),
				'condition' => array(
					'show_type' => '',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_general_style',
			array(
				'label' => esc_html__( 'General', 'alpus-elementor-addon' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_responsive_control(
			'nav_box_padding',
			array(
				'label'      => esc_html__( 'Nav Box Padding', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'selectors'  => array(
					'.elementor-element-{{ID}} .sticky-navs' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units' => array( 'px', 'em', 'rem' ),
			)
		);

		$this->add_control(
			'nav_box_bg_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Nav Box Background Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_item_style',
			array(
				'label'      => esc_html__( 'Item', 'alpus-elementor-addon' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			)
		);

		$this->start_controls_tabs( 'tabs_link_color' );

		$this->start_controls_tab(
			'link_color_normal',
			array(
				'label' => esc_html__( 'Normal', 'alpus-elementor-addon' ),
			)
		);

		$this->add_control(
			'link_color1',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Link Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs > li > a' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'link_bg_color1',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Link Background Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .nav-wrapper .sticky-navs > li > a' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'link_color_hover',
			array(
				'label' => esc_html__( 'Hover', 'alpus-elementor-addon' ),
			)
		);

		$this->add_control(
			'link_hover_color1',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Link Hover Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs > li > a:hover' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'link_hbg_color1',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Link Hover Background Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs > li > a:hover' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'link_color_active',
			array(
				'label' => esc_html__( 'Active', 'alpus-elementor-addon' ),
			)
		);

		$this->add_control(
			'link_acolor1',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Link Active Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs > li.active > a' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'link_abg_color1',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Link Active Background Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs > li.active > a' => 'background-color: {{VALUE}};',
				),
			)
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_responsive_control(
			'link_padding',
			array(
				'label'      => esc_html__( 'Link Padding', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'selectors'  => array(
					'.elementor-element-{{ID}} .sticky-navs > li > a.sticky-nav-item, .elementor-element-{{ID}} .sticky-navs > li > span.sticky-nav-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units' => array( 'px', 'em', 'rem' ),
			)
		);

		$this->add_responsive_control(
			'link_margin',
			array(
				'label'      => esc_html__( 'Link Margin', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'selectors'  => array(
					'.elementor-element-{{ID}} .sticky-navs > li > a, .elementor-element-{{ID}} .sticky-navs > li > span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units' => array( 'px', 'em', 'rem' ),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'label_style',
			array(
				'label' => esc_html__( 'Label', 'alpus-elementor-addon' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'typography',
				'label'    => esc_html__( 'Label Typograhy', 'alpus-elementor-addon' ),
				'selector' => '.elementor-element-{{ID}} .sticky-navs li .sticky-nav-item span',
			)
		);

		$this->add_control(
			'tooltip_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Tooltip Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs li .sticky-nav-item span' => 'color: {{VALUE}};',
				),
				'condition' => array(
					'hide_label' => 'yes',
				),
			)
		);

		$this->add_control(
			'tooltip_bg_color',
			array(
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Tooltip Background Color', 'alpus-elementor-addon' ),
				'selectors' => array(
					'.elementor-element-{{ID}} .hide-label:not(.rect-hover) .sticky-nav-item span' => 'background-color: {{VALUE}};',
					'.elementor-element-{{ID}} .hide-label:not(.rect-hover) .sticky-nav-item span:before' => 'background-color: {{VALUE}};',

				),
				'condition' => array(
					'hide_label'   => 'yes',
					'tooltip_type' => '',
				),
			)
		);

		$this->add_responsive_control(
			'label_padding',
			array(
				'label'      => esc_html__( 'Label Padding', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'selectors'  => array(
					'.elementor-element-{{ID}} .sticky-navs li .sticky-nav-item span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'size_units' => array( 'px', 'em', 'rem' ),
				'condition'  => array(
					'hide_label'   => 'yes',
					'tooltip_type' => '',
				),
			)
		);

		$this->add_responsive_control(
			'label_hover_padding',
			array(
				'label'              => esc_html__( 'Label Hover Padding', 'alpus-elementor-addon' ),
				'type'               => Controls_Manager::DIMENSIONS,
				'description'        => esc_html__( 'Control the padding left & right of hovered label.', 'alpus-elementor-addon' ),
				'allowed_dimensions' => 'horizontal',
				'placeholder'        => array(
					'top'    => '0',
					'right'  => '',
					'bottom' => '0',
					'left'   => '',
				),
				'selectors'          => array(
					'.elementor-element-{{ID}} .sticky-navs li .sticky-nav-item:hover span' => 'padding-right: {{RIGHT}}{{UNIT}}; padding-left: {{LEFT}}{{UNIT}};',
				),
				'size_units'         => array( 'px', 'em', 'rem' ),
				'condition'          => array(
					'hide_label'   => 'yes',
					'tooltip_type' => 'rect-hover',
				),
			)
		);

		$this->add_responsive_control(
			'label_margin',
			array(
				'label'      => esc_html__( 'Label Margin', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'selectors'  => array(
					'.elementor-element-{{ID}} .sticky-navs li .sticky-nav-item span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
				'condition'  => array(
					'tooltip_type!' => 'rect-hover',
				),
				'size_units' => array( 'px', 'em', 'rem' ),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'icon_style',
			array(
				'label' => esc_html__( 'Icon', 'alpus-elementor-addon' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'icon_position',
			array(
				'label'     => esc_html__( 'Icon Position?', 'alpus-elementor-addon' ),
				'type'      => Controls_Manager::CHOOSE,
				'default'   => 'column',
				'options'   => array(
					'row'         => array(
						'title' => esc_html__( 'Left', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-h-align-left',
					),
					'column'      => array(
						'title' => esc_html__( 'Top', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-v-align-top',
					),
					'row-reverse' => array(
						'title' => esc_html__( 'Right', 'alpus-elementor-addon' ),
						'icon'  => 'eicon-h-align-right',
					),
				),
				'selectors' => array(
					'.elementor-element-{{ID}} .sticky-navs .sticky-nav-item' => 'flex-direction: {{VALUE}};',
				),
				'condition' => array(
					'hide_label!' => 'yes',
				),
			)
		);

		$this->add_control(
			'icon_size',
			array(
				'label'      => esc_html__( 'Icon Size (px)', 'alpus-elementor-addon' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array(
					'px',
				),
				'range'      => array(
					'px' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'selectors'  => array(
					'.elementor-element-{{ID}} .sticky-navs li .sticky-nav-item i' => 'font-size: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$this->end_controls_section();
	}

	protected function render() {
		$atts = $this->get_settings_for_display();

		require ALPUS_ELEMENTOR_ADDON_PATH . '/inc/widgets/sticky-nav/render-sticky-nav-elementor.php';
	}

	protected function content_template() {
		?>
		<#
		view.addRenderAttribute('nav-wrapper', 'class', 'fix-top sticky-nav-container');
		if ( 'yes' === settings.is_sticky ) {
			view.addRenderAttribute( 'nav-wrapper', 'class', 'sticky-content' );
		}
		view.addRenderAttribute( 'wrapper', 'class', 'nav-wrapper' );
		view.addRenderAttribute( 'wrapper', 'data-plugin-options', "{'minWidth': " + Number( settings.min_width ) + "}" );
		view.addRenderAttribute( 'nav', 'class', 'nav sticky-navs' );
		if( 'vertical-nav' === settings.show_type )  {
			view.addRenderAttribute( 'nav', 'class', 'vertical-nav' );
			if( settings.hide_label && 'rect-hover' === settings.tooltip_type ) {
				view.addRenderAttribute( 'nav', 'class', 'rect-hover' );
			}
		}
		if( settings.hide_label ) {
			view.addRenderAttribute( 'nav', 'class', 'hide-label' );
		}
		#>
		<div {{{ view.getRenderAttributeString( 'nav-wrapper' ) }}}>
			<div {{{ view.getRenderAttributeString( 'wrapper' ) }}}>
				<div class="container">
					<ul {{{ view.getRenderAttributeString( 'nav' ) }}}>
						<#
						_.each( settings.sticky_nav_item_list, function( item, index ) {
							if ( settings.show_icon || settings.hide_label ) {
								view.addRenderAttribute( 'nav-link', 'class', item.icon_cl.value, true );
							}
						if(item.icon_cl && item.icon_cl.value ) {
						#><li class="elementor-repeater-item-{{ item._id }}" title="{{item.tooltip}}">
							<# if(item.link.url) { #>
								<a href="{{item.link.url}}" class="sticky-nav-item" > <#
							} else {#>
							<span class="sticky-nav-item"> 
							<# } 
							let icon_html = elementor.helpers.renderIcon( view, item.icon_cl, { 'aria-hidden': true }, 'i' , 'object' );

							if( settings.show_icon || settings.hide_label ) {
								if ( icon_html && icon_html.rendered ) {
									print(icon_html.value);
								} else { #>
									<i {{{ view.getRenderAttributeString( 'nav-link' ) }}}></i>
								<# } 
							} if( item.label ) { #>
								<span>{{{ item.label }}}</span>
							<# } if(item.link.url) { #> </a> <# } else { #> </span> <# } #>
							</li><# 
						} } );
						#>
					</ul>
				</div>
			</div>
		</div>
		<?php
	}

}
