<?php
/*
Plugin Name: Alpus Elementor Addon
Plugin URI: https://alpustheme.com/
Description: Alpus Elementor Addon is a collection of slick, powerful widgets and features that work seamlessly with Elementor page builder for WordPress.
Version: 1.0.1
Author: AlpusTheme
Author URI: https://alpustheme.com/
Text Domain: alpus-elementor-addon
*/

// Direct load is not allowed
defined( 'ABSPATH' ) || die;

/**************************************/
/* Define Constants                   */
/**************************************/

defined( 'ALPHA_NAME' ) || define( 'ALPHA_NAME', 'alpha' );
defined( 'ALPHA_DISPLAY_NAME' ) || define( 'ALPHA_DISPLAY_NAME', 'Alpus' );
defined( 'ALPHA_ICON_PREFIX' ) || define( 'ALPHA_ICON_PREFIX', 'a' );
define( 'ALPUS_ELEMENTOR_ADDON_URI', untrailingslashit( plugin_dir_url( __FILE__ ) ) );               // Plugin directory uri
define( 'ALPUS_ELEMENTOR_ADDON_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );             // Plugin directory path
define( 'ALPUS_ELEMENTOR_ADDON_FILE', __FILE__ );                                                     // Plugin file path

if ( ! defined( 'ALPUS_ELEMENTOR_ADDON_VERSION' ) ) {
	define( 'ALPUS_ELEMENTOR_ADDON_VERSION', '1.0.0' );
}

define( 'ALPUS_ELEMENTOR_ADDON_ASSETS', ALPUS_ELEMENTOR_ADDON_URI . '/assets' );                                                // Template assets directory uri
define( 'ALPUS_ELEMENTOR_ADDON_CSS', ALPUS_ELEMENTOR_ADDON_ASSETS . '/css' );                                                   // Template css uri
define( 'ALPUS_ELEMENTOR_ADDON_JS', ALPUS_ELEMENTOR_ADDON_ASSETS . '/js' );                                                     // Template javascript uri

// Defines core name and slug if not defined.
define( 'ALPUS_ELEMENTOR_ADDON_NAME', 'Alpus Elementor Addon' );
define( 'ALPUS_ELEMENTOR_ADDON_SLUG', 'alpus-elementor-addon' );
define( 'ALPUS_ELEMENTOR_ADDON_PLUGIN_URI', 'alpus-elementor-addon/alpus-elementor-addon.php' );

if ( ! function_exists( 'alpus_plugin_framework_loader' ) ) {
	require_once( ALPUS_ELEMENTOR_ADDON_PATH . '/plugin-framework/init.php' );
}
alpus_plugin_framework_loader( ALPUS_ELEMENTOR_ADDON_PATH . '/' );

/**
 * Alpus Pro Plugin Class
 *
 * @since 1.0
 */
class Alpus_Elementor_Addon_Manager {

	/**
	 * Plugin Config
	 *
	 * @since 1.0
	 */
	public $plugin_config = '';

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	public function __construct() {

		$this->plugin_config = array(
			'slug'        => 'alpus-elementor-addon',
			'name'        => esc_html__( 'Elementor Addon', 'alpus-elementor-addon' ),
			'description' => esc_html__( 'The Alpus Elementor Addon is a collection of slick, powerful widgets and features that work seamlessly with Elementor page builder for WordPress.', 'alpus-elementor-addon' ),
			'admin'       => array(
				'tabs' => array(),
			),
		);

		// Load plugin
		add_action( 'plugins_loaded', array( $this, 'load' ) );
	}

	/**
	 * Load required files
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function load() {
		// Load text domain
		load_plugin_textdomain( ALPUS_ELEMENTOR_ADDON_SLUG, false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

		// Check if theme & plugins installed and activated
		if ( 'alpus' != get_template() && 'alpus-pro' != get_template() ) {
			add_action( 'admin_notices', array( $this, 'theme_required' ) );
			return;
		}

		if ( ! did_action( 'elementor/loaded' ) || ! defined( 'ALPHA_CORE_VERSION' ) ) {
			// add_action( 'admin_notices', array( $this, 'plugins_required' ) );
			return;
		}

		global $alpus_plugin_fw_data;
		if ( ! empty( $alpus_plugin_fw_data ) ) {
			require_once array_values( $alpus_plugin_fw_data )[0];
		}

		$this->framework = new Alpus_Plugin_Framework( $this->plugin_config );

		require_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/addon-functions.php';
		require_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/addon-actions.php';
		require_once ALPUS_ELEMENTOR_ADDON_PATH . '/inc/class-alpus-elementor-addon.php';
	}

	/**
	 * Show in WP Dashboard notice about the alpus theme is not activated.
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function theme_required() {
		$message  = '<p>' . sprintf( esc_html__( '%1$sAlpus Elementor Addon%2$s requires Alpus to be your active theme. Please install & activate to continue.', 'alpus-elementor-addon' ), '<strong>', '</strong>' ) . '</p>';
		echo '<div class="error">' . $message . '</div>';
	}

	/**
	 * Show in WP Dashboard notice about the elementor & alpus core plugin is not activated.
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function plugins_required() {
		$screen = get_current_screen();
		if ( isset( $screen->parent_file ) && 'plugins.php' === $screen->parent_file && 'update' === $screen->id ) {
			return;
		}

		$installed_plugins = get_plugins();

		if ( ! did_action( 'elementor/loaded' ) ) {
			$plugin = 'elementor/elementor.php';

			if ( isset( $installed_plugins[ $plugin ] ) ) {
				if ( ! current_user_can( 'activate_plugins' ) ) {
					return;
				}

				$activation_url = wp_nonce_url( 'plugins.php?action=activate&plugin=elementor/elementor.php&plugin_status=all&paged=1', 'activate-plugin_elementor/elementor.php' );

				$message  = '<p>' . sprintf( esc_html__( '%1$sAlpus Elementor Addon%2$s requires Elementor plugin to be active. Please activate Elementor to continue.', 'alpus-elementor-addon' ), '<strong>', '</strong>' ) . '</p>';
				$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $activation_url, esc_html__( 'Activate Elementor', 'alpus-elementor-addon' ) ) . '</p>';
			} else {
				if ( ! current_user_can( 'install_plugins' ) ) {
					return;
				}

				$install_url = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=elementor' ), 'install-plugin_elementor' );

				$message  = '<p>' . sprintf( esc_html__( '%1$sAlpus Elementor Addon%2$s requires Elementor plugin to be active. Please install Elementor to continue.', 'alpus-elementor-addon' ), '<strong>', '</strong>' ) . '</p>';
				$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $install_url, esc_html__( 'Install Elementor', 'alpus-elementor-addon' ) ) . '</p>';
			}
			
			echo '<div class="error">' . $message . '</div>';
		}
		if ( ! defined( 'ALPHA_CORE_VERSION' ) ) {
			$plugin = 'alpus-core/alpus-core.php';

			if ( isset( $installed_plugins[ $plugin ] ) ) {
				if ( ! current_user_can( 'activate_plugins' ) ) {
					return;
				}

				$activation_url = wp_nonce_url( 'plugins.php?action=activate&plugin=alpus-core/alpus-core.php&plugin_status=all&paged=1', 'activate-plugin_alpus-core/alpus-core.php' );

				$message  = '<p>' . sprintf( esc_html__( '%1$sAlpus Elementor Addon%2$s requires Alpus Core plugin to be active. Please activate Alpus Core to continue.', 'alpus-elementor-addon' ), '<strong>', '</strong>' ) . '</p>';
				$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $activation_url, esc_html__( 'Activate Alpus Core', 'alpus-elementor-addon' ) ) . '</p>';
			} else {
				if ( ! current_user_can( 'install_plugins' ) ) {
					return;
				}

				$install_url = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=alpus-core' ), 'install-plugin_alpus-core' );

				$message  = '<p>' . sprintf( esc_html__( '%1$sAlpus Elementor Addon%2$s requires Alpus Core plugin to be active. Please install Alpus Core to continue.', 'alpus-elementor-addon' ), '<strong>', '</strong>' ) . '</p>';
				$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $install_url, esc_html__( 'Install Alpus Core', 'alpus-elementor-addon' ) ) . '</p>';
			}
			
			echo '<div class="error">' . $message . '</div>';
		}
	}
}

new Alpus_Elementor_Addon_Manager();
