<?php
/*
Plugin Name: Alpus Pro
Plugin URI: https://alpustheme.com/
Description: Adds advanced functionality such as AI Content Writer, Critical Css & Js, Full Site Editing and WooCommerce Builders to Alpus Theme
Version: 1.0.1
Author: AlpusTheme
Author URI: https://alpustheme.com/
Text Domain: alpha-pro
*/

// Direct load is not allowed
defined( 'ABSPATH' ) || die;

/**************************************/
/* Define Constants                   */
/**************************************/
define( 'ALPHA_PRO_URI', untrailingslashit( plugin_dir_url( __FILE__ ) ) );               // Plugin directory uri
define( 'ALPHA_PRO_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );             // Plugin directory path
define( 'ALPHA_PRO_FILE', __FILE__ );                                                     // Plugin file path
define( 'ALPHA_PRO_VERSION', '1.0.0' );                                                   // Plugin Version

defined( 'ALPHA_SERVER_URI' ) || define( 'ALPHA_SERVER_URI', 'http://alpustheme.com/' );                    // Server uri

define( 'ALPHA_PRO_ASSETS', ALPHA_PRO_URI . '/assets' );                                                // Template assets directory uri
define( 'ALPHA_PRO_CSS', ALPHA_PRO_ASSETS . '/css' );                                                   // Template css uri
define( 'ALPHA_PRO_JS', ALPHA_PRO_ASSETS . '/js' );                                                     // Template javascript uri

// Defines core name and slug if not defined.
defined( 'ALPHA_PRO_NAME' ) || define( 'ALPHA_PRO_NAME', 'Alpus Pro' );
defined( 'ALPHA_PRO_SLUG' ) || define( 'ALPHA_PRO_SLUG', 'alpus-pro' );
defined( 'ALPHA_PRO_PLUGIN_URI' ) || define( 'ALPHA_PRO_PLUGIN_URI', 'alpus-pro/alpus-pro.php' );

if ( ! class_exists( 'Alpha_Base' ) ) {
	require_once ALPHA_PRO_PATH . '/inc/class-alpha-base.php';
}

/**
 * Alpha Pro Plugin Class
 *
 * @since 1.0
 */
class Alpha_Pro {

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	public function __construct() {
		// Load plugin
		add_action( 'plugins_loaded', array( $this, 'load' ) );
	}

	/**
	 * Load required files
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function load() {
		// Load text domain
		load_plugin_textdomain( 'alpha-pro', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

		if ( 'alpus' != get_template() && 'alpus-pro' != get_template() ) {
			add_action( 'admin_notices', array( $this, 'theme_required' ) );
			return;
		}

		if ( ! defined( 'ALPHA_CORE_VERSION' ) ) {
			// add_action( 'admin_notices', array( $this, 'pro_fail_load' ) );

			return;
		}

		$core_version_required = '1.0';
		if ( ! version_compare( ALPHA_CORE_VERSION, $core_version_required, '>=' ) ) {
			// add_action( 'admin_notices', array( $this, 'pro_fail_load_out_of_date' ) );

			return;
		}

		$core_version_recommendation = '1.0';
		if ( ! version_compare( ALPHA_CORE_VERSION, $core_version_recommendation, '>=' ) ) {
			// add_action( 'admin_notices', array( $this, 'pro_admin_notice_upgrade_recommendation' ) );
		}

		require_once ALPHA_PRO_PATH . '/inc/pro-setup.php';
	}

	/**
	 * Show in WP Dashboard notice about the alpus theme is not activated.
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function theme_required() {
		$message  = '<p>' . sprintf( esc_html__( '%1$sAlpus Pro%2$s requires Alpus to be your active theme. Please install & activate to continue.', 'alpha-pro' ), '<strong>', '</strong>' ) . '</p>';
		echo '<div class="error">' . $message . '</div>';
	}

	/**
	 * Show in WP Dashboard notice about the alpha core plugin is not activated.
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function pro_fail_load() {
		$screen = get_current_screen();
		if ( isset( $screen->parent_file ) && 'plugins.php' === $screen->parent_file && 'update' === $screen->id ) {
			return;
		}

		$plugin = 'alpus-core/alpus-core.php';

		if ( $this->is_alpha_core_installed() ) {
			if ( ! current_user_can( 'activate_plugins' ) ) {
				return;
			}

			$activation_url = wp_nonce_url( 'plugins.php?action=activate&amp;plugin=' . $plugin . '&amp;plugin_status=all&amp;paged=1&amp;s', 'activate-plugin_' . $plugin );

			$message  = '<p>' . esc_html__( 'Alpus Pro is not working because you need to activate the Alpus Core plugin.', 'alpha-pro' ) . '</p>';
			$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $activation_url, esc_html__( 'Activate Alpus Core', 'alpha-pro' ) ) . '</p>';
		} else {
			if ( ! current_user_can( 'install_plugins' ) ) {
				return;
			}

			$install_url = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=alpus-core' ), 'install-plugin_alpus-core' );

			$message  = '<p>' . esc_html__( 'Alpus Pro is not working because you need to install the Alpus Core plugin.', 'alpha-pro' ) . '</p>';
		}

		echo '<div class="error">' . $message . '</div>';
	}

	/**
	 * Show in WP Dashboard notice about the alpha core plugin must be updated.
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function pro_fail_load_out_of_date() {

		if ( ! current_user_can( 'update_plugins' ) ) {
			return;
		}

		$file_path = 'alpus-core/alpus-core.php';

		$upgrade_link = wp_nonce_url( self_admin_url( 'update.php?action=upgrade-plugin&plugin=' ) . $file_path, 'upgrade-plugin_' . $file_path );
		$message      = '<p>' . esc_html__( 'Alpus Pro is not working because you are using an old version of Alpus Core.', 'alpha-pro' ) . '</p>';

		echo '<div class="error">' . $message . '</div>';
	}

	/**
	 * Show in WP Dashboard notice about the alpha core plugin might be updated.
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function pro_admin_notice_upgrade_recommendation() {

		if ( ! current_user_can( 'update_plugins' ) ) {
			return;
		}

		$file_path = 'alpus-core/alpus-core.php';

		$upgrade_link = wp_nonce_url( self_admin_url( 'update.php?action=upgrade-plugin&plugin=' ) . $file_path, 'upgrade-plugin_' . $file_path );
		$message      = '<p>' . esc_html__( 'A new version of Alpus Core is available. For better performance and compatibility of Alpus Pro, we recommend updating to the latest version.', 'alpha-pro' ) . '</p>';

		echo '<div class="error">' . $message . '</div>';
	}

	/**
	 * Returns if Alpus Core plugin is installed or not.
	 *
	 * @since 1.0
	 *
	 * @return boolean
	 */
	public function is_alpha_core_installed() {
		$file_path         = 'alpus-core/alpus-core.php';
		$installed_plugins = get_plugins();

		return isset( $installed_plugins[ $file_path ] );
	}
}

new Alpha_Pro();
