<?php
/**
 * Alpha Pro Customizer
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

if ( ! class_exists( 'Alpha_Pro_Custom_Cursor' ) ) :

	class Alpha_Pro_Custom_Cursor extends Alpha_Base {

		/**
		 * Constructor
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

			// Add options in customize panel
			add_filter( 'alpha_customize_sections', array( $this, 'extend_sections' ) );
			add_filter( 'alpha_customize_fields', array( $this, 'extend_fields' ), 20 );

			// Add body class
			add_filter( 'body_class', array( $this, 'add_body_class' ) );

			// Save as dynamic style
			add_filter( 'alpha_dynamic_vars', array( $this, 'dynamic_style' ) );
		}

		/**
		 * load custom cursor css & js
		 *
		 * @since 1.0
		 */
		public function enqueue_scripts() {
			if ( alpha_get_option( 'change_cursor_type' ) ) {
				wp_enqueue_style( 'alpha-pro-cursor-type', ALPHA_PRO_ADDONS_URI . '/custom-cursor/cursor-type' . ( is_rtl() ? '-rtl' : '' ) . '.min.css', array(), ALPHA_PRO_VERSION );
				wp_enqueue_script( 'alpha-pro-cursor-type', ALPHA_PRO_ADDONS_URI . '/custom-cursor/cursor-type' . ALPHA_JS_SUFFIX, array(), ALPHA_PRO_VERSION, true );
			}
		}

		/**
		 * Extend sections
		 *
		 * @since 1.0
		 */
		public function extend_sections( $sections ) {

			// Miscellaneous / Custom Cursor
			$sections['custom_cursor'] = array(
				'title'    => esc_html__( 'Custom Cursor', 'alpha-pro' ),
				'panel'    => 'advanced',
				'priority' => 65,
			);

			return $sections;
		}

		/**
		 * Extend fields
		 *
		 * @since 1.0
		 */
		public function extend_fields( $fields ) {

			$fields = array_merge(
				$fields,
				array(
					'cs_cursor_type_title' => array(
						'section'   => 'custom_cursor',
						'type'      => 'custom',
						'label'     => '',
						'default'   => '<h3 class="options-custom-title">' . esc_html__( 'Cursor Type', 'alpha-pro' ) . '</h3>',
						'transport' => 'postMessage',
					),

					'change_cursor_type'   => array(
						'section' => 'custom_cursor',
						'type'    => 'toggle',
						'label'   => esc_html__( 'Change Cursor Type', 'alpha-pro' ),
						'tooltip' => esc_html__( 'Change custom cursor type. This is a dot cursor surrounded circle shaped border and follows the mouse position.', 'alpha-pro' ),
						'default' => false,
					),

					'cursor_inner_color'   => array(
						'section'         => 'custom_cursor',
						'type'            => 'color',
						'label'           => esc_html__( 'Cursor Dot Color', 'alpha-pro' ),
						'default'         => '',
						'transport'       => 'postMessage',
						'active_callback' => array(
							array(
								'setting'  => 'change_cursor_type',
								'operator' => '==',
								'value'    => true,
							),
						),
					),

					'cursor_outer_color'   => array(
						'section'         => 'custom_cursor',
						'type'            => 'color',
						'label'           => esc_html__( 'Cursor Border Color', 'alpha-pro' ),
						'default'         => '',
						'transport'       => 'postMessage',
						'active_callback' => array(
							array(
								'setting'  => 'change_cursor_type',
								'operator' => '==',
								'value'    => true,
							),
						),
					),
				)
			);

			return $fields;
		}

		/**
		 * Add body class
		 *
		 * @since 1.0
		 */
		public function add_body_class( $classes ) {
			if ( alpha_get_option( 'change_cursor_type' ) ) {
				$classes[] = 'custom-cursor-type';
			}
			return $classes;
		}


		/**
		 * Add dynamic styles
		 *
		 * @since 1.0
		 */
		public function dynamic_style( $style ) {
			$change_cursor_type = alpha_get_option( 'change_cursor_type' );

			if ( $change_cursor_type ) {
				if ( alpha_get_option( 'cursor_inner_color' ) ) {
					$style['html']['--alpha-cursor-inner-color'] = alpha_get_option( 'cursor_inner_color' );
				}
				if ( alpha_get_option( 'cursor_outer_color' ) ) {
					$style['html']['--alpha-cursor-outer-color'] = alpha_get_option( 'cursor_outer_color' );
				}
			}

			return $style;
		}

	}
endif;

Alpha_Pro_Custom_Cursor::get_instance();
