/**
 * Alpha Pro Custom Cursor Type JS Library
 * 
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 * @version    1.0
 */
'use strict';
window.theme || ( window.theme = {} );

( function ( $ ) {
    /**
    * Custom Cursor Type
    * 
    * @since 1.0
    */
    theme.initCurorType = function ( theme, $ ) {

        theme = theme || {};

        var instanceName = '__cursorEffect';

        var CursorType = function ( $el, opts ) {
            return this.initialize( $el, opts );
        };

        CursorType.defaults = {

        }

        CursorType.prototype = {
            initialize: function ( $el, opts ) {
                if ( $el.data( instanceName ) ) {
                    return this;
                }

                this.$el = $el;

                this
                    .setData()
                    .setOptions( opts )
                    .build()
                    .events();

                return this;
            },

            setData: function () {
                this.$el.data( instanceName, this );

                return this;
            },

            setOptions: function ( opts ) {
                this.options = $.extend( true, {}, CursorType.defaults, opts, {
                    wrapper: this.$el
                } );

                return this;
            },

            build: function () {
                var self = this;

                // Global Variables for cursor position
                self.clientX = -100;
                self.clientY = -100;

                // Creates the cursor wrapper node
                var cursorOuter = document.createElement( 'DIV' );
                cursorOuter.className = 'cursor-outer';

                // Creates the cursor inner node
                var cursorInner = document.createElement( 'DIV' );
                cursorInner.className = 'cursor-inner';

                // Style
                if ( self.options.style ) {
                    self.$el.addClass( self.options.style );
                }

                // Prepend cursor wrapper node to the body
                document.body.prepend( cursorOuter );

                // Prepend cursor inner node to the body
                document.body.prepend( cursorInner );

                // Loop for render
                var render = function () {
                    cursorOuter.style.transform = `translate(${ self.clientX }px, ${ self.clientY }px)`;
                    cursorInner.style.transform = `translate(${ self.clientX }px, ${ self.clientY }px)`;

                    self.loopInside = requestAnimationFrame( render );
                }
                self.loop = requestAnimationFrame( render );

                return this;
            },

            events: function () {
                var self = this;

                // Update Cursor Position
                document.addEventListener( 'mousemove', function ( e ) {
                    if ( !self.isStuck ) {
                        self.clientX = e.clientX - 20;
                        self.clientY = e.clientY - 20;
                    }
                } );

                self.isStuck = false;

                return this;
            },
        };

        // expose to scope
        $.extend( theme, {
            CursorType: CursorType
        } );

        // jquery plugin
        $.fn.themeCursorType = function ( opts ) {
            return this.map( function () {
                var $this = $( this );

                if ( $this.data( instanceName ) ) {
                    return $this.data( instanceName );
                } else {
                    return new CursorType( $this, opts );
                }

            } );
        }
        if ( $( 'body' ).hasClass( 'custom-cursor-type' ) ) {
            $( 'body' ).themeCursorType();
        }
    }


    /**
     * Theme Setup
     */
    $( window )
        .on( 'alpha_complete', function () {
            // Enable Custom Cursor Type
            theme.initCurorType( theme, $ );
        } );
} )( jQuery );