<?php
/**
 * Alpha Pro Dark Mode
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

if ( ! class_exists( 'Alpha_Pro_Dark_Mode' ) ) :

	class Alpha_Pro_Dark_Mode extends Alpha_Base {

		/**
		 * Constructor
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_filter( 'alpha_dynamic_vars', array( $this, 'add_pro_dynamic_vars' ) );
			add_filter( 'alpha_theme_option_default_values', array( $this, 'add_pro_theme_option' ) );
			add_filter( 'alpha_customize_fields', array( $this, 'extend_fields' ), 20 );
			add_filter( 'body_class', array( $this, 'add_dark_body_class' ) );
		}

		/**
		 * Extend fields
		 *
		 * @since 1.0
		 */
		public function extend_fields( $fields ) {

			$fields = array_merge(
				$fields,
				array(
					'cs_skin_title'               => array(
						'section' => 'color',
						'type'    => 'custom',
						'label'   => '',
						'default' => '<h3 class="options-custom-title">' . esc_html__( 'Skin', 'alpha-pro' ) . '</h3>',
						'priority'  => 2,
					),
					'dark_skin'          => array(
						'section'   => 'color',
						'type'      => 'toggle',
						'label'     => esc_html__( 'Dark Skin', 'alpha-pro' ),
						'tooltip'   => esc_html__( 'Enable dark skin throughout full site.', 'alpha-pro' ),
						'transport' => 'postMessage',
						'priority'  => 2,
					),

					'cs_dark_skin_alert' => array(
						'section'         => 'color',
						'type'            => 'custom',
						'label'           => '<p class="options-description description-danger"><span>' . esc_html__( 'Caution:', 'alpha-pro' ) . '</span> ' . esc_html__( 'Page background color and heading color has been set as default dark preset color via this option.', 'alpha-pro' ) . '<br/>' . sprintf( esc_html__( '%1$sGeneral/Site Layout/Background Color%2$s%3$sStyle/Heading Typography%2$s', 'alpha-pro' ), '<a class="customizer-nav-item" href="#" data-target="general" data-type="section">', '</a>', '<a class="customizer-nav-item" href="#" data-target="typo_heading" data-type="control">' ) . '</p>',
						'priority'        => 3,
						'active_callback' => array(
							array(
								'setting'  => 'dark_skin',
								'operator' => '==',
								'value'    => true,
							),
						),
					),
				)
			);

			return $fields;
		}

		/**
		 * Add dynamic styles
		 *
		 * @since 1.0
		 */
		function add_pro_dynamic_vars( $dynamic_vars ) {
			// Dark Mode
			$dark_mode = alpha_get_option( 'dark_skin' );

			if ( $dark_mode ) {
				$dynamic_vars['html']['--alpha-heading-color']             = '#fff';
				$dynamic_vars['html']['--alpha-change-border-color']       = '#444';
				$dynamic_vars['html']['--alpha-change-light-border-color'] = '#282828';
				$dynamic_vars['html']['--alpha-change-color-light-1']      = '#111';
				$dynamic_vars['html']['--alpha-change-color-light-2']      = '#555';
				$dynamic_vars['html']['--alpha-change-color-light-3']      = '#3a3a3a';
				$dynamic_vars['html']['--alpha-change-color-light-4']      = '#666';
				$dynamic_vars['html']['--alpha-change-color-light-5']      = '#181818';
				$dynamic_vars['html']['--alpha-change-color-dark-1']       = '#ccc';
				$dynamic_vars['html']['--alpha-change-color-dark-2']       = '#aaa';
				$dynamic_vars['html']['--alpha-change-color-dark-3']       = '#999';
			}

			// Page Wrapper
			$content_bg = alpha_get_option( 'content_bg' );
			if ( empty( $content_bg['background-color'] ) ) {
				if ( alpha_get_option( 'dark_skin' ) ) {
					$content_bg['background-color'] = '#111';
				} else {
					$content_bg['background-color'] = '#fff';
				}
			}
			alpha_dynamic_vars_bg( 'page-wrapper', $content_bg, $dynamic_vars['.page-wrapper'] );
			return $dynamic_vars;
		}

		/**
		 * Add theme option
		 *
		 * @since 1.0
		 */
		function add_pro_theme_option( $alpha_option ) {
			$alpha_option['dark_skin'] = false;
			return $alpha_option;
		}

		/**
		 * Add dark body class
		 *
		 * @since 1.0
		 */
		function add_dark_body_class( $classes ) {
			if ( alpha_get_option( 'dark_skin' ) ) {
				$classes[] = 'alpha-dark';
			}
			return $classes;
		}
	}
endif;

Alpha_Pro_Dark_Mode::get_instance();
