<?php
/**
 * Alpha Pro Customizer
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

if ( ! class_exists( 'Alpha_Pro_Customizer' ) ) :

	class Alpha_Pro_Customizer extends Alpha_Base {

		/**
		 * Constructor
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_action( 'wp_enqueue_scripts', array( $this, 'load_selective_assets' ) );
			add_filter( 'alpha_customize_sections', array( $this, 'extend_sections' ), 20 );
			add_filter( 'alpha_customize_fields', array( $this, 'extend_fields' ), 20 );
		}

		/**
		 * load selective refresh JS
		 *
		 * @since 1.0
		 */
		public function load_selective_assets() {
			wp_enqueue_script( 'alpha-pro-selective', ALPHA_PRO_INC_URI . '/admin/customizer/pro-selective-refresh' . ALPHA_JS_SUFFIX, array( 'jquery-core', 'alpha-selective' ), ALPHA_VERSION, true );
		}
		/**
		 * Extend sections
		 *
		 * @since 1.0
		 */
		public function extend_sections( $sections ) {
			// Features
			$sections['ajax_filter'] = array(
				'title'    => esc_html__( 'Ajax Filter', 'alpha-pro' ),
				'panel'    => 'features',
				'priority' => 10,
			);

			// Miscellaneous / Custom Cursor
			$sections['custom_cursor'] = array(
				'title'    => esc_html__( 'Custom Cursor', 'alpha-pro' ),
				'panel'    => 'advanced',
				'priority' => 65,
			);

			// WooCommerce Panel
			if ( class_exists( 'WooCommerce' ) ) {
				$sections['wc_cart'] = array(
					'title'    => esc_html__( 'Cart Page', 'alpha-pro' ),
					'panel'    => 'woocommerce',
					'priority' => 20,
				);
			}

			return $sections;
		}

		/**
		 * Extend fields
		 *
		 * @since 1.0
		 */
		public function extend_fields( $fields ) {

			$alpha_templates = alpha_get_global_templates_sidebars();
			if ( ! empty( $alpha_templates['block'] ) ) {
				$custom_tab_block     = $alpha_templates['block'];
				$custom_tab_block[''] = esc_html__( 'None', 'alpha-pro' );
			}

			$fields = array_replace_recursive(
				$fields,
				array(
					// Custom Cursor
					'cs_cursor_type_title' => array(
						'section'   => 'custom_cursor',
						'type'      => 'custom',
						'label'     => '',
						'default'   => '<h3 class="options-custom-title">' . esc_html__( 'Cursor Type', 'alpha-pro' ) . '</h3>',
						'transport' => 'postMessage',
					),
					'change_cursor_type'   => array(
						'section' => 'custom_cursor',
						'type'    => 'toggle',
						'label'   => esc_html__( 'Change Cursor Type', 'alpha-pro' ),
						'tooltip' => esc_html__( 'Change custom cursor type. This is a dot cursor surrounded circle shaped border and follows the mouse position.', 'alpha-pro' ),
						'default' => false,
					),
					'cursor_inner_color'   => array(
						'section'         => 'custom_cursor',
						'type'            => 'color',
						'label'           => esc_html__( 'Cursor Dot Color', 'alpha-pro' ),
						'default'         => '',
						'transport'       => 'postMessage',
						'active_callback' => array(
							array(
								'setting'  => 'change_cursor_type',
								'operator' => '==',
								'value'    => true,
							),
						),
					),
					'cursor_outer_color'   => array(
						'section'         => 'custom_cursor',
						'type'            => 'color',
						'label'           => esc_html__( 'Cursor Border Color', 'alpha-pro' ),
						'default'         => '',
						'transport'       => 'postMessage',
						'active_callback' => array(
							array(
								'setting'  => 'change_cursor_type',
								'operator' => '==',
								'value'    => true,
							),
						),
					),
				)
			);

			if ( class_exists( 'WooCommerce' ) ) {

				$fields = array_replace_recursive(
					$fields,
					array(
						'quickview_type'           => array(
							'section' => 'quickview',
							'type'    => 'radio-image',
							'label'   => esc_html__( 'Quickview Type', 'alpha-pro' ),
							'choices' => array(
								''          => ALPHA_PRO_ASSETS . '/images/quickview-popup.jpg',
								'zoom'      => ALPHA_PRO_ASSETS . '/images/quickview-zoom.jpg',
								'offcanvas' => ALPHA_PRO_ASSETS . '/images/quickview-offcanvas.jpg',
							),
						),

						// Product Page / Product Data / Custom Tab
						'cs_product_custom_tab'    => array(
							'section'  => 'product_detail',
							'type'     => 'custom',
							'label'    => '',
							'default'  => '<h3 class="options-custom-title">' . esc_html__( 'Custom Tab', 'alpha-pro' ) . '</h3>',
							'priority' => 15,
						),
						'product_tab_title'        => array(
							'section'   => 'product_detail',
							'type'      => 'text',
							'label'     => esc_html__( 'Custom Tab Title', 'alpha-pro' ),
							'tooltip'   => esc_html__( 'Show custom tab in all product pages.', 'alpha-pro' ),
							'transport' => 'postMessage',
							'priority'  => 15,
						),
						'product_tab_block'        => array(
							'section'  => 'product_detail',
							'type'     => 'select',
							'label'    => esc_html__( 'Custom Tab Content ( Block Builder )', 'alpha-pro' ),
							'choices'  => empty( $alpha_templates['block'] ) ? array() : $custom_tab_block,
							'priority' => 15,
						),
					)
				);
			}

			return $fields;
		}
	}
endif;

Alpha_Pro_Customizer::get_instance();
