/**
 * Alpha Pro Selective Refresh for Customize
 * 
 * @package  Alpha Pro
 * @since 1.0
 */
'use strict';
jQuery( document ).ready( function ( $ ) {

    eventsInit();

    function getCustomize( option ) {
        var o = wp.customize( option );
        return o ? o.get() : '';
    }

    var options = [
        'cursor_inner_color', 'cursor_outer_color',
        'dark_skin',
    ];

    var firstLoad = 0;

    for ( var i = 0; i < options.length; i++ ) {
        if ( Array.isArray( options[ i ] ) ) {
            var option = options[ i ];
        } else {
            var option = [ options[ i ] ];
        }

        for ( var j = 0; j < option.length; j++ ) {
            wp.customize( option[ j ], function ( e ) {
                var event = option[ 0 ];
                e.bind( function ( value ) {
                    $( document.body ).trigger( event );
                } );
            } );
        }

        $( document.body ).trigger( option[ 0 ] );
    }

    function setBackgroundColor(id, value) {
        var input = window.top.document.querySelector('#customize-control-' + id + '-background-color input.kirki-color-input');
        var nativeInputValueSetter = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, "value").set;
        nativeInputValueSetter.call(input, value);

        var ev2 = new Event('input', { bubbles: true});
        input.dispatchEvent(ev2);
    }

    function setTypographyColor(id, value) {
        var input = window.top.document.querySelector('#customize-control-' + id + '-color input.kirki-color-input');
        var nativeInputValueSetter = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, "value").set;
        nativeInputValueSetter.call(input, value);

        var ev2 = new Event('input', { bubbles: true});
        input.dispatchEvent(ev2);
    }

    function eventsInit() {
        var style = $( 'html' )[ 0 ].style;

        $( document.body ).on( 'cursor_inner_color', function () {
            style.setProperty( '--alpha-cursor-inner-color', getCustomize( 'cursor_inner_color' ) );
        } )

        $( document.body ).on( 'cursor_outer_color', function () {
            style.setProperty( '--alpha-cursor-outer-color', getCustomize( 'cursor_outer_color' ) );
        } )

        $( document.body ).on( 'dark_skin', function () {
            var isDarkSkin = getCustomize( 'dark_skin' );

            firstLoad++;

            if ( firstLoad < 2 ) {
                return;
            }

            $( document.body ).toggleClass( 'alpha-dark', isDarkSkin );

            if ( isDarkSkin ) {
                // Save Previous Values
                window.top.wp.customize.typo_default_light_color = window.top.wp.customize.instance( 'typo_default' ).get()['color'];
                window.top.wp.customize.typo_heading_light_color = window.top.wp.customize.instance( 'typo_heading' ).get()['color'];
                window.top.wp.customize.site_bg_light_color = window.top.wp.customize.instance( 'site_bg' ).get()['background-color'];
                window.top.wp.customize.content_bg_light_color = window.top.wp.customize.instance( 'content_bg' ).get()['background-color'];

                // Update Controls
                setBackgroundColor('site_bg', undefined != window.top.wp.customize.site_bg_dark_color ? window.top.wp.customize.site_bg_dark_color : '#111');
                setBackgroundColor('content_bg', undefined != window.top.wp.customize.content_bg_dark_color ? window.top.wp.customize.content_bg_dark_color : '#111');
                setTypographyColor('typo_default', undefined != window.top.wp.customize.typo_default_dark_color ? window.top.wp.customize.typo_default_dark_color :'#777');
                setTypographyColor('typo_heading', undefined != window.top.wp.customize.typo_heading_dark_color ? window.top.wp.customize.typo_heading_dark_color :'#fff');

                // Update Preview Change
                style.setProperty( '--alpha-change-border-color', '#444' );
                style.setProperty( '--alpha-change-light-border-color', '#282828' );
                style.setProperty( '--alpha-change-color-light-1', '#111' );
                style.setProperty( '--alpha-change-color-light-2', '#555' );
                style.setProperty( '--alpha-change-color-light-3', '#3a3a3a' );
                style.setProperty( '--alpha-change-color-light-4', '#666' );
                style.setProperty( '--alpha-change-color-light-5', '#181818' );
                style.setProperty( '--alpha-change-color-dark-1', '#ccc' );
                style.setProperty( '--alpha-change-color-dark-2', '#aaa' );
                style.setProperty( '--alpha-change-color-dark-3', '#999' );
                style.setProperty( '--alpha-dark-color-hover', getLighten( '#ccc' ) );
                style.setProperty( '--alpha-heading-color', '#fff' );
                style.setProperty( '--alpha-site-bg-color', '#111' );
                document.querySelector( '.page-wrapper' ).style.setProperty( '--alpha-page-wrapper-bg-color', '#111' );
            } else {
                // Save Previous Values
                window.top.wp.customize.typo_default_dark_color = window.top.wp.customize.instance( 'typo_default' ).get()['color'];
                window.top.wp.customize.typo_heading_dark_color = window.top.wp.customize.instance( 'typo_heading' ).get()['color'];
                window.top.wp.customize.site_bg_dark_color = window.top.wp.customize.instance( 'site_bg' ).get()['background-color'];
                window.top.wp.customize.content_bg_dark_color = window.top.wp.customize.instance( 'content_bg' ).get()['background-color'];

                // Update Controls
                setBackgroundColor('site_bg', undefined != window.top.wp.customize.site_bg_light_color ? window.top.wp.customize.site_bg_light_color : '');
                setBackgroundColor('content_bg', undefined != window.top.wp.customize.content_bg_light_color ? window.top.wp.customize.content_bg_light_color : '');
                setTypographyColor('typo_default', undefined != window.top.wp.customize.typo_default_light_color ? window.top.wp.customize.typo_default_light_color : window.top.wp.customize.control( 'typo_default' ).params.default.color);
                setTypographyColor('typo_heading', undefined != window.top.wp.customize.typo_heading_light_color ? window.top.wp.customize.typo_heading_light_color : window.top.wp.customize.control( 'typo_heading' ).params.default.color);

                // Update Preview Change
                style.setProperty( '--alpha-change-border-color', '#ccc' );
                style.setProperty( '--alpha-change-light-border-color', '#e1e1e1' );
                style.setProperty( '--alpha-change-color-light-1', '#fff' );
                style.setProperty( '--alpha-change-color-light-2', '#aaa' );
                style.setProperty( '--alpha-change-color-light-3', '#ddd' );
                style.setProperty( '--alpha-change-color-light-4', '#999' );
                style.setProperty( '--alpha-change-color-light-5', '#f6f6f6' );
                style.setProperty( '--alpha-change-color-dark-1', '#222' );
                style.setProperty( '--alpha-change-color-dark-2', '#3a3a3a' );
                style.setProperty( '--alpha-change-color-dark-3', '#555' );
                style.setProperty( '--alpha-dark-color-hover', getLighten( '#ccc' ) );
                style.setProperty( '--alpha-heading-color', '#000' );
                style.setProperty( '--alpha-site-bg-color', '#fff' );
                document.querySelector( '.page-wrapper' ).style.setProperty( '--alpha-page-wrapper-bg-color', '#fff' );
            }
        } )
    }

    /**
     * Generate font styles.
     * 
     * @since 1.0
     */
    function alpha_selective_typography( style, id, typo ) {
        if ( typo[ 'font-family' ] && 'inherit' != typo[ 'font-family' ] ) {
            style.setProperty( '--alpha-' + id + '-font-family', "'" + typo[ 'font-family' ] + "', sans-serif" );

            if ( !typo[ 'variant' ] ) {
                typo[ 'variant' ] = 400;
            }
        } else {
            style.removeProperty( '--alpha-' + id + '-font-family' );
        }
        if ( typo[ 'variant' ] ) {
            style.setProperty( '--alpha-' + id + '-font-weight', 'regular' == typo[ 'variant' ] ? 400 : typo[ 'variant' ] );
        } else if ( 'heading' == id ) {
            style.setProperty( '--alpha-' + id + '-font-weight', 600 );
        } else {
            style.removeProperty( '--alpha-' + id + '-font-weight' );
        }
        if ( typo[ 'font-size' ] && '' != typo[ 'font-size' ] ) {
            style.setProperty( '--alpha-' + id + '-font-size', ( Number( typo[ 'font-size' ] ) ? ( typo[ 'font-size' ] + 'px' ) : typo[ 'font-size' ] ) );
        } else {
            style.removeProperty( '--alpha-' + id + '-font-size' );
        }
        if ( typo[ 'line-height' ] && '' != typo[ 'line-height' ] ) {
            style.setProperty( '--alpha-' + id + '-line-height', typo[ 'line-height' ] );
        } else {
            style.removeProperty( '--alpha-' + id + '-line-height' );
        }
        if ( typo[ 'letter-spacing' ] && '' != typo[ 'letter-spacing' ] ) {
            style.setProperty( '--alpha-' + id + '-letter-spacing', typo[ 'letter-spacing' ] );
        } else {
            style.removeProperty( '--alpha-' + id + '-letter-spacing' );
        }
        if ( typo[ 'text-transform' ] && '' != typo[ 'text-transform' ] ) {
            style.setProperty( '--alpha-' + id + '-text-transform', typo[ 'text-transform' ] );
        } else {
            style.removeProperty( '--alpha-' + id + '-text-transform' );
        }
        if ( typo[ 'color' ] && '' != typo[ 'color' ] ) {
            style.setProperty( '--alpha-' + id + '-color', typo[ 'color' ] );
        } else {
            style.removeProperty( '--alpha-' + id + '-color' );
        }
    }

    /**
     * Transform color format.
     * 
     * @since 1.0
     */
    function getHSL( color ) {
        color = Number.parseInt( color.slice( 1 ), 16 );
        var $blue = color % 256;
        color /= 256;
        var $green = color % 256;
        var $red = color = color / 256;

        var $min = Math.min( $red, $green, $blue );
        var $max = Math.max( $red, $green, $blue );

        var $l = $min + $max;
        var $d = Number( $max - $min );
        var $h = 0;
        var $s = 0;

        if ( $d ) {
            if ( $l < 255 ) {
                $s = $d / $l;
            } else {
                $s = $d / ( 510 - $l );
            }

            if ( $red == $max ) {
                $h = 60 * ( $green - $blue ) / $d;
            } else if ( $green == $max ) {
                $h = 60 * ( $blue - $red ) / $d + 120;
            } else if ( $blue == $max ) {
                $h = 60 * ( $red - $green ) / $d + 240;
            }
        }

        return [ ( $h + 360 ) % 360, ( $s * 100 ), ( $l / 5.1 + 7 ) ];
    }

    /**
     * Change hue to rgb.
     * 
     * @since 1.0
     * @param {int} $m1 
     * @param {int} $m2 
     * @param {int} $h 
     */
    function hueToRGB( $m1, $m2, $h ) {
        if ( $h < 0 ) {
            $h += 1;
        } else if ( $h > 1 ) {
            $h -= 1;
        }

        if ( $h * 6 < 1 ) {
            return $m1 + ( $m2 - $m1 ) * $h * 6;
        }

        if ( $h * 2 < 1 ) {
            return $m2;
        }

        if ( $h * 3 < 2 ) {
            return $m1 + ( $m2 - $m1 ) * ( 2 / 3 - $h ) * 6;
        }

        return $m1;
    }

    /**
     * Get RGB
     * 
     * @since 1.0
     * @param {int} $hue 
     * @param {int} $saturation 
     * @param {int} $lightness 
     */
    function getRGB( $hue, $saturation, $lightness ) {
        if ( $hue < 0 ) {
            $hue += 360;
        }

        var $h = $hue / 360;
        var $s = Math.min( 100, Math.max( 0, $saturation ) ) / 100;
        var $l = Math.min( 100, Math.max( 0, $lightness ) ) / 100;

        var $m2 = $l <= 0.5 ? $l * ( $s + 1 ) : $l + $s - $l * $s;
        var $m1 = $l * 2 - $m2;

        var $r = hueToRGB( $m1, $m2, $h + 1 / 3 ) * 255;
        var $g = hueToRGB( $m1, $m2, $h ) * 255;
        var $b = hueToRGB( $m1, $m2, $h - 1 / 3 ) * 255;

        var $out = [ Math.ceil( $r ), Math.ceil( $g ), Math.ceil( $b ) ];

        return $out;
    }

    /**
     * Adjust the hsl.
     * 
     * @since 1.0
     * @param {string} color 
     * @param {int} amount 
     */
    function adjustHsl( color, amount ) {
        var $hsl = getHSL( color );
        $hsl[ 2 ] += amount;
        var $out = getRGB( $hsl[ 0 ], $hsl[ 1 ], $hsl[ 2 ] );
        return 'rgb(' + $out[ 0 ] + ',' + $out[ 1 ] + ',' + $out[ 2 ] + ')';
    }

    /**
     * Returns the light color.
     * 
     * @since 1.0
     * @param {string} color 
     * @param {int} amount
     */
    function getLighten( color, amount = 5 ) {
        if ( !color || 'transparent' == color ) {
            return 'transparent';
        }
        if ( color.length == 4 ) {
            color = '#' + color[ 1 ] + color[ 1 ] + color[ 2 ] + color[ 2 ] + color[ 3 ] + color[ 3 ];
        }
        return adjustHsl( color, amount );
    }
} )