<?php
defined( 'ABSPATH' ) || die;

/**
 * Alpha Elementor Billing Widget
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */

use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;

class Alpha_Checkout_Billing_Elementor_Widget extends \Elementor\Widget_Base {

	public function get_name() {
		return ALPHA_NAME . '_checkout_widget_billing';
	}

	public function get_title() {
		return esc_html__( 'Checkout Billing', 'alpha-pro' );
	}

	public function get_categories() {
		return array( 'alpha_checkout_widget' );
	}

	public function get_keywords() {
		return array( 'billing', 'checkout', 'woocommerce' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon alpha-widget-icon-checkout-billing';
	}

	public function get_script_depends() {
		$depends = array();
		if ( alpha_is_elementor_preview() ) {
			$depends[] = 'alpha-elementor-js';
		}
		return $depends;
	}

	protected function register_controls() {

		// $right = is_rtl() ? 'left' : 'right';

		$this->start_controls_section(
			'section_billing_heading',
			array(
				'label' => esc_html( 'Heading', 'alpha-pro' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				array(
					'name'     => 'heading_typography',
					'label'    => esc_html__( 'Typography', 'alpha-pro' ),
					'selector' => '{{WRAPPER}} .woocommerce-billing-fields > h3',
				)
			);
			$this->add_control(
				'heading_margin',
				array(
					'label'      => esc_html__( 'Margin', 'alpha-pro' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', 'rem' ),
					'selectors'  => array(
						'{{WRAPPER}} .woocommerce-billing-fields > h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				)
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_billing_label',
			array(
				'label' => esc_html( 'Label', 'alpha-pro' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				array(
					'name'     => 'label_typography',
					'label'    => esc_html__( 'Typography', 'alpha-pro' ),
					'selector' => '{{WRAPPER}} .form-row label',
				)
			);
			$this->add_control(
				'label_margin',
				array(
					'label'      => esc_html__( 'Margin', 'alpha-pro' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => array( 'px', 'rem' ),
					'selectors'  => array(
						'{{WRAPPER}} .form-row label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				)
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_coupons_style',
			array(
				'label' => esc_html__( 'Form Field', 'alpha-pro' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				array(
					'name'     => 'input_typography',
					'label'    => esc_html__( 'Typography', 'alpha-pro' ),
					'selector' => '{{WRAPPER}} .input-text, {{WRAPPER}} .select2 .select2-selection__rendered',
				)
			);

			$this->add_control(
				'form_spacing_between',
				array(
					'label'       => esc_html__( 'Space Between', 'alpha-pro' ),
					'description' => esc_html__( 'Control spacing between form fields.', 'alpha-pro' ),
					'type'        => Controls_Manager::SLIDER,
					'size_units'  => array( 'px', 'rem' ),
					'selectors'   => array(
						'{{WRAPPER}} p.form-row:not(:last-of-type)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_control(
				'field_padding',
				array(
					'label'       => esc_html__( 'Padding', 'alpha-pro' ),
					'description' => esc_html__( 'Control the padding of form fields.', 'alpha-pro' ),
					'type'        => Controls_Manager::DIMENSIONS,
					'size_units'  => array( 'px' ),
					'selectors'   => array(
						'{{WRAPPER}} .input-text, {{WRAPPER}} .select2-selection--single' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					),
				)
			);

			$this->start_controls_tabs( 'input_tab_color' );
				$this->start_controls_tab(
					'tab_input_normal',
					array(
						'label' => esc_html__( 'Normal', 'alpha-pro' ),
					)
				);

					$this->add_control(
						'input_color',
						array(
							'label'       => esc_html__( 'Color', 'alpha-pro' ),
							'description' => esc_html__( 'Control the text color of the form fields.', 'alpha-pro' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'{{WRAPPER}} .input-text, {{WRAPPER}} .select2 .select2-selection__rendered' => 'color: {{VALUE}};',
							),
						)
					);
					$this->add_control(
						'input_bg_color',
						array(
							'label'       => esc_html__( 'Background Color', 'alpha-pro' ),
							'description' => esc_html__( 'Control the background color of the form fields.', 'alpha-pro' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'{{WRAPPER}} .input-text, {{WRAPPER}} .select2 .select2-selection--single' => 'background-color: {{VALUE}};',
							),
						)
					);
					$this->add_control(
						'input_bd_color',
						array(
							'label'       => esc_html__( 'Border Color', 'alpha-pro' ),
							'description' => esc_html__( 'Control the border color of the form fields.', 'alpha-pro' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'{{WRAPPER}} .input-text, {{WRAPPER}} .select2 .select2-selection--single' => 'border-color: {{VALUE}};transition: border-color .3s;',
							),
						)
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'tab_input_focus',
					array(
						'label' => esc_html__( 'Focus', 'alpha-pro' ),
					)
				);
					$this->add_control(
						'input_focus_color',
						array(
							'label'       => esc_html__( 'Focus Color', 'alpha-pro' ),
							'description' => esc_html__( 'Control the text color of the form fields on focus.', 'alpha-pro' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'{{WRAPPER}} .input-text:focus, {{WRAPPER}} .select2 .select2-selection--single:focus' => 'color: {{VALUE}};',
							),
						)
					);
					$this->add_control(
						'input_focus_bg_color',
						array(
							'label'       => esc_html__( 'Focus Background Color', 'alpha-pro' ),
							'description' => esc_html__( 'Control the background color of the form fields on focus.', 'alpha-pro' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'{{WRAPPER}} .input-text:focus, {{WRAPPER}} .select2 .select2-selection--single:focus' => 'background-color: {{VALUE}};',
							),
						)
					);
					$this->add_control(
						'input_focus_bd',
						array(
							'label'       => esc_html__( 'Focus Border Color', 'alpha-pro' ),
							'description' => esc_html__( 'Control the border color of the form fields on focus.', 'alpha-pro' ),
							'type'        => Controls_Manager::COLOR,
							'selectors'   => array(
								'{{WRAPPER}} .input-text:focus, {{WRAPPER}} .select2 .select2-selection--single:focus' => 'border-color: {{VALUE}};',
							),
						)
					);
				$this->end_controls_tab();
			$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function render() {

		$atts = $this->get_settings_for_display();

		if ( apply_filters( 'alpha_checkout_builder_set_preview', false ) ) {
			$checkout = WC()->checkout();
			$checkout->checkout_form_billing();
		}
		do_action( 'alpha_checkout_builder_unset_preview' );
	}

	protected function content_template() {}
}
