<?php
/**
 * Alpha Footer Builder Class
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Background;

class Alpha_Pro_Footer_Builder extends Alpha_Base {

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	public function __construct() {

		// Add Controls
		add_action( 'elementor/documents/register_controls', array( $this, 'register_elementor_footer_controls' ) );

		// Add body class
		add_filter( 'body_class', array( $this, 'add_footer_body_class' ) );

	}

	/**
	 * Add footer builder's preview controls for elementor
	 *
	 * @since 1.0
	 * @access public
	 * @param object $document
	 */
	public function register_elementor_footer_controls( $document ) {
		if ( ! $document instanceof Elementor\Core\DocumentTypes\PageBase && ! $document instanceof Elementor\Modules\Library\Documents\Page ) {
			return;
		}

		// Add Template Builder Controls
		$id = (int) $document->get_main_id();

		if ( $id && ALPHA_NAME . '_template' == get_post_type( $id ) && 'footer' == get_post_meta( $id, ALPHA_NAME . '_template_type', true ) ) {

			$document->start_controls_section(
				'alpha_footer_settings',
				array(
					'label' => alpha_elementor_panel_heading( esc_html__( 'Footer Settings', 'alpha-pro' ) ),
					'tab'   => Controls_Manager::TAB_SETTINGS,
				)
			);

			$document->add_control(
				'alpha_fixed_footer',
				array(
					'label' => esc_html__( 'Is Fixed?', 'alpha-pro' ),
					'type'  => Elementor\Controls_Manager::SWITCHER,
				)
			);

			$document->add_group_control(
				Group_Control_Background::get_type(),
				array(
					'name'     => 'footer_background',
					'types'    => array( 'classic', 'gradient' ),
					'selector' => '.footer-' . $id,
				)
			);

			$document->end_controls_section();
		}
	}

	/**
	 * Add body class
	 *
	 * @since 1.0
	 */
	public function add_footer_body_class( $classes ) {
		// Fixed Footer
		global $alpha_layout;
		$footer = false;

		if ( alpha_get_feature( 'fs_pb_elementor' ) && defined( 'ELEMENTOR_VERSION' ) && isset( $alpha_layout['footer'] ) && ! empty( get_post_meta( $alpha_layout['footer'], '_elementor_data', true ) ) ) {
			$footer = $alpha_layout['footer'];
		}
		if ( ALPHA_NAME . '_template' == get_post_type() && 'footer' == get_post_meta( get_the_ID(), ALPHA_NAME . '_template_type', true ) ) {
			$footer = get_the_ID();
		}
		if ( $footer && ! wp_is_mobile() ) {
			$settings = get_post_meta( $footer, '_elementor_page_settings', true );

			if ( ! empty( $settings['alpha_fixed_footer'] ) ) {
				$classes[] = 'fixed-footer';
			}
		}

		return $classes;
	}
}

Alpha_Pro_Footer_Builder::get_instance();
