<?php
/**
 * Alpha Elementor Single Product Linked Products Widget
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;

class Alpha_Product_Linked_Products_Elementor_Widget extends Alpha_Posts_Grid_Elementor_Widget {

	public function get_name() {
		return ALPHA_NAME . '_widget_product_linked_products';
	}

	public function get_title() {
		return esc_html__( 'Linked Products', 'alpha-pro' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon eicon-product-related';
	}

	public function get_categories() {
		return array( 'alpha_single_product_widget', 'alpha_cart_widget' );
	}

	public function get_keywords() {
		return array( 'single', 'custom', 'layout', 'product', 'woocommerce', 'shop', 'store', 'linked_products', 'cart', 'cross', 'upsell', 'related' );
	}

	protected function register_controls() {
		parent::register_controls();

		$this->remove_control( 'source' );
		$this->update_control(
			'orderby',
			array(
				'type'        => Controls_Manager::SELECT,
				'label'       => esc_html__( 'Order by', 'alpha-pro' ),
				'options'     => array(
					''               => esc_html__( 'Default', 'alpha-pro' ),
					'ID'             => esc_html__( 'ID', 'alpha-pro' ),
					'title'          => esc_html__( 'Name', 'alpha-pro' ),
					'date'           => esc_html__( 'Date', 'alpha-pro' ),
					'modified'       => esc_html__( 'Modified', 'alpha-pro' ),
					'price'          => esc_html__( 'Price', 'alpha-pro' ),
					'rand'           => esc_html__( 'Random', 'alpha-pro' ),
					'rating'         => esc_html__( 'Rating', 'alpha-pro' ),
					'comment_count'  => esc_html__( 'Comment count', 'alpha-pro' ),
					'popularity'     => esc_html__( 'Total Sales', 'alpha-pro' ),
					'wishqty'        => esc_html__( 'Wish', 'alpha-pro' ),
					'sale_date_to'   => esc_html__( 'Sale End Date', 'alpha-pro' ),
					'sale_date_from' => esc_html__( 'Sale Start Date', 'alpha-pro' ),
				),
				'description' => esc_html__( 'Price, Rating, Total Sales, Wish, Sale End Date and Sale Start Date values work for only product post type.', 'alpha-pro' ),
				'condition'   => array(),
			)
		);
		global $post;
		if ( ( $post && ( is_cart() || 'cart' == get_post_meta( $post->ID, ALPHA_NAME . '_template_type', true ) ) ) ) {
				$this->update_control(
					'post_type',
					array(
						'type'        => Controls_Manager::HIDDEN,
						'label'       => esc_html__( 'Product Type', 'alpha-pro' ),
						'description' => esc_html__( 'Please select a product type of products to display related or upsell products', 'alpha-pro' ),
						'default'     => 'crosssell',
						'options'     => array(
							'crosssell' => esc_html__( 'Cross-sells Products', 'alpha-pro' ),
						),
						'condition'   => array(),
					)
				);
		} elseif ( alpha_is_product() || ( $post && 'product_layout' == get_post_meta( $post->ID, ALPHA_NAME . '_template_type', true ) ) ) {
			$this->update_control(
				'post_type',
				array(
					'type'        => Controls_Manager::SELECT,
					'label'       => esc_html__( 'Product Type', 'alpha-pro' ),
					'description' => esc_html__( 'Please select a product type of products to display related or upsell products', 'alpha-pro' ),
					'default'     => 'related',
					'options'     => array(
						'related' => esc_html__( 'Related Products', 'alpha-pro' ),
						'upsell'  => esc_html__( 'Upsells Products', 'alpha-pro' ),
					),
					'condition'   => array(),
				)
			);
		}

		$this->add_control(
			'linked_description',
			array(
				'raw'             => esc_html__( 'If there are no linked products, the widget will show products at random.', 'alpha-pro' ),
				'type'            => Controls_Manager::RAW_HTML,
				'content_classes' => 'alpha-notice notice-warning',
			),
			array(
				'position' => array(
					'at' => 'after',
					'of' => 'orderway',
				),
			)
		);

		$this->remove_control( 'post_tax' );
		$this->remove_control( 'post_filter_section' );
		$this->remove_control( 'pagination_style' );
	}

	protected function render() {

		$atts = $this->get_settings_for_display();
		if ( is_array( $atts['count'] ) ) {
			if ( ! empty( $atts['count']['size'] ) ) {
				$atts['count'] = $atts['count']['size'];
			} else {
				$atts['count'] = '4';
			}
		}

		if ( is_array( $atts['col_cnt'] ) ) {
			if ( isset( $atts['col_cnt']['size'] ) ) {
				$atts['col_cnt'] = $atts['col_cnt']['size'];
			} else {
				$atts['col_cnt'] = '';
			}
		}
		global $post;
		if ( ( $post && ( is_cart() || 'cart' == get_post_meta( $post->ID, ALPHA_NAME . '_template_type', true ) ) ) ) {
			// Cart builder - only use cross-sells
			$atts['shortcode_type'] = 'cart';
			require alpha_core_framework_path( ALPHA_CORE_FRAMEWORK_PATH . '/builders/single-product/widgets/linked-products/render-linked-products-elementor.php' );
		} elseif ( alpha_is_product() || ( $post && 'product_layout' == get_post_meta( $post->ID, ALPHA_NAME . '_template_type', true ) ) ) {
			/**
			 * Filters post products in single product builder
			 *
			 * @since 1.0
			 */
			apply_filters( 'alpha_single_product_builder_set_preview', false );
			require alpha_core_framework_path( ALPHA_CORE_FRAMEWORK_PATH . '/builders/single-product/widgets/linked-products/render-linked-products-elementor.php' );
			do_action( 'alpha_single_product_builder_unset_preview' );
		}
	}
}
