<?php
/**
 * Alpha Elementor Single Post Image Widget
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */
defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Css_Filter;

class Alpha_Single_Image_Elementor_Widget extends \Elementor\Widget_Base {

	public function get_name() {
		return ALPHA_NAME . '_single_image';
	}

	public function get_title() {
		return esc_html__( 'Featured Image', 'alpha-pro' );
	}

	public function get_icon() {
		return 'alpha-elementor-widget-icon eicon-featured-image';
	}

	public function get_categories() {
		return array( 'alpha_single_widget' );
	}

	public function get_keywords() {
		return array( 'single', 'custom', 'layout', 'post', 'image', 'thumbnail', 'gallery' );
	}

	public function get_script_depends() {
		$depends = array( 'swiper' );
		if ( alpha_is_elementor_preview() ) {
			$depends[] = 'alpha-elementor-js';
		}
		return $depends;
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_single_image',
			array(
				'label' => esc_html__( 'Image', 'alpha-pro' ),
			)
		);

			$this->add_group_control(
				Elementor\Group_Control_Image_Size::get_type(),
				array(
					'name'    => 'thumbnail', // Usage: `{name}_size` and `{name}_custom_dimension`
					'exclude' => array( 'custom' ),
					'default' => 'full',
				)
			);
			

			$this->add_responsive_control(
				'align',
				array(
					'label' => esc_html__( 'Alignment', 'alpha-pro' ),
					'type' => Controls_Manager::CHOOSE,
					'options' => array(
						'left' => array(
							'title' => esc_html__( 'Left', 'alpha-pro' ),
							'icon' => 'eicon-text-align-left',
						),
						'center' => array(
							'title' => esc_html__( 'Center', 'alpha-pro' ),
							'icon' => 'eicon-text-align-center',
						),
						'right' => array(
							'title' => esc_html__( 'Right', 'alpha-pro' ),
							'icon' => 'eicon-text-align-right',
						),
					),
					'selectors' => array(
						'{{WRAPPER}}' => 'text-align: {{VALUE}};',
					),
				)
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_single_image_style',
			array(
				'label' => esc_html__( 'Image', 'alpha-pro' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

			$this->add_responsive_control(
				'width',
				array(
					'label' => esc_html__( 'Width', 'alpha-pro' ),
					'type' => Controls_Manager::SLIDER,
					'default' => array(
						'unit' => '%',
					),
					'tablet_default' => array(
						'unit' => '%',
					),
					'mobile_default' => array(
						'unit' => '%',
					),
					'size_units' => array( 'px', '%', 'em', 'rem', 'vw', 'custom' ),
					'range' => array(
						'%' => array(
							'min' => 1,
							'max' => 100,
						),
						'px' => array(
							'min' => 1,
							'max' => 1000,
						),
						'vw' => array(
							'min' => 1,
							'max' => 100,
						),
					),
					'selectors' => array(
						'{{WRAPPER}} img' => 'width: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_responsive_control(
				'space',
				array(
					'label' => esc_html__( 'Max Width', 'alpha-pro' ),
					'type' => Controls_Manager::SLIDER,
					'default' => array(
						'unit' => '%',
					),
					'tablet_default' => array(
						'unit' => '%',
					),
					'mobile_default' => array(
						'unit' => '%',
					),
					'size_units' => array( 'px', '%', 'em', 'rem', 'vw', 'custom' ),
					'range' => array(
						'%' => array(
							'min' => 1,
							'max' => 100,
						),
						'px' => array(
							'min' => 1,
							'max' => 1000,
						),
						'vw' => array(
							'min' => 1,
							'max' => 100,
						),
					),
					'selectors' => array(
						'{{WRAPPER}} img' => 'max-width: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_responsive_control(
				'height',
				array(
					'label' => esc_html__( 'Height', 'alpha-pro' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => array( 'px', '%', 'em', 'rem', 'vh', 'custom' ),
					'range' => array(
						'px' => array(
							'min' => 1,
							'max' => 500,
						),
						'vh' => array(
							'min' => 1,
							'max' => 100,
						),
					),
					'selectors' => array(
						'{{WRAPPER}} img' => 'height: {{SIZE}}{{UNIT}};',
					),
				)
			);

			$this->add_responsive_control(
				'object-fit',
				array(
					'label' => esc_html__( 'Object Fit', 'alpha-pro' ),
					'type' => Controls_Manager::SELECT,
					'condition' => array(
						'height[size]!' => '',
					),
					'options' => array(
						'' => esc_html__( 'Default', 'alpha-pro' ),
						'fill' => esc_html__( 'Fill', 'alpha-pro' ),
						'cover' => esc_html__( 'Cover', 'alpha-pro' ),
						'contain' => esc_html__( 'Contain', 'alpha-pro' ),
					),
					'default' => '',
					'selectors' => array(
						'{{WRAPPER}} img' => 'object-fit: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'separator_panel_style',
				array(
					'type' => Controls_Manager::DIVIDER,
					'style' => 'thick',
				)
			);

			$this->start_controls_tabs( 'image_effects' );

			$this->start_controls_tab( 'normal',
				array(
					'label' => esc_html__( 'Normal', 'alpha-pro' ),
				)
			);

			$this->add_control(
				'opacity',
				array(
					'label' => esc_html__( 'Opacity', 'alpha-pro' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'px' => array(
							'max' => 1,
							'min' => 0.10,
							'step' => 0.01,
						),
					),
					'selectors' => array(
						'{{WRAPPER}} img' => 'opacity: {{SIZE}};',
					),
				)
			);

			$this->add_group_control(
				Group_Control_Css_Filter::get_type(),
				[
					'name' => 'css_filters',
					'selector' => '{{WRAPPER}} img',
				]
			);

			$this->end_controls_tab();

			$this->start_controls_tab( 'hover',
				array(
					'label' => esc_html__( 'Hover', 'alpha-pro' ),
				)
			);

			$this->add_control(
				'opacity_hover',
				array(
					'label' => esc_html__( 'Opacity', 'alpha-pro' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'px' => array(
							'max' => 1,
							'min' => 0.10,
							'step' => 0.01,
						),
					),
					'selectors' => array(
						'{{WRAPPER}}:hover img' => 'opacity: {{SIZE}};',
					),
				)
			);

			$this->add_group_control(
				Group_Control_Css_Filter::get_type(),
				array(
					'name' => 'css_filters_hover',
					'selector' => '{{WRAPPER}}:hover img',
				)
			);

			$this->add_control(
				'background_hover_transition',
				array(
					'label' => esc_html__( 'Transition Duration', 'alpha-pro' ),
					'type' => Controls_Manager::SLIDER,
					'range' => array(
						'px' => array(
							'max' => 3,
							'step' => 0.1,
						),
					),
					'selectors' => array(
						'{{WRAPPER}} img' => 'transition-duration: {{SIZE}}s',
					),
				)
			);
			
			$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function render() {
		/**
		 * Filters the preview for editor and template.
		 *
		 * @since 1.0
		 */
		if ( apply_filters( 'alpha_single_builder_set_preview', false ) ) {
			alpha_set_loop_prop( 'single_image_size', $this->get_settings_for_display( 'thumbnail_size' ) );
			alpha_get_template_part( 'posts/single/post', 'media' );
			alpha_reset_loop();
			do_action( 'alpha_single_builder_unset_preview' );
		}
	}
}
