<?php
/**
 * Alpha Pro bbPress Compatibility.
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */

defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;

if ( ! class_exists( 'Alpha_Pro_BBPress' ) ) {
	class Alpha_Pro_BBPress extends Alpha_Base {

		/**
		 * The Constructor
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_filter( 'alpha_breadcrumb_items', array( $this, 'update_breadcrumbs' ) );
			add_filter( 'bbp_no_breadcrumb', '__return_true' );
			add_action( 'wp_footer', array( $this, 'enqueue_style' ), 19 );
		}

		/**
		 * Enqueue styles
		 *
		 * @since 1.0
		 */
		public function enqueue_style() {
			wp_enqueue_style( 'alpha-pro-bbpress', ALPHA_PRO_INC_URI . '/plugins/bbpress/bbpress' . ( is_rtl() ? '-rtl' : '' ) . '.min.css', array(), ALPHA_PRO_VERSION );
		}

		/**
		 * Update breadcrumb in bbpress single topic, search and user info pages
		 *
		 * @since 1.0
		 */
		public function update_breadcrumbs( $breadcrumbs ) {
			if ( is_bbpress() ) {
				add_filter( 'bbp_no_breadcrumb', '__return_false' );

				ob_start();
				echo bbp_get_breadcrumb();
				$bbp_breadcrumb = ob_get_clean();
				add_filter( 'bbp_no_breadcrumb', '__return_true' );

				if ( $bbp_breadcrumb ) {
					$delimiter = alpha_strip_script_tags( alpha_get_option( 'ptb_delimiter' ) );
					if ( ! $delimiter ) {
						$delimiter = '<i class="' . ALPHA_ICON_PREFIX . '-icon-angle-' . ( is_rtl() ? 'left' : 'right' ) . '"></i>';
					}

					$bbp_breadcrumb = str_replace( array( '<div class="bbp-breadcrumb"><p>', '<span class="bbp-breadcrumb-sep">', '&rsaquo;', '&lsaquo;', '</p></div>' ), array( '<div class="breadcrumb">', '<span class="delimiter">', $delimiter, $delimiter, '</div>' ), $bbp_breadcrumb );
					echo $bbp_breadcrumb;
					return '';
				}
			}

			return $breadcrumbs;
		}
	}
}

Alpha_Pro_BBPress::get_instance();
