/**
 * Alpha Pro Elementor Preview
 * 
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 * 
 */
'use strict';

window.themeAdmin = window.themeAdmin || {};

( function ( $ ) {

    function initSlider( $el ) {
        if ( $el.length != 1 ) {
            return;
        }

        // var customDotsHtml = '';
        if ( $el.data( 'slider' ) ) {
            $el.data( 'slider' ).destroy();
            $el.children( '.slider-slide' ).removeClass( 'slider-slide' );
            $el.parent().siblings( '.slider-thumb-dots' ).off( 'click.preview' );
            $el.removeData( 'slider' );
        }

        theme.slider( $el, {}, true );

        // Register events for thumb dots
        var $dots = $el.parent().siblings( '.slider-thumb-dots' );
        if ( $dots.length ) {
            var slider = $el.data( 'slider' );
            $dots.on( 'click.preview', 'button', function () {
                if ( !slider.destroyed ) {
                    slider.slideTo( $( this ).index(), 300 );
                }
            } );
            slider && slider.on( 'transitionEnd', function () {
                $dots.children().removeClass( 'active' ).eq( this.realIndex ).addClass( 'active' );
            } )
        }

        Object.setPrototypeOf( $el.get( 0 ), HTMLElement.prototype );
    }

    themeAdmin.themeProElementorPreview = themeAdmin.themeProElementorPreview || {}
    themeAdmin.themeProElementorPreview.completed = false;
    themeAdmin.themeProElementorPreview.fnArray = [];
    themeAdmin.themeProElementorPreview.init = function () {
        var self = this;

        elementorFrontend.hooks.addAction( 'frontend/element_ready/section', function ( $obj ) {
            self.completed ? self.initSection( $obj ) : self.fnArray.push( {
                fn: self.initSection,
                arg: $obj
            } );
        } );
    }

    themeAdmin.themeProElementorPreview.onComplete = function () {
        var self = this;
        self.completed = true;
        self.initWidgets();

    }

    themeAdmin.themeProElementorPreview.initSection = function ( $obj ) {
        var $container = $obj.children( '.elementor-container' ),
            $row = 0 == $obj.find( '.elementor-row' ).length ? $container : $container.children( '.elementor-row' ),
            $section = $row.closest( '.elementor-element' );

        if ( !$row.hasClass( 'parallax' ) && $row.attr( 'data-parallax-options' ) && $.fn.themeParallax ) {
            var pluginOptions = JSON.parse( $row.attr( 'data-parallax-options' ) ),
                opts;

            $section.addClass( 'parallax' );
            if ( 'left' == pluginOptions.direction || 'right' == pluginOptions.direction ) {
                $section.removeClass( 'parallax-vertical' ).addClass( 'parallax-horizontal' );
            } else {
                $section.removeClass( 'parallax-horizontal' ).addClass( 'parallax-vertical' );
            }
            $section.attr( 'data-parallax-options', $row.attr( 'data-parallax-options' ) );
            $section.attr( 'data-parallax-image', $row.attr( 'data-parallax-image' ) );

            if ( $section.data( '__parallax' ) && $section.data( '__parallax' ).options ) {
                var old_speed = $section.data( '__parallax' ).options.speed;
                var old_direction = $section.data( '__parallax' ).options.direction || '';
                if ( parseFloat( old_speed ) !== parseFloat( pluginOptions.speed ) || ( pluginOptions.direction !== old_direction ) ) {
                    $section.removeData( '__parallax' );
                }
            }

            if ( pluginOptions )
                opts = pluginOptions;

            $section.themeParallax( opts );
        } else {
            $section.removeClass( 'parallax parallax-horizontal parallax-vertical' );
            $section.removeAttr( 'data-parallax-options' );
            $section.removeAttr( 'data-parallax-image' );
            $section.removeData( '__parallax' );
        }

        // Execute cursor effects once
        if ( window.cursor_settings && window.cursor_settings.length ) {
            var ins = $( document.body ).data( '__cursorEffect' );
            if ( ins ) {
                $( document.body ).removeData( '__cursorEffect' );
            }

            if ( $.fn.themeCursorType ) {
                $( document.body ).themeCursorType();
            }
        }
    }

    themeAdmin.themeProElementorPreview.initWidgets = function () {
        // Widget for banner
        var bannerWidgets = [ 'widget_banner', 'widget_products_banner' ];
        bannerWidgets.forEach( function ( widget_name ) {
            elementorFrontend.hooks.addAction( 'frontend/element_ready/' + alpha_vars.theme + '_' + widget_name + '.default', function ( $obj ) {
                if ( $obj.find( '.parallax' ).length && $.fn.themeParallax ) {
                    var $banner = $obj.find( '.parallax' ),
                        pluginOptions = JSON.parse( $banner.attr( 'data-parallax-options' ) ),
                        opts;

                    if ( $banner.data( '__parallax' ) && $banner.data( '__parallax' ).options ) {
                        var old_speed = $banner.data( '__parallax' ).options.speed;
                        var old_direction = $banner.data( '__parallax' ).options.direction || '';
                        if ( parseFloat( old_speed ) !== parseFloat( pluginOptions.speed ) || ( pluginOptions.direction !== old_direction ) ) {
                            $banner.removeData( '__parallax' );
                        }
                    }

                    if ( pluginOptions )
                        opts = pluginOptions;

                    $banner.themeParallax( opts );
                }

                theme.appearAnimate( '.appear-animate' );
                jQuery( window ).trigger( 'appear.check' );

                if ( $obj.find( '.banner-stretch' ).length ) {
                    $obj.addClass( 'elementor-widget-alpha_banner_stretch' );
                } else {
                    $obj.removeClass( 'elementor-widget-alpha_banner_stretch' );
                }

                $obj.find( '.banner-item' ).each( function () {
                    var settings = $( this ).data( 'motion' );
                    if ( 'object' == typeof settings ) {
                        if ( 'undefined' != typeof settings.track ) {
                            $( this ).children().wrap( '<div class="layer"></div>' );
                        }

                        $( this ).children().wrap( '<div class="floating-wrapper layer-wrapper elementor-repeater-item-wrapper"></div>' );

                        themeAdmin.themeElementorPreview.initWidgetAdvanced( $( this ).children( '.floating-wrapper' ), { motion: settings } ); // floating effect
                    }
                } );
            } );
        } );

        elementorFrontend.hooks.addAction( 'frontend/element_ready/' + alpha_vars.theme + '_widget_menu.default', function ( $obj ) {
            if ( $obj.find( '.flyout-menu-container' ).length || $obj.find( '.collapsible-menu' ).length ) { // flyout menu
                theme.menu.addToggleButtons( $obj.find( 'li' ) );
            } else {
                $obj.find( 'li .toggle-btn' ).remove();
            }
        } );

    }

    if ( 'undefined' != typeof themeAdmin.themeElementorPreview ) {
        themeAdmin.themeElementorPreview.initWidgetAdvanced = function ( $obj, settings ) {
            var $parent = $obj.parent(),
                widget_settings;

            if ( $parent.hasClass( 'slider-wrapper' ) ) {
                initSlider( $parent );
            } else if ( $parent.hasClass( 'slider-container' ) && $obj.siblings( '.slider-wrapper' ).length ) {
                var $slider = $obj.siblings( '.slider-wrapper' );
                $obj.remove().appendTo( $slider );
                initSlider( $slider );
            }
            if ( 'undefined' == typeof settings ) {
                widget_settings = this.widgetEditorSettings( $obj.data( 'id' ) );
            } else {
                widget_settings = settings;
            }

            if ( typeof theme == 'object' && typeof theme.initAdvancedMotions == 'function' && $obj.attr( 'data-plugin' ) == 'skrollr' ) {
                theme.initAdvancedMotions( $obj, 'destroy' );
            }

            // Ribbon
            if ( widget_settings.ribbon && widget_settings.ribbon.enabled ) {
                if ( 'type-4' == widget_settings.ribbon.type || 'type-5' == widget_settings.ribbon.type ) {
                    $obj.addClass( 'ribbon-widget overflow-hidden' );
                } else {
                    $obj.removeClass( 'overflow-hidden' ).addClass( 'ribbon-widget' );
                }

                var $ribbon_after;

                if ( $obj.hasClass( 'elementor-section' ) ) {
                    if ( $obj.children( '.elementor-container' ).length ) {
                        $ribbon_after = $obj.children( '.elementor-container' );
                    } else if ( $obj.find( '.tab' ).length ) {
                        $ribbon_after = $obj.find( '.tab-content' );
                    } else {
                        $ribbon_after = $obj.find( '.elementor-column' ).eq( 0 );
                    }
                } else if ( $obj.hasClass( 'elementor-column' ) ) {
                    if ( $obj.children( '.card-header' ).length ) {
                        $ribbon_after = $obj.children( '.card-header' ).next();
                    } else {
                        $ribbon_after = $obj.children().eq( 0 );
                    }
                } else {
                    $ribbon_after = $obj.find( '.elementor-widget-container' );
                }

                if ( !$ribbon_after.siblings( '.ribbon' ).length ) {
                    var $ribbon =
                        '<div class="ribbon ribbon-' + $obj.data( 'id' ) + ' ribbon-' + widget_settings.ribbon.type + ' ribbon-' + widget_settings.ribbon.position + '">' +
                        '<span class="ribbon-text">' + ( widget_settings.ribbon.text ? widget_settings.ribbon.text : alpha_vars.texts.ribbon ) + '</span>' +
                        '</div>';

                    $ribbon_after.before( $ribbon );
                }
            } else {
                $obj.removeClass( 'ribbon-widget overflow-hidden' );
            }

            // Duplex
            if ( widget_settings.duplex && widget_settings.duplex.enabled ) {
                $obj.addClass( 'duplex-widget' );

                var $duplex_after;

                if ( $obj.hasClass( 'elementor-section' ) ) {
                    if ( $obj.children( '.elementor-container' ).length ) {
                        $duplex_after = $obj.children( '.elementor-container' );
                    } else {
                        $duplex_after = $obj.find( '.elementor-column' ).eq( 0 );
                    }
                } else if ( $obj.hasClass( 'elementor-column' ) ) {
                    if ( $obj.children( '.card-header' ).length ) {
                        $duplex_after = $obj.children( '.card-header' ).next();
                    } else {
                        $duplex_after = $obj.children().eq( 0 );
                    }
                } else {
                    $duplex_after = $obj.find( '.elementor-widget-container' );
                }

                if ( !$duplex_after.siblings( '.duplex-wrap' ).length ) {
                    var $duplex = '';
                    if ( 'text' == widget_settings.duplex.type ) {
                        $duplex =
                            '<div class="duplex-wrap duplex-wrap-' + $obj.data( 'id' ) + ( widget_settings.duplex.origin ? ( ' ' + widget_settings.duplex.origin ) : '' ) + '">' +
                            '<span class="duplex duplex-text">' + widget_settings.duplex.text + '</span>' +
                            '</div>';
                    } else {
                        $duplex =
                            '<div class="duplex-wrap duplex-wrap-' + $obj.data( 'id' ) + ( widget_settings.duplex.origin ? ( ' ' + widget_settings.duplex.origin ) : '' ) + '">' +
                            '<div class="duplex duplex-image" alt="">' +
                            '<img src="' + widget_settings.duplex.image.url + '">' +
                            '</div>' +
                            '</div>';
                    }

                    $duplex_after.before( $duplex );
                }
            }

            if ( 'object' == typeof widget_settings && widget_settings.motion ) {
                if ( 'undefined' != typeof widget_settings.motion.track ) {
                    $obj.attr( 'data-plugin', 'floating' );

                    var trackOptions = widget_settings.motion.track,
                        settings = {};

                    if ( 'yes' == trackOptions[ 'opposite' ] ) {
                        settings[ 'invertX' ] = true;
                        settings[ 'invertY' ] = true;
                    } else {
                        settings[ 'invertX' ] = false;
                        settings[ 'invertY' ] = false;
                    }

                    if ( 'horizontal' == trackOptions[ 'dir' ] ) {
                        settings[ 'limitY' ] = '0';
                    } else if ( 'vertical' == trackOptions[ 'dir' ] ) {
                        settings[ 'limitX' ] = '0';
                    }

                    $obj.attr( 'data-options', JSON.stringify( settings ) );
                    $obj.attr( 'data-floating-depth', trackOptions[ 'speed' ] );

                    if ( $.fn.parallax ) {
                        theme.initFloatingElements( $obj );
                    } else {
                        if ( alpha_elementor.core_framework_url ) {
                            $( document.createElement( 'script' ) ).attr( 'id', 'jquery-floating' ).appendTo( 'body' ).attr( 'src', alpha_elementor.core_framework_url + '/assets/js/jquery.floating.min.js' ).on( 'load', function () {
                                theme.initFloatingElements( $obj );
                            } );
                        }
                    }

                    return;
                }

                if ( 'undefined' != typeof widget_settings.motion.scroll ) {
                    $obj.attr( 'data-plugin', 'skrollr' );

                    var scrollOptions = widget_settings.motion.scroll,
                        pos = scrollOptions.scrollStop,
                        settings = {};


                    var from = { transform: { translate: {} } },
                        to = { transform: { translate: {} } };
                    if ( 'object' == typeof scrollOptions[ 'horizontal' ] ) {
                        var size = parseFloat( scrollOptions[ 'horizontal' ][ 'speed' ] ) * 50;
                        if ( 'left' == scrollOptions[ 'horizontal' ][ 'dir' ] ) {
                            from[ 'transform' ][ 'translate' ][ 'translateX' ] = size + '%';
                            to[ 'transform' ][ 'translate' ][ 'translateX' ] = -size + '%';
                        } else {
                            from[ 'transform' ][ 'translate' ][ 'translateX' ] = -size + '%';
                            to[ 'transform' ][ 'translate' ][ 'translateX' ] = size + '%';
                        }
                    }
                    if ( 'object' == typeof scrollOptions[ 'vertical' ] ) {
                        var size = parseFloat( scrollOptions[ 'vertical' ][ 'speed' ] ) * 50;
                        if ( 'up' == scrollOptions[ 'vertical' ][ 'dir' ] ) {
                            from[ 'transform' ][ 'translate' ][ 'translateY' ] = size + '%';
                            to[ 'transform' ][ 'translate' ][ 'translateY' ] = -size + '%';
                        } else {
                            from[ 'transform' ][ 'translate' ][ 'translateY' ] = -size + '%';
                            to[ 'transform' ][ 'translate' ][ 'translateY' ] = size + '%';
                        }
                    }
                    if ( 'object' == typeof scrollOptions[ 'opacity' ] ) {
                        var size = Math.max( 0, 1 - parseFloat( scrollOptions[ 'opacity' ][ 'speed' ] ) / 5 );
                        if ( 'in' == scrollOptions[ 'opacity' ][ 'dir' ] ) {
                            from[ 'opacity' ] = size;
                            to[ 'opacity' ] = 1;
                        } else {
                            from[ 'opacity' ] = 1;
                            to[ 'opacity' ] = size;
                        }
                    }
                    if ( 'object' == typeof scrollOptions[ 'rotate' ] ) {
                        var size = parseFloat( scrollOptions[ 'rotate' ][ 'speed' ] ) * 50;
                        if ( 'left' == scrollOptions[ 'rotate' ][ 'dir' ] ) {
                            from[ 'transform' ][ 'rotate' ] = '0deg';
                            to[ 'transform' ][ 'rotate' ] = ( -360 * size / 50 ) + 'deg';
                        } else {
                            from[ 'transform' ][ 'rotate' ] = '0deg';
                            to[ 'transform' ][ 'rotate' ] = ( 360 * size / 50 ) + 'deg';
                        }
                    }
                    if ( 'object' == typeof scrollOptions[ 'zoom' ] ) {
                        var size = scrollOptions[ 'zoom' ][ 'speed' ];
                        if ( 'in' == scrollOptions[ 'zoom' ][ 'dir' ] ) {
                            from[ 'transform' ][ 'scale' ] = Math.max( 0, 1 - size / 10 );
                            to[ 'transform' ][ 'scale' ] = 1;
                        } else if ( 'out' == scrollOptions[ 'zoom' ][ 'dir' ] ) {
                            from[ 'transform' ][ 'scale' ] = 1 + size / 10;
                            to[ 'transform' ][ 'scale' ] = 1;
                        } else if ( 'in-x' == scrollOptions[ 'zoom' ][ 'dir' ] ) {
                            from[ 'width' ] = ( Math.max( 0, 100 - size * 10 ) ) + '%';
                            to[ 'width' ] = '100%';
                            from[ 'margin' ] = '0 auto';
                            to[ 'margin' ] = '0 auto';
                        } else {
                            from[ 'width' ] = '100%';
                            to[ 'width' ] = ( 100 + size * 10 ) + '%';
                            from[ 'margin' ] = '0 auto';
                            to[ 'margin' ] = '0 auto';
                        }
                    }

                    settings[ 'data-bottom-top' ] = '';
                    settings[ 'data-' + pos ] = '';

                    if ( 'undefined' == typeof from.transform.translate.translateX && 'undefined' == typeof from.transform.translate.translateY ) {
                        delete from.transform.translate;
                        delete to.transform.translate;
                    }
                    if ( !Object.keys( from.transform ).length ) {
                        delete from.transform;
                        delete to.transform;
                    }
                    Object.entries( from ).forEach( ( [ key, styles ] ) => {
                        settings[ 'data-bottom-top' ] += key + ': ';
                        if ( 'transform' == key ) {
                            Object.entries( styles ).forEach( ( [ transform, style ] ) => {
                                if ( 'translate' == transform ) {
                                    if ( Object.keys( style ).length ) {
                                        if ( 'undefined' != typeof style[ 'translateX' ] && 'undefined' != typeof style[ 'translateY' ] ) {
                                            settings[ 'data-bottom-top' ] += transform + '(' + style[ 'translateX' ] + ', ' + style[ 'translateY' ] + ')';
                                        } else if ( 'undefined' != typeof style[ 'translateX' ] ) {
                                            settings[ 'data-bottom-top' ] += transform + '(' + style[ 'translateX' ] + ', 0' + ')';
                                        } else {
                                            settings[ 'data-bottom-top' ] += transform + '(0, ' + style[ 'translateY' ] + ')';
                                        }
                                    }
                                } else {
                                    settings[ 'data-bottom-top' ] += ' ' + transform + '(' + style + ')';
                                }
                            } );
                            settings[ 'data-bottom-top' ] += ';';
                        } else {
                            settings[ 'data-bottom-top' ] += styles + ';';
                        }
                        settings[ 'data-bottom-top' ] += ' ';
                    } );

                    Object.entries( to ).forEach( ( [ key, styles ] ) => {
                        settings[ 'data-' + pos ] += key + ': ';
                        if ( 'transform' == key ) {
                            Object.entries( styles ).forEach( ( [ transform, style ] ) => {
                                if ( 'translate' == transform ) {
                                    if ( Object.keys( style ).length ) {
                                        if ( 'undefined' != typeof style[ 'translateX' ] && 'undefined' != typeof style[ 'translateY' ] ) {
                                            settings[ 'data-' + pos ] += transform + '(' + style[ 'translateX' ] + ', ' + style[ 'translateY' ] + ')';
                                        } else if ( 'undefined' != typeof style[ 'translateX' ] ) {
                                            settings[ 'data-' + pos ] += transform + '(' + style[ 'translateX' ] + ', 0' + ')';
                                        } else {
                                            settings[ 'data-' + pos ] += transform + '(0, ' + style[ 'translateY' ] + ')';
                                        }
                                    }
                                } else {
                                    settings[ 'data-' + pos ] += ' ' + transform + '(' + style + ')';
                                }
                            } );
                            settings[ 'data-' + pos ] += ';';
                        } else {
                            settings[ 'data-' + pos ] += styles + ';';
                        }
                        settings[ 'data-' + pos ] += ' ';
                    } );

                    $obj.attr( 'data-options', JSON.stringify( settings ) );

                    if ( typeof skrollr != 'object' ) {
                        if ( alpha_elementor.core_framework_url ) {
                            $( document.createElement( 'script' ) ).attr( 'id', 'jquery-skrollr' ).appendTo( 'body' ).attr( 'src', alpha_elementor.core_framework_url + '/assets/js/skrollr.min.js' ).on( 'load', function () {
                                theme.initAdvancedMotions();
                            } );
                        }
                    }
                }
            }

            if ( typeof skrollr == 'object' && typeof skrollr.init == 'function' ) {
                theme.initAdvancedMotions();
            }
        }
        themeAdmin.themeElementorPreview.widgetEditorSettings = function ( widgetId ) {
            var editorElements = null,
                widgetData = {};

            if ( !window.elementor.hasOwnProperty( 'elements' ) ) {
                return false;
            }

            editorElements = window.elementor.elements;

            if ( !editorElements.models ) {
                return false;
            }

            var found = false;

            $.each( editorElements.models, function ( index, obj ) {
                if ( found ) {
                    return;
                }

                if ( widgetId == obj.id ) {
                    widgetData = obj.attributes.settings.attributes;
                    return;
                }

                $.each( obj.attributes.elements.models, function ( index, obj ) {
                    if ( found ) {
                        return;
                    }

                    if ( widgetId == obj.id ) {
                        widgetData = obj.attributes.settings.attributes;
                        return;
                    }

                    $.each( obj.attributes.elements.models, function ( index, obj ) {
                        if ( found ) {
                            return;
                        }

                        if ( widgetId == obj.id ) {
                            widgetData = obj.attributes.settings.attributes;
                            return;
                        }

                        $.each( obj.attributes.elements.models, function ( index, obj ) {
                            if ( found ) {
                                return;
                            }

                            if ( widgetId == obj.id ) {
                                widgetData = obj.attributes.settings.attributes;
                                return;
                            }

                            $.each( obj.attributes.elements.models, function ( index, obj ) {
                                if ( found ) {
                                    return;
                                }

                                if ( widgetId == obj.id ) {
                                    widgetData = obj.attributes.settings.attributes;
                                }

                            } );

                        } );
                    } );

                } );

            } );

            var motion = {};
            if ( widgetData[ 'alpha_scroll' ] ) {
                motion[ 'scroll' ] = {};
                if ( widgetData[ 'alpha_scroll_horizontal_toggle' ] ) {
                    motion[ 'scroll' ][ 'horizontal' ] = { dir: widgetData[ 'alpha_scroll_horizontal_dir' ], speed: typeof widgetData[ 'alpha_scroll_horizontal_speed' ][ 'size' ] ? widgetData[ 'alpha_scroll_horizontal_speed' ][ 'size' ] : 1 };
                }
                if ( widgetData[ 'alpha_scroll_vertical_toggle' ] ) {
                    motion[ 'scroll' ][ 'vertical' ] = { dir: widgetData[ 'alpha_scroll_vertical_dir' ], speed: typeof widgetData[ 'alpha_scroll_vertical_speed' ][ 'size' ] ? widgetData[ 'alpha_scroll_vertical_speed' ][ 'size' ] : 1 };
                }
                if ( widgetData[ 'alpha_scroll_opacity_toggle' ] ) {
                    motion[ 'scroll' ][ 'opacity' ] = { dir: widgetData[ 'alpha_scroll_opacity_dir' ], speed: typeof widgetData[ 'alpha_scroll_opacity_speed' ][ 'size' ] ? widgetData[ 'alpha_scroll_opacity_speed' ][ 'size' ] : 0.4 };
                }
                if ( widgetData[ 'alpha_scroll_rotate_toggle' ] ) {
                    motion[ 'scroll' ][ 'rotate' ] = { dir: widgetData[ 'alpha_scroll_rotate_dir' ], speed: typeof widgetData[ 'alpha_scroll_rotate_speed' ][ 'size' ] ? widgetData[ 'alpha_scroll_rotate_speed' ][ 'size' ] : 1 };
                }
                if ( widgetData[ 'alpha_scroll_zoom_toggle' ] ) {
                    motion[ 'scroll' ][ 'zoom' ] = { dir: widgetData[ 'alpha_scroll_zoom_dir' ], speed: typeof widgetData[ 'alpha_scroll_zoom_speed' ][ 'size' ] ? widgetData[ 'alpha_scroll_zoom_speed' ][ 'size' ] : 1 };
                }
                motion[ 'scroll' ][ 'scrollStop' ] = 'undefined' == typeof widgetData[ 'alpha_scroll_stop' ] ? 'center' : widgetData[ 'alpha_scroll_stop' ];
            }
            if ( widgetData[ 'alpha_track' ] ) {
                motion[ 'track' ] = {
                    dir: widgetData[ 'alpha_track_dir' ],
                    opposite: widgetData[ 'alpha_track_oppisite' ],
                    speed: widgetData[ 'alpha_track_speed' ][ 'size' ] ? widgetData[ 'alpha_track_speed' ][ 'size' ] : 0.5,
                }
            }

            var duplex = {};
            if ( 'true' == widgetData[ 'alpha_widget_duplex' ] ) {
                duplex.enabled = true;
                duplex.origin = widgetData[ 'alpha_widget_duplex_origin' ];
                if ( 'text' == widgetData[ 'alpha_widget_duplex_type' ] ) {
                    duplex.type = 'text';
                    duplex.text = widgetData[ 'alpha_widget_duplex_text' ];
                } else {
                    duplex.type = 'image';
                    duplex.image = {
                        url: widgetData[ 'alpha_widget_duplex_image' ][ 'url' ]
                    };
                }
            }

            var ribbon = {};
            if ( 'true' == widgetData[ 'alpha_widget_ribbon' ] ) {
                ribbon.enabled = true;
                ribbon.type = widgetData[ 'alpha_widget_ribbon_type' ];
                ribbon.text = widgetData[ 'alpha_widget_ribbon_text' ];
                ribbon.position = widgetData[ 'alpha_widget_ribbon_position' ];
            }

            return { motion: motion, duplex: duplex, ribbon: ribbon };
        }
    }

    /**
     * Setup AlphaElementorPreview
     */
    $( window ).on( 'load', function () {
        if ( typeof elementorFrontend != 'undefined' && typeof theme != 'undefined' ) {
            if ( elementorFrontend.hooks ) {
                themeAdmin.themeProElementorPreview.init();
                themeAdmin.themeProElementorPreview.onComplete();
            } else {
                elementorFrontend.on( 'components:init', function () {
                    themeAdmin.themeProElementorPreview.init();
                    themeAdmin.themeProElementorPreview.onComplete();
                } );
            }
        }
    } );
} )( jQuery );