<?php
/**
 * Alpha Pro Elementor partials.
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */

defined( 'ABSPATH' ) || die;

use Elementor\Controls_Manager;

if ( ! class_exists( 'Alpha_Pro_Elementor' ) ) {
	class Alpha_Pro_Elementor extends Alpha_Base {

		/**
		 * The Constructor
		 *
		 * @since 1.0
		 */
		public function __construct() {

			add_action( 'elementor/editor/after_enqueue_scripts', array( $this, 'enqueue_editor_scripts' ), 20 );

			// Include Partials

			if ( function_exists( 'alpha_is_elementor_preview' ) && alpha_is_elementor_preview() ) {
				add_action( 'wp_enqueue_scripts', array( $this, 'load_preview_scripts' ) );
			}

			add_filter( 'alpha_elementor_section_addon_presets', array( $this, 'add_section_presets' ), 10, 1 );
		}

		/**
		 * Load extended elementor css
		 *
		 * @since 1.0
		 */
		public function load_preview_scripts() {
			wp_enqueue_script( 'alpha-pro-elementor', ALPHA_PRO_INC_URI . '/plugins/elementor/assets/pro-elementor' . ALPHA_JS_SUFFIX, array( 'jquery-core' ), ALPHA_PRO_VERSION, true );
		}

		/**
		 * Load Elementor Editor Scripts
		 *
		 * @since 1.0
		 */
		public function enqueue_editor_scripts() {
			wp_enqueue_script( 'alpha-pro-elementor-admin', ALPHA_PRO_INC_URI . '/plugins/elementor/assets/pro-elementor-admin' . ALPHA_JS_SUFFIX, array( 'elementor-editor' ), ALPHA_PRO_VERSION, true );
		}

		/**
		 * Add additonal presets for section
		 *
		 * @since 1.0
		 */
		public function add_section_presets( $additional_presets ) {
			$new_presets = array(
				2 => array(
					array(
						'preset' => array( 'flex-1', 'flex-auto' ),
					),
				),
				3 => array(
					array(
						'preset' => array( 'flex-1', 'flex-auto', 'flex-1' ),
					),
					array(
						'preset' => array( 'flex-auto', 'flex-1', 'flex-auto' ),
					),
				),
			);

			foreach ( $new_presets as $column_cnt => $presets ) {
				$additional_presets[ $column_cnt ] = array_merge( $presets, $additional_presets[ $column_cnt ] );
			}

			return $additional_presets;
		}
	}
}

Alpha_Pro_Elementor::get_instance();
