<?php

/**
 * Get search form
 *
 * @since 1.0
 */
if ( ! function_exists( 'alpha_search_form' ) ) {
	function alpha_search_form( $args = array() ) {
		$args = wp_parse_args(
			$args,
			array(
				'type'             => 'classic',
				'toggle_type'      => 'overlap',
				'search_align'     => 'start',
				'show_categories'  => false,
				'where'            => '',
				'live_search'      => (bool) alpha_get_option( 'live_search' ),
				'search_post_type' => alpha_get_option( 'search_post_type' ),
				'label'            => '',
				'placeholder'      => '',
			)
		);
		extract( $args );

		ob_start();
		$class = '';
		if ( 'toggle' == $type ) {
			$class .= ' hs-toggle hs-' . $toggle_type;
		}

		if ( $show_categories ) {
			$class .= ' hs-expanded';
		} else {
			$class .= ' hs-simple';
		}
		if ( 'toggle' == $type && 'dropdown' == $toggle_type ) {
			$class .= ' hs-' . $search_align;
		}

		?>
	
		<div class="search-wrapper<?php echo esc_attr( $class ); ?>">
			<?php if ( 'toggle' == $type ) : ?>
			<a href="#" class="search-toggle" title="search" aria-label="<? esc_attr_e('Search', 'alpha-pro'); ?>">
				<i class="<?php echo esc_attr( ALPHA_ICON_PREFIX . '-icon-search' ); ?>"></i>
				<?php if ( $label ) : ?>
				<span><?php echo esc_html( $label ); ?></span>
				<?php endif; ?>
			</a>
			<?php endif; ?>
	
			<?php if ( 'fullscreen' == $toggle_type ) : ?>
			<div class="search-form-overlay">
				<div class="close-overlay"></div>
				<div class="search-form-wrapper">
					<div class="search-inner-wrapper">
						<div class="search-form">
			<?php endif; ?>
			<form action="<?php echo esc_url( home_url() ); ?>/" method="get" class="input-wrapper">
				<input type="hidden" name="post_type" value="<?php echo esc_attr( $search_post_type ); ?>"/>
	
				<?php if ( 'header' == $where && $show_categories ) : ?>
				<div class="select-box">
					<?php
					$args = array(
						'show_option_all' => esc_html__( 'All Categories', 'alpha-pro' ),
						'hierarchical'    => 1,
						'class'           => 'cat',
						'echo'            => 1,
						'value_field'     => 'slug',
						'selected'        => 1,
						'depth'           => 1,
					);
					if ( 'product' == $search_post_type && class_exists( 'WooCommerce' ) ) {
						$args['taxonomy'] = 'product_cat';
						$args['name']     = 'product_cat';
					}
					wp_dropdown_categories( $args );
					?>
				</div>
				<?php endif; ?>
	
				<input type="search" aria-label="<?php esc_attr_e( 'Search', 'alpha-pro' ); ?>" class="form-control" name="s" placeholder="<?php echo esc_attr( $placeholder ); ?>" required="" autocomplete="off">
	
				<?php if ( $live_search ) : ?>
					<div class="live-search-list"></div>
				<?php endif; ?>
	
				<button class="btn btn-search" aria-label="<?php esc_attr_e( 'Search Button', 'alpha-pro' ); ?>" type="submit">
					<i class="<?php echo esc_attr( ALPHA_ICON_PREFIX . '-icon-search' ); ?>"></i>
				</button>
	
			<?php if ( 'overlap' == $toggle_type ) : ?>
				<div class="hs-close">
					<a href="#">
						<span class="close-wrap">
							<span class="close-line close-line1"></span>
							<span class="close-line close-line2"></span>
						</span>
					</a>
				</div>
			<?php endif; ?>
	
			</form>
			<?php if ( 'fullscreen' == $toggle_type ) : ?>
							<div class="search-header">
								<?php esc_html_e( 'Hit enter to search or ESC to close', 'alpha-pro' ); ?>
								<div class="hs-close">
									<a href="#">
										<span class="close-wrap">
											<span class="close-line close-line1"></span>
											<span class="close-line close-line2"></span>
										</span>
									</a>
								</div>
							</div>
						</div>
						<div class="search-container">
							<div class="scrollable">
								<div class="search-results">
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		<?php endif; ?>
		</div>
		<?php

		/**
		 * Filters search form.
		 *
		 * @since 1.0
		 */
		echo apply_filters( 'alpha_get_search_form', ob_get_clean() );
	}
}
