<?php
/**
 * Entrypoint of Alpha Pro
 *
 * Here, pro features of Alpha theme and Alpha Core plugin are added.
 *
 * @author     AlpusTheme
 * @package    Alpus Pro
 * @subpackage Pro
 * @since      1.0
 */

defined( 'ABSPATH' ) || die;

/**************************************/
/* Define Constants                */
/**************************************/
define( 'ALPHA_PRO_INC', ALPHA_PRO_PATH . '/inc' );
define( 'ALPHA_PRO_INC_URI', ALPHA_PRO_URI . '/inc' );
define( 'ALPHA_PRO_INC_PATH', ALPHA_PRO_PATH . '/inc' );
define( 'ALPHA_PRO_BUILDERS', ALPHA_PRO_INC . '/builders' );
define( 'ALPHA_PRO_ADDONS_URI', ALPHA_PRO_INC_URI . '/addons' );
define( 'ALPHA_PRO_ADDONS', ALPHA_PRO_INC_PATH . '/addons' );

class Alpha_Pro_Setup extends Alpha_Base {

	/**
	 * The Constructor
	 *
	 * @since 1.0
	 */
	public function __construct() {

		/**************************************/
		/* 1. Load the core general            */
		/**************************************/
		require_once ALPHA_PRO_PATH . '/inc/class-alpha-pro-assets.php';
		require_once ALPHA_PRO_PATH . '/inc/pro-functions.php';
		require_once ALPHA_PRO_PATH . '/inc/pro-actions.php';
		$this->config_extend();

		/**************************************/
		/* 2. Load scripts			          */
		/**************************************/
		add_action( 'wp_footer', array( $this, 'enqueue_js_css' ) );

		/**************************************/
		/* 3. Load plugin functions */
		/**************************************/
		$this->init_plugins();

		/**************************************/
		/* 4. Load builders                   */
		/**************************************/
		$this->load_builders();

		/**************************************/
		/* 5. Load addons and shortcodes      */
		/**************************************/
		add_action( 'alpha_after_framework_init', array( $this, 'extend_admin' ) );
		add_action( 'alpha_framework_addons', array( $this, 'extend_addons' ) );

	}

	/**
	 * Enqueue Theme Pro js at last
	 *
	 * @since 1.0
	 */
	public function enqueue_js_css() {
	}

	/**
	 * Manage features configuration
	 *
	 * @since 1.0
	 * @access public
	 */
	public function config_extend() {
	}

	/**
	 * Init plugins
	 *
	 * @since 1.0
	 * @access public
	 */
	public function init_plugins() {
		if ( alpha_get_feature( 'fs_pb_elementor' ) && defined( 'ELEMENTOR_VERSION' ) ) {
			require_once ALPHA_PRO_INC . '/plugins/elementor/class-alpha-pro-elementor.php';
		}
		if ( class_exists( 'bbPress' ) ) {
			require_once ALPHA_PRO_INC . '/plugins/bbpress/class-alpha-pro-bbpress.php';
		}
	}

	/**
	 * Load builders
	 *
	 * @since 1.0
	 * @access public
	 */
	public function load_builders() {
		require_once ALPHA_PRO_INC . '/builders/class-alpha-pro-builders.php';
	}

	/**
	 * Extends admin
	 *
	 * @param array $request
	 * @since 1.0
	 */
	public function extend_admin( $request ) {
		if ( alpha_get_feature( 'fs_admin_customize' ) && $request['customize_preview'] ) {
			require_once ALPHA_PRO_INC . '/admin/customizer/class-alpha-pro-customizer.php';
		}

		if ( $request['can_manage'] ) {
			require_once ALPHA_PRO_INC . '/admin/admin/class-alpha-pro-admin.php';
			if ( $request['is_admin'] ) {
				require_once ALPHA_PRO_INC . '/admin/layout-builder/class-alpha-pro-layout-builder-admin.php';
			}
		}
	}

	/**
	 * Extend addons
	 *
	 * @since 1.0
	 * @access public
	 */
	public function extend_addons( $request ) {
		// Custom Cursor Type
		require_once ALPHA_PRO_ADDONS . '/custom-cursor/class-alpha-pro-custom-cursor.php';

		// Dark Mode
		require_once ALPHA_PRO_ADDONS . '/dark-mode/class-alpha-pro-dark-mode.php';
	}
}

Alpha_Pro_Setup::get_instance();
